<?php

$LANG = array(
    'organization' => 'Entreprise',
    'name' => 'Nom',
    'website' => 'Site web',
    'work_phone' => 'Téléphone',
    'address' => 'Adresse',
    'address1' => 'Rue',
    'address2' => 'Appartement / Bureau',
    'city' => 'Ville',
    'state' => 'État / Province',
    'postal_code' => 'Code postal',
    'country_id' => 'Pays',
    'contacts' => 'Contacts',
    'first_name' => 'Prénom',
    'last_name' => 'Nom',
    'phone' => 'Téléphone',
    'email' => 'Courriel',
    'additional_info' => 'Informations complémentaires',
    'payment_terms' => 'Délais de paiement',
    'currency_id' => 'Devise',
    'size_id' => 'Taille de l\'entreprise',
    'industry_id' => 'Secteur d\'activité',
    'private_notes' => 'Notes personnelles',
    'invoice' => 'Facture',
    'client' => 'Client',
    'invoice_date' => 'Date de facturation',
    'due_date' => 'Échéance',
    'invoice_number' => 'N° de facture',
    'invoice_number_short' => 'Facture n°',
    'po_number' => 'N° de bon de commande',
    'po_number_short' => 'Bon de commande n°',
    'frequency_id' => 'Fréquence',
    'discount' => 'Escompte',
    'taxes' => 'Taxes',
    'tax' => 'Taxe',
    'item' => 'Article',
    'description' => 'Description',
    'unit_cost' => 'Coût unitaire',
    'quantity' => 'Quantité',
    'line_total' => 'Total',
    'subtotal' => 'Sous-total',
    'paid_to_date' => 'Payé à ce jour',
    'balance_due' => 'Solde dû',
    'invoice_design_id' => 'Modèle',
    'terms' => 'Modalités',
    'your_invoice' => 'Votre facture',
    'remove_contact' => 'Supprimer un contact',
    'add_contact' => 'Ajouter un contact',
    'create_new_client' => 'Créer un nouveau client',
    'edit_client_details' => 'Modifier les informations du client',
    'enable' => 'Autoriser',
    'learn_more' => 'En savoir plus',
    'manage_rates' => 'Gérer les taux',
    'note_to_client' => 'Commentaire pour le client',
    'invoice_terms' => 'Conditions de facturation',
    'save_as_default_terms' => 'Sauvegarder comme conditions par défaut',
    'download_pdf' => 'PDF',
    'pay_now' => 'Payer maintenant',
    'save_invoice' => 'Sauvegarder la facture',
    'clone_invoice' => 'Dupliquer en facture',
    'archive_invoice' => 'Archiver la facture',
    'delete_invoice' => 'Supprimer la facture',
    'email_invoice' => 'Envoyer la facture par courriel',
    'enter_payment' => 'Inscrire un paiement',
    'tax_rates' => 'Taux de taxe',
    'rate' => 'Taux',
    'settings' => 'Paramètres',
    'enable_invoice_tax' => 'Spécifier une <b>taxe pour la facture</b>',
    'enable_line_item_tax' => 'Spécifier une <b>taxe pour chaque ligne</b>',
    'dashboard' => 'Tableau de bord',
    'dashboard_totals_in_all_currencies_help' => 'Note: ajoutez un :link intitulé ":name" pour afficher les totaux qui utilisent une seule devise de base.',
    'clients' => 'Clients',
    'invoices' => 'Factures',
    'payments' => 'Paiements',
    'credits' => 'Crédits',
    'history' => 'Historique',
    'search' => 'Rechercher',
    'sign_up' => 'Inscription',
    'guest' => 'Invité',
    'company_details' => 'Informations sur l\'entreprise',
    'online_payments' => 'Paiements en ligne',
    'notifications' => 'Notifications',
    'import_export' => 'Importer / Exporter',
    'done' => 'Valider',
    'save' => 'Sauvegarder',
    'create' => 'Créer',
    'upload' => 'Téléverser',
    'import' => 'Importer',
    'download' => 'Télécharger',
    'cancel' => 'Annuler',
    'close' => 'Fermer',
    'provide_email' => 'Veuillez fournir une adresse courriel valide',
    'powered_by' => 'Propulsé par',
    'no_items' => 'Aucun élément',
    'recurring_invoices' => 'Factures récurrentes',
    'recurring_help' => '<p>Envoyer automatiquement la même facture à vos clients de façon hebdomadaire, bimensuelle, mensuelle, trimestrielle ou annuelle.</p>
    <p>Utiliser :MONTH, :QUARTER ou :YEAR pour des dates dynamiques. Les opérations simples fonctionnent également, par exemple :MONTH-1.</p>
    <p>Exemples de variables dynamiques pour les factures:</p>
    <ul>
    <li>"Adhésion au club de gym pour le mois de :MONTH" >> "Adhésion au club de gym pour le mois de Juillet"</li>
    <li>":YEAR+1 - abonnement annuel" >> "2015 - abonnement annuel"</li>
    <li>"Acompte pour le :QUARTER+1" >> "Acompte pour le Q2"</li>
    </ul>',
    'recurring_quotes' => 'Soumissions récurrentes',
    'in_total_revenue' => 'de revenu total',
    'billed_client' => 'client facturé',
    'billed_clients' => 'clients facturés',
    'active_client' => 'client actif',
    'active_clients' => 'clients actifs',
    'invoices_past_due' => 'Factures en souffrance',
    'upcoming_invoices' => 'Factures à venir',
    'average_invoice' => 'Facture moyenne',
    'archive' => 'Archiver',
    'delete' => 'Supprimer',
    'archive_client' => 'Archiver ce client',
    'delete_client' => 'Supprimer ce client',
    'archive_payment' => 'Archiver ce paiement',
    'delete_payment' => 'Supprimer ce paiement',
    'archive_credit' => 'Archiver ce crédit',
    'delete_credit' => 'Supprimer ce crédit',
    'show_archived_deleted' => 'Afficher archivés / supprimés',
    'filter' => 'Filtrer',
    'new_client' => 'Nouveau client',
    'new_invoice' => 'Nouvelle facture',
    'new_payment' => 'Inscrire un paiement',
    'new_credit' => 'Inscrire un crédit',
    'contact' => 'Contact',
    'date_created' => 'Date de création',
    'last_login' => 'Dernière connexion',
    'balance' => 'Solde',
    'action' => 'Action',
    'status' => 'Statut',
    'invoice_total' => 'Montant total',
    'frequency' => 'Fréquence',
    'range' => 'Étendue',
    'start_date' => 'Date de début',
    'end_date' => 'Date de fin',
    'transaction_reference' => 'N° de référence',
    'method' => 'Méthode',
    'payment_amount' => 'Montant du paiement',
    'payment_date' => 'Date du paiement',
    'credit_amount' => 'Montant du crédit',
    'credit_balance' => 'Solde du crédit',
    'credit_date' => 'Date du crédit',
    'empty_table' => 'Aucune donnée disponible dans le tableau',
    'select' => 'Sélectionner',
    'edit_client' => 'Modifier le client',
    'edit_invoice' => 'Modifier la facture',
    'create_invoice' => 'Créer une facture',
    'enter_credit' => 'Inscrire un crédit',
    'last_logged_in' => 'Dernière connexion',
    'details' => 'Détails',
    'standing' => 'En attente',
    'credit' => 'Crédit',
    'activity' => 'Activité',
    'date' => 'Date',
    'message' => 'Message',
    'adjustment' => 'Ajustement',
    'are_you_sure' => 'Voulez-vous vraiment effectuer cette action?',
    'payment_type_id' => 'Type de paiement',
    'amount' => 'Montant',
    'work_email' => 'Courriel',
    'language_id' => 'Langue',
    'timezone_id' => 'Fuseau horaire',
    'date_format_id' => 'Format de date',
    'datetime_format_id' => 'Format de date et d\'heure',
    'users' => 'Utilisateurs',
    'localization' => 'Paramètres régionaux',
    'remove_logo' => 'Supprimer le logo',
    'logo_help' => 'Formats supportés: JPEG, GIF et PNG',
    'payment_gateway' => 'Passerelle de paiement',
    'gateway_id' => 'Passerelle',
    'email_notifications' => 'Notifications par courriel',
    'email_sent' => 'M\'envoyer un courriel quand une facture est <b>envoyée</b>',
    'email_viewed' => 'M\'envoyer un courriel quand une facture est <b>vue</b>',
    'email_paid' => 'M\'envoyer un courriel quand une facture est <b>payée</b>',
    'site_updates' => 'Mises à jour du site',
    'custom_messages' => 'Messages personnalisés',
    'default_email_footer' => 'Définir comme la signature de courriel par défaut',
    'select_file' => 'Veuillez sélectionner un fichier',
    'first_row_headers' => 'Utiliser la première ligne comme entête',
    'column' => 'Colonne',
    'sample' => 'Exemple',
    'import_to' => 'Importer vers',
    'client_will_create' => 'client sera créé',
    'clients_will_create' => 'clients seront créés',
    'email_settings' => 'Paramètres de courriel',
    'client_view_styling' => 'Style de l\'affichage client',
    'pdf_email_attachment' => 'Joindre un PDF',
    'custom_css' => 'CSS personnalisé',
    'import_clients' => 'Importer des données de clients',
    'csv_file' => 'Fichier CSV',
    'export_clients' => 'Exporter les données de clients',
    'created_client' => 'Le client a été créé avec succès',
    'created_clients' => ':count clients ont été créés avec succès',
    'updated_settings' => 'Les paramètres ont été mis à jour avec succès',
    'removed_logo' => 'Le logo a été supprimé avec succès',
    'sent_message' => 'Le message a été envoyé avec succès',
    'invoice_error' => 'Veuillez vous assurer de sélectionner un client et de corriger les erreurs',
    'limit_clients' => 'Désolé, cela dépasse la limite de :count clients',
    'payment_error' => 'Il y a eu une erreur lors du traitement de votre paiement. Veuillez réessayer ultérieurement',
    'registration_required' => 'Veuillez vous enregistrer pour envoyer une facture par courriel',
    'confirmation_required' => 'Veuillez confirmer votre adresse courriel, :link pour renvoyer le courriel de confirmation.',
    'updated_client' => 'Le client a été modifié avec succès',
    'archived_client' => 'Le client a été archivé avec succès',
    'archived_clients' => ':count clients archivés avec succès',
    'deleted_client' => 'Le client a été supprimé avec succès',
    'deleted_clients' => ':count clients ont été supprimés avec succès',
    'updated_invoice' => 'La facture a été modifiée avec succès',
    'created_invoice' => 'La facture a été créée avec succès',
    'cloned_invoice' => 'La facture a été dupliquée avec succès',
    'emailed_invoice' => 'La facture a été envoyée par courriel avec succès',
    'and_created_client' => 'et client créé',
    'archived_invoice' => 'La facture a été archivée avec succès',
    'archived_invoices' => ':count factures ont été archivées avec succès',
    'deleted_invoice' => 'La facture a été supprimée avec succès',
    'deleted_invoices' => ':count factures supprimées avec succès',
    'created_payment' => 'Le paiement a été créé avec succès',
    'created_payments' => ':count paiements ont été créés avec succès',
    'archived_payment' => 'Le paiement a été archivé avec succès',
    'archived_payments' => ':count paiements ont été archivés avec succès',
    'deleted_payment' => 'Le paiement a été supprimé avec succès',
    'deleted_payments' => ':count paiements ont été supprimés avec succès',
    'applied_payment' => 'Le paiement a été appliqué avec succès',
    'created_credit' => 'Le crédit a été créé avec succès',
    'archived_credit' => 'Le crédit a été archivé avec succès',
    'archived_credits' => ':count crédits ont archivés avec succès',
    'deleted_credit' => 'Le crédit a été supprimé avec succès',
    'deleted_credits' => ':count crédits ont été supprimés avec succès',
    'imported_file' => 'Le fichier a été importé avec succès',
    'updated_vendor' => 'Le fournisseur a été mis à jour avec succès',
    'created_vendor' => 'Le fournisseur a été créé avec succès',
    'archived_vendor' => 'Le fournisseur a été archivé avec succès',
    'archived_vendors' => ':count fournisseurs ont été archivés avec succès',
    'deleted_vendor' => 'Le fournisseur a été supprimé avec succès',
    'deleted_vendors' => ':count fournisseurs ont été supprimés avec succès',
    'confirmation_subject' => 'Validation du compte Invoice Ninja',
    'confirmation_header' => 'Validation du compte',
    'confirmation_message' => 'Veuillez cliquer sur le lien ci-dessous pour valider votre compte.',
    'invoice_subject' => 'Nouvelle facture :number de :account',
    'invoice_message' => 'Pour voir votre facture de :amount, Cliquez sur le lien ci-dessous.',
    'payment_subject' => 'Paiement reçu',
    'payment_message' => 'Merci pour votre paiement d\'un montant de :amount',
    'email_salutation' => 'Cher :name,',
    'email_signature' => 'Cordialement,',
    'email_from' => 'L\'équipe de Invoice Ninja',
    'invoice_link_message' => 'Pour voir la facture de votre client cliquez sur le lien ci-dessous:',
    'notification_invoice_paid_subject' => 'La facture :invoice a été payée par le client :client',
    'notification_invoice_sent_subject' => 'La facture :invoice a été envoyée au client :client',
    'notification_invoice_viewed_subject' => 'La facture :invoice a été vue par le client :client',
    'notification_invoice_paid' => 'Un paiement de :amount a été effectué par le client :client concernant la facture :invoice.',
    'notification_invoice_sent' => 'Le client suivant :client a reçu par courriel la facture :invoice d\'un montant de :amount',
    'notification_invoice_viewed' => 'Le client suivant :client a vu la facture :invoice d\'un montant de :amount',
    'reset_password' => 'Vous pouvez réinitialiser votre mot de passe en cliquant sur le lien suivant :',
    'secure_payment' => 'Paiement sécurisé',
    'card_number' => 'N° de carte',
    'expiration_month' => 'Mois d\'expiration',
    'expiration_year' => 'Année d\'expiration',
    'cvv' => 'CVV',
    'logout' => 'Déconnexion',
    'sign_up_to_save' => 'Connectez-vous pour sauvegarder votre travail',
    'agree_to_terms' => 'J\'accepte les :terms',
    'terms_of_service' => 'Conditions d\'utilisation',
    'email_taken' => 'Cette adresse courriel existe déjà',
    'working' => 'En cours',
    'success' => 'Succès',
    'success_message' => 'Inscription réussie avec succès! Veuillez cliquer sur le lien dans le courriel de confirmation de compte pour vérifier votre adresse courriel.',
    'erase_data' => 'Votre compte n\'est pas enregistré. Cette action va définitivement supprimer vos données.',
    'password' => 'Mot de passe',
    'pro_plan_product' => 'Plan Pro',
    'pro_plan_success' => 'Merci pour votre inscription ! Une fois la facture réglée, votre adhésion au Plan Pro commencera.',
    'unsaved_changes' => 'Vous avez des modifications non enregistrées',
    'custom_fields' => 'Champs personnalisés',
    'company_fields' => 'Champs d\'entreprise',
    'client_fields' => 'Champs de client',
    'field_label' => 'Nom du champ',
    'field_value' => 'Valeur du champ',
    'edit' => 'Modifier',
    'set_name' => 'Entrez le nom de votre entreprise',
    'view_as_recipient' => 'Voir en tant que destinataire',
    'product_library' => 'Inventaire',
    'product' => 'Produit',
    'products' => 'Produits',
    'fill_products' => 'Remplissage automatique des produits',
    'fill_products_help' => 'La sélection d\'un produit entrainera la mise à jour de <b>la description et du prix</b>',
    'update_products' => 'Mise à jour automatique des produits',
    'update_products_help' => 'La mise à jour d\'une facture entraîne la <b>mise à jour des produits</b>',
    'create_product' => 'Nouveau produit',
    'edit_product' => 'Modifier le produit',
    'archive_product' => 'Archiver le produit',
    'updated_product' => 'Le produit a été mis à jour avec succès',
    'created_product' => 'Le produit a été créé avec succès',
    'archived_product' => 'Le produit a été archivé avec succès',
    'pro_plan_custom_fields' => ':link pour activer les champs personnalisés en rejoingant le Plan Pro',
    'advanced_settings' => 'Paramètres avancés',
    'pro_plan_advanced_settings' => ':link pour activer les paramètres avancés en rejoingant le Plan Pro',
    'invoice_design' => 'Modèles de factures',
    'specify_colors' => 'Spécifiez les couleurs',
    'specify_colors_label' => 'Sélectionnez les couleurs utilisés dans les factures',
    'chart_builder' => 'Concepteur de graphiques',
    'ninja_email_footer' => 'Créé par :site | Créer. Envoyer. Encaisser.',
    'go_pro' => 'Devenez Pro',
    'quote' => 'Soumission',
    'quotes' => 'Soumissions',
    'quote_number' => 'N° de soumission',
    'quote_number_short' => 'Soumission n° ',
    'quote_date' => 'Date de soumission',
    'quote_total' => 'Total de la soumission',
    'your_quote' => 'Votre soumission',
    'total' => 'Total',
    'clone' => 'Dupliquer',
    'new_quote' => 'Nouvelle soumission',
    'create_quote' => 'Créer une soumission',
    'edit_quote' => 'Modifier la soumission',
    'archive_quote' => 'Archiver la soumission',
    'delete_quote' => 'Supprimer la soumission',
    'save_quote' => 'Enregistrer la soumission',
    'email_quote' => 'Envoyer la soumission par courriel',
    'clone_quote' => 'Dupliquer vers une nouvelle soumission',
    'convert_to_invoice' => 'Convertir en facture',
    'view_invoice' => 'Voir la facture',
    'view_client' => 'Voir le client',
    'view_quote' => 'Voir la soumission',
    'updated_quote' => 'La soumission a été mise à jour avec succès',
    'created_quote' => 'La soumission a été créée avec succès',
    'cloned_quote' => 'La soumission a été dupliquée avec succès',
    'emailed_quote' => 'La soumission a été envoyée avec succès',
    'archived_quote' => 'La soumission a été archivée avec succès',
    'archived_quotes' => ':count soumissions ont été archivées avec succès',
    'deleted_quote' => 'La soumission a été supprimée avec succès',
    'deleted_quotes' => ':count soumissions ont été supprimées avec succès',
    'converted_to_invoice' => 'La soumission a été convertie en facture avec succès',
    'quote_subject' => 'Nouvelle soumission :number de :account',
    'quote_message' => 'Pour visionner votre soumission de :amount, cliquez sur le lien ci-dessous.',
    'quote_link_message' => 'Pour visionner votre soumission, cliquez sur le lien ci-dessous:',
    'notification_quote_sent_subject' => 'La soumission :invoice a été envoyée à :client',
    'notification_quote_viewed_subject' => 'La soumission :invoice a été visionnée par :client',
    'notification_quote_sent' => 'La soumission :invoice de :amount a été envoyée au client :client.',
    'notification_quote_viewed' => 'La soumission :invoice de :amount a été visionnée par le client :client.',
    'session_expired' => 'Votre session a expiré.',
    'invoice_fields' => 'Champs de facture',
    'invoice_options' => 'Options de facture',
    'hide_paid_to_date' => 'Masquer "Payé à ce jour"',
    'hide_paid_to_date_help' => 'Afficher seulement la ligne "Payé à ce jour" sur les factures pour lesquelles il y a au moins un paiement.',
    'charge_taxes' => 'Facturer les taxes',
    'user_management' => 'Gestion des utilisateurs',
    'add_user' => 'Ajouter un utilisateur',
    'send_invite' => 'Envoyer l\'invitation',
    'sent_invite' => 'L\'invitation a été envoyée avec succès',
    'updated_user' => 'L\'utilisateur a été mis à jour avec succès',
    'invitation_message' => 'Vous avez été invité par :invitor. ',
    'register_to_add_user' => 'Veuillez vous enregistrer pour ajouter un utilisateur',
    'user_state' => 'État',
    'edit_user' => 'Éditer l\'utilisateur',
    'delete_user' => 'Supprimer l\'utilisateur',
    'active' => 'Actif',
    'pending' => 'En attente',
    'deleted_user' => 'L\'utilisateur a été supprimé avec succès',
    'confirm_email_invoice' => 'Voulez-vous vraiment envoyer cette facture par courriel?',
    'confirm_email_quote' => 'Voulez-vous vraiment envoyer cette soumission par courriel?',
    'confirm_recurring_email_invoice' => 'Voulez-vous vraiment envoyer cette facture par courriel?',
    'confirm_recurring_email_invoice_not_sent' => 'Voulez-vous vraiment démarrer cette récurrence?',
    'cancel_account' => 'Supprimer le compte',
    'cancel_account_message' => 'Avertissement: cette action est irréversible et supprimera votre compte de façon définitive.',
    'go_back' => 'Retour',
    'data_visualizations' => 'Visualisation des données',
    'sample_data' => 'Données fictives présentées',
    'hide' => 'Cacher',
    'new_version_available' => 'Une nouvelle version de :releases_link est disponible. Vous utilisez v:user_version, la plus récente est v:latest_version',
    'invoice_settings' => 'Paramètres des factures',
    'invoice_number_prefix' => 'Préfixe du numéro de facture',
    'invoice_number_counter' => 'Compteur du numéro de facture',
    'quote_number_prefix' => 'Préfixe du numéro de soumission',
    'quote_number_counter' => 'Compteur du numéro de soumission',
    'share_invoice_counter' => 'Partager le compteur de facture',
    'invoice_issued_to' => 'Facture destinée à',
    'invalid_counter' => 'Pour éviter un éventuel conflit, merci de définir un préfixe pour le numéro de facture ou pour le numéro de soumission',
    'mark_sent' => 'Marquer comme envoyé',
    'gateway_help_1' => ':link pour vous inscrire à Authorize.net.',
    'gateway_help_2' => ':link pour vous inscrire à Authorize.net.',
    'gateway_help_17' => ':link pour obtenir votre signature API PayPal.',
    'gateway_help_27' => ':link pour vous inscrire à 2Checkout.com. Pour permettre le suivi des paiements, veuillez définir :complete_link comme URL de redirection dans Mon compte > Gestion de site dans le portail de 2Checkout.',
    'gateway_help_60' => ':link pour créer un compte WePay.',
    'more_designs' => 'Plus de modèles',
    'more_designs_title' => 'Modèles de factures additionnels',
    'more_designs_cloud_header' => 'Passez au Plan Pro pour obtenir plus de modèles',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Acheter',
    'bought_designs' => 'Les nouveaux modèles ont été ajoutés avec succès',
    'sent' => 'Envoyé',
    'vat_number' => 'N° de taxe',
    'timesheets' => 'Feuilles de temps',
    'payment_title' => 'Veuillez entrer votre adresse de facturation et vos information de carte de crédit',
    'payment_cvv' => '*Il s\'agit des 3 ou 4 chiffres au dos de votre carte',
    'payment_footer1' => '*L\'adresse de facturation doit correspondre à l\'adresse associée à votre carte de crédit.',
    'payment_footer2' => '*Veuillez cliquer sur "PAYER MAINTENANT" une seule fois - la transaction peut prendre jusqu\'à 1 minute.',
    'id_number' => 'N° d\'entreprise',
    'white_label_link' => 'Sans marque',
    'white_label_header' => 'Entête de version sans marque',
    'bought_white_label' => 'Licence de version sans marque activée avec succès',
    'white_labeled' => 'Sans marque',
    'restore' => 'Restaurer',
    'restore_invoice' => 'Restaurer la facture',
    'restore_quote' => 'Restaurer la soumission',
    'restore_client' => 'Restaurer le client',
    'restore_credit' => 'Restaurer le crédit',
    'restore_payment' => 'Restaurer le paiement',
    'restored_invoice' => 'La facture a été restaurée avec succès',
    'restored_quote' => 'La soumission a été restaurée avec succès',
    'restored_client' => 'Le client a été restauré avec succès',
    'restored_payment' => 'Le paiement a été restauré avec succès',
    'restored_credit' => 'Le crédit a été restauré avec succès',
    'reason_for_canceling' => 'Aidez-nous à améliorer notre site en nous disant pourquoi vous partez.',
    'discount_percent' => 'Pourcent',
    'discount_amount' => 'Montant',
    'invoice_history' => 'Historique des factures',
    'quote_history' => 'Historique des soumissions',
    'current_version' => 'Version courante',
    'select_version' => 'Choix de la verison',
    'view_history' => 'Consulter l\'historique',
    'edit_payment' => 'Modifier le paiement',
    'updated_payment' => 'Le paiement a été mis à jour avec succès',
    'deleted' => 'Supprimé',
    'restore_user' => 'Restaurer un utilisateur',
    'restored_user' => 'L\'utilisateur a été restauré avec succès',
    'show_deleted_users' => 'Afficher les utilisateurs supprimés',
    'email_templates' => 'Modèles de courriel',
    'invoice_email' => 'Courriel de facturation',
    'payment_email' => 'Courriel de paiement',
    'quote_email' => 'Courriel de soumission',
    'reset_all' => 'Remise à zéro',
    'approve' => 'Approuver',
    'token_billing_type_id' => 'Jeton de facturation',
    'token_billing_help' => 'Enregistrez les informations de paiement avec WePay, Stripe, Braintree ou GoCardless.',
    'token_billing_1' => 'Désactivé',
    'token_billing_2' => 'Adhérer - case à cocher affichée et non sélectionner',
    'token_billing_3' => 'Se soustraire - case à cocher affichée et sélectionnée',
    'token_billing_4' => 'Toujours',
    'token_billing_checkbox' => 'Mémoriser les informations de carte de crédit',
    'view_in_gateway' => 'Visualiser dans :gateway',
    'use_card_on_file' => 'Utiliser la carte inscrite au dossier',
    'edit_payment_details' => 'Modifier les informations de paiement',
    'token_billing' => 'Sauvegarder les informations de carte de crédit',
    'token_billing_secure' => 'Les données sont mémorisées de façon sécuritaire avec :link',
    'support' => 'Support',
    'contact_information' => 'Contact',
    '256_encryption' => 'Chiffrage 256-Bit',
    'amount_due' => 'Montant dû',
    'billing_address' => 'Adresse de facturation',
    'billing_method' => 'Méthode de facturation',
    'order_overview' => 'Récapitulatif de la commande',
    'match_address' => '*L\'adresse doit correspondre à l\'adresse associée à la carte de crédit.',
    'click_once' => '*Please click "PAY NOW" only once - transaction may take up to 1 minute to process.',
    'invoice_footer' => 'Pied de facture',
    'save_as_default_footer' => 'Sauvegarder comme pied de facture par défaut',
    'token_management' => 'Gestion des jetons',
    'tokens' => 'Jetons',
    'add_token' => 'Ajouter un jeton',
    'show_deleted_tokens' => 'Afficher les jetons supprimés',
    'deleted_token' => 'Le jeton a été supprimé avec succès',
    'created_token' => 'Le jeton a été créé avec succès',
    'updated_token' => 'Le jeton a été mis à jour avec succès',
    'edit_token' => 'Éditer le jeton',
    'delete_token' => 'Supprimer le jeton',
    'token' => 'Jeton',
    'add_gateway' => 'Ajouter une passerelle',
    'delete_gateway' => 'Supprimer la passerelle',
    'edit_gateway' => 'Éditer la passerelle',
    'updated_gateway' => 'La passerelle a été mise à jour avec succès',
    'created_gateway' => 'La passerelle a été créée avec succès',
    'deleted_gateway' => 'La passerelle a été supprimée avec succès',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Carte de crédit',
    'change_password' => 'Modifier le mot de passe',
    'current_password' => 'Mot de passe actuel',
    'new_password' => 'Nouveau mot de passe',
    'confirm_password' => 'Confirmer le mot de passe',
    'password_error_incorrect' => 'Le mot de passe est incorrect.',
    'password_error_invalid' => 'Le nouveau mot de passe est invalide.',
    'updated_password' => 'Le mot de passe a été mis à jour avec succès',
    'api_tokens' => 'Jetons API',
    'users_and_tokens' => 'Utilisateurs et jetons',
    'account_login' => 'Connexion',
    'recover_password' => 'Récupérez votre mot de passe',
    'forgot_password' => 'Mot de passe oublié?',
    'email_address' => 'Adresse courriel',
    'lets_go' => 'Allons-y',
    'password_recovery' => 'Récupération de mot de passe',
    'send_email' => 'Envoyer un courriel',
    'set_password' => 'Nouveau mot de passe',
    'converted' => 'Convertie',
    'email_approved' => 'M\'envoyer un courriel lorsqu\'une soumission a été <b>acceptée</b>',
    'notification_quote_approved_subject' => 'La soumission :invoice a été acceptée par :client',
    'notification_quote_approved' => 'Le client :client a accepté la soumission :invoice pour :amount.',
    'resend_confirmation' => 'Renvoyer la confirmation par courriel',
    'confirmation_resent' => 'La confirmation a été renvoyée',
    'gateway_help_42' => ':link pour s\'inscrire à BitPay.<br/>Note: utilisez une clé API ancienne et non un jeton API.',
    'payment_type_credit_card' => 'Carte de crédit',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Base de connaissances',
    'partial' => 'Partiel / dépôt',
    'partial_remaining' => ':partiel de :balance',
    'more_fields' => 'Plus de champs',
    'less_fields' => 'Moins de champs',
    'client_name' => 'Nom du client',
    'pdf_settings' => 'Paramètres PDF',
    'product_settings' => 'Paramètres des produits',
    'auto_wrap' => 'Retour à la ligne automatique',
    'duplicate_post' => 'Avertissement: la page précédente a été envoyée deux fois. Le deuxième envoi a été ignoré.',
    'view_documentation' => 'Voir la documentation',
    'app_title' => 'Gestionnaire de facturation en ligne, gratuit et open-source',
    'app_description' => 'Invoice Ninja est une solution de facturation et de paiement gratuite et open-source. Avec Invoice Ninja, vous pouvez facilement construire et envoyer des factures de n\'importe quel appareil ayant accès au web. Vos clients peuvent imprimer leurs factures, les télécharger au format PDF, et même les payer en ligne à partir du système.',
    'rows' => 'lignes',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'sous-domaine',
    'provide_name_or_email' => 'Veuillez entrer un nom ou un courriel',
    'charts_and_reports' => 'Rapports et graphiques',
    'chart' => 'Graphique',
    'report' => 'Rapport',
    'group_by' => 'Grouper par',
    'paid' => 'Payé',
    'enable_report' => 'Rapport',
    'enable_chart' => 'Graphique',
    'totals' => 'Totaux',
    'run' => 'Lancer',
    'export' => 'Exporter',
    'documentation' => 'Documentation',
    'zapier' => 'Zapier',
    'recurring' => 'Récurrente',
    'last_invoice_sent' => 'Dernière facture envoyée le :date',
    'processed_updates' => 'La mise à jour été complétée avec succès',
    'tasks' => 'Tâches',
    'new_task' => 'Nouvelle tâche',
    'start_time' => 'Démarrée à',
    'created_task' => 'La tâche a été créée avec succès',
    'updated_task' => 'La tâche a été modifiée avec succès',
    'edit_task' => 'Éditer la tâche',
    'clone_task' => 'Dupliquer la tâche',
    'archive_task' => 'Archiver la Tâche',
    'restore_task' => 'Restaurer la Tâche',
    'delete_task' => 'Supprimer la Tâche',
    'stop_task' => 'Arrêter la Tâche',
    'time' => 'Temps',
    'start' => 'Démarrer',
    'stop' => 'Arrêter',
    'now' => 'Maintenant',
    'timer' => 'Minuteur',
    'manual' => 'Manuel',
    'date_and_time' => 'Date et heure',
    'second' => 'Seconde',
    'seconds' => 'Secondes',
    'minute' => 'Minute',
    'minutes' => 'Minutes',
    'hour' => 'Heure',
    'hours' => 'Heures',
    'task_details' => 'Détails de la tâche',
    'duration' => 'Durée',
    'time_log' => 'Journal de temps',
    'end_time' => 'Arrêtée à',
    'end' => 'Fin',
    'invoiced' => 'Facturée',
    'logged' => 'Enregistrée',
    'running' => 'En cours',
    'task_error_multiple_clients' => 'Une tâche ne peut appartenir à plusieurs clients',
    'task_error_running' => 'Merci d\'arrêter les tâches en cours',
    'task_error_invoiced' => 'Ces tâches ont déjà été facturées',
    'restored_task' => 'La tâche a été restaurée avec succès',
    'archived_task' => 'La tâche a été archivée avec succès',
    'archived_tasks' => ':count tâches ont été archivées avec succès',
    'deleted_task' => 'La tâche a été supprimée avec succès',
    'deleted_tasks' => ':count tâches ont été supprimées avec succès',
    'create_task' => 'Créer une Tâche',
    'stopped_task' => 'La tâche a été arrêtée avec succès',
    'invoice_task' => 'Facturer la tâche',
    'invoice_labels' => 'Champs des produits',
    'prefix' => 'Préfixe',
    'counter' => 'Compteur',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link pour s\'inscrire à Dwolla.',
    'partial_value' => 'Doit être plus grand que zéro et moins que le total',
    'more_actions' => 'Plus d\'actions',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Mettre à niveau!',
    'pro_plan_feature1' => 'Nombre illimité de client',
    'pro_plan_feature2' => '10 extraodinaires modèles de factures',
    'pro_plan_feature3' => 'URL personnalisées - "VotreNom.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Suppression de "Créé par Invoice Ninja"',
    'pro_plan_feature5' => 'Accès multi-utilisateurs & suivi d\'activité',
    'pro_plan_feature6' => 'Création de soumission et de factures Pro-forma',
    'pro_plan_feature7' => 'Personnalisation des champs de facture',
    'pro_plan_feature8' => 'Pièces jointes PDF pour les envois de courriel aux clients',
    'resume' => 'Continuer',
    'break_duration' => 'Pause',
    'edit_details' => 'Modifier les détails',
    'work' => 'Travail',
    'timezone_unset' => 'Veuillez :link pour définir votre fuseau horaire',
    'click_here' => 'cliquer ici',
    'email_receipt' => 'Envoyer le reçu de paiement par courriel au client',
    'created_payment_emailed_client' => 'Le paiement a été créé et envoyé par courriel au client avec succès',
    'add_company' => 'Ajouter une entreprise',
    'untitled' => 'Sans nom',
    'new_company' => 'Nouvelle entreprise',
    'associated_accounts' => 'Les comptes ont été liés avec succès',
    'unlinked_account' => 'Les comptes ont été dissociés avec succès',
    'login' => 'Connexion',
    'or' => 'ou',
    'email_error' => 'Il y a eu un problème lors de l\'envoi du courriel',
    'confirm_recurring_timing' => 'Note: Les courriels sont envoyés au début de chaque heure.',
    'confirm_recurring_timing_not_sent' => 'Note : Les factures sont créées au début de chaque heure.',
    'payment_terms_help' => 'Définit la <b>date d\'échéance de la facture</b> par défaut',
    'unlink_account' => 'Dissocier le compte',
    'unlink' => 'Dissocié',
    'show_address' => 'Afficher l\'adresse',
    'show_address_help' => 'Le client doit fournir son adresse de facturation',
    'update_address' => 'Mise à jour de l\'adresse',
    'update_address_help' => 'Met à jour l\'adresse du client avec les informations fournies',
    'times' => 'Temps',
    'set_now' => 'Définir',
    'dark_mode' => 'Mode foncé',
    'dark_mode_help' => 'Utiliser un fond sombre pour les barres latérales',
    'add_to_invoice' => 'Ajouter à la facture :invoice',
    'create_new_invoice' => 'Créer une facture',
    'task_errors' => 'Veuillez corriger les plages de temps qui se chevauchent',
    'from' => 'De',
    'to' => 'à',
    'font_size' => 'Taille de police',
    'primary_color' => 'Couleur principale',
    'secondary_color' => 'Couleur secondaire',
    'customize_design' => 'Personnaliser le modèle',
    'content' => 'Contenu',
    'styles' => 'Styles',
    'defaults' => 'Pré-définis',
    'margins' => 'Marges',
    'header' => 'Entête',
    'footer' => 'Pied de page',
    'custom' => 'Personnalisé',
    'invoice_to' => 'Facture à',
    'invoice_no' => 'Facture n°',
    'quote_no' => 'N° de soumission',
    'recent_payments' => 'Paiements reçus',
    'outstanding' => 'Impayées',
    'manage_companies' => 'Gérer les entreprises',
    'total_revenue' => 'Revenu total',
    'current_user' => 'Utilisateur en cours',
    'new_recurring_invoice' => 'Nouvelle facture récurrente',
    'recurring_invoice' => 'Facture récurrente',
    'new_recurring_quote' => 'Nouvelle soumission récurrente',
    'recurring_quote' => 'Soumission récurrente',
    'recurring_too_soon' => 'il est trop tôt pour la création d\'une autre facture récurrente, elle est planifiée pour le :date',
    'created_by_invoice' => 'Créée par :invoice',
    'primary_user' => 'Utilisateur principal',
    'help' => 'Aide',
    'customize_help' => '<p>Nous utilisons :pdfmake_link pour définir la présentation graphique des factures de manière déclarative. Pdfmake playground_link fournit une excellente façon de voir la librairie en action.</p>
                        <p>Si vous avez besoin d\'aide à ce sujet, vous pouvez publier une question sur notre :forum_link avec la présentation graphique que vous utilisez.</p>',
    'playground' => 'environnement',
    'support_forum' => 'Forum de support',
    'invoice_due_date' => 'Échéance',
    'quote_due_date' => 'Valide jusqu\'au',
    'valid_until' => 'Valide jusqu\'au',
    'reset_terms' => 'Remise à zéro des délais',
    'reset_footer' => 'Remise à zéro du pied de page',
    'invoice_sent' => ':count facture envoyée',
    'invoices_sent' => ':count factures envoyées',
    'status_draft' => 'Brouillon',
    'status_sent' => 'Envoyée',
    'status_viewed' => 'Vue',
    'status_partial' => 'Partiel',
    'status_paid' => 'Payée',
    'status_unpaid' => 'Impayé',
    'status_all' => 'Tous',
    'show_line_item_tax' => 'Afficher la <b>taxe</b> sur la même ligne',
    'iframe_url' => 'Site web',
    'iframe_url_help1' => 'Copier ce code sur une page de votre site.',
    'iframe_url_help2' => 'Vous pouvez tester cette fonctionnalité en cliquant \'Visualiser en tant que destinataire\' pour une facture.',
    'auto_bill' => 'Facturation automatique',
    'military_time' => 'Format d\'heure 24 h',
    'last_sent' => 'Dernier envoi',
    'reminder_emails' => 'Courriels de rappel',
    'quote_reminder_emails' => 'Courriel de rappel de soumission',
    'templates_and_reminders' => 'Modèles et rappels',
    'subject' => 'Sujet',
    'body' => 'Message',
    'first_reminder' => '1er rappel',
    'second_reminder' => '2e rappel',
    'third_reminder' => '3e rappel',
    'num_days_reminder' => 'Jours après la date d\'échéance',
    'reminder_subject' => 'Rappel: facture :invoice de :account',
    'reset' => 'Remise à zéro',
    'invoice_not_found' => 'La facture demandée n\'est pas disponible',
    'referral_program' => 'Programme de référencement',
    'referral_code' => 'Code de référencement',
    'last_sent_on' => 'Dernier envoi le :date',
    'page_expire' => 'Cette page va expirer bientôt, :click_here pour continuer',
    'upcoming_quotes' => 'Soumissions à venir',
    'expired_quotes' => 'Soumissions expirées',
    'sign_up_using' => 'Connectez-vous avec',
    'invalid_credentials' => 'Ces informations ne correspondent pas à nos données',
    'show_all_options' => 'Afficher toutes les options',
    'user_details' => 'Profil utilisateur',
    'oneclick_login' => 'Compte connecté',
    'disable' => 'Désactiver',
    'invoice_quote_number' => 'Numéros de factures et de soumissions',
    'invoice_charges' => 'Suppléments de facture',
    'notification_invoice_bounced' => 'Impossible d\'envoyer la facture :invoice à :contact.',
    'notification_invoice_bounced_subject' => 'Impossible d\'envoyer la facture :invoice',
    'notification_quote_bounced' => 'Impossible d\'envoyer la soumission :invoice à :contact.',
    'notification_quote_bounced_subject' => 'Impossible d\'envoyer la soumission :invoice',
    'custom_invoice_link' => 'Lien de facture personnalisé',
    'total_invoiced' => 'Total facturé',
    'open_balance' => 'Solde restant',
    'verify_email' => 'Veuillez vérifier votre adresse courriel en suivant le lien dans le courriel de confirmation.',
    'basic_settings' => 'Paramètres de base',
    'pro' => 'Pro',
    'gateways' => 'Passerelles de paiements',
    'next_send_on' => 'Prochain envoi: :date',
    'no_longer_running' => 'Cette facture n\'est pas planifiée pour un envoi',
    'general_settings' => 'Paramètres généraux',
    'customize' => 'Personnalisation',
    'oneclick_login_help' => 'Connectez-vous à un compte pour une connexion sans mot de passe',
    'referral_code_help' => 'Gagnez de l\'argent en faisant connaître notre application',
    'enable_with_stripe' => 'Activer | Requiert Stripe',
    'tax_settings' => 'Paramètres des taxes',
    'create_tax_rate' => 'Ajouter un taux de taxe',
    'updated_tax_rate' => 'Le taux de taxe a été mis à jour avec succès',
    'created_tax_rate' => 'Le taux de taxe a été créé avec succès',
    'edit_tax_rate' => 'Éditer le taux de taxe',
    'archive_tax_rate' => 'Archiver le taux de taxe',
    'archived_tax_rate' => 'Le taux de taxe a été archivé avec succès',
    'default_tax_rate_id' => 'Taux de taxe par défaut',
    'tax_rate' => 'Taux de taxe',
    'recurring_hour' => 'Heure récurrente',
    'pattern' => 'Modèle',
    'pattern_help_title' => 'Aide pour les modèles',
    'pattern_help_1' => 'Crée une numérotation personnalisée à partir d\'un modèle',
    'pattern_help_2' => 'Variables disponibles:',
    'pattern_help_3' => 'Par exemple, :example produira :value',
    'see_options' => 'Voir les options',
    'invoice_counter' => 'Numéros de factures',
    'quote_counter' => 'Numéros de soumissions',
    'type' => 'Type',
    'activity_1' => ':user a créé le client :client',
    'activity_2' => ':user a archivé le client :client',
    'activity_3' => ':user a supprimé le client :client',
    'activity_4' => ':user a créé la facture :invoice',
    'activity_5' => ':user a mis à jour la facture :invoice',
    'activity_6' => ':user a envoyé par courriel la facture :invoice pour :client à :contact',
    'activity_7' => ':contact a visualisé la facture :invoice pour :client',
    'activity_8' => ':user a archivé la facture :invoice',
    'activity_9' => ':user a supprimé la facture :invoice',
    'activity_10' => ':contact a saisi le paiement :payment de :payment_amount de la facture :invoice pour :client',
    'activity_11' => ':user a mis à jour le paiement :payment',
    'activity_12' => ':user a archivé le paiement :payment',
    'activity_13' => ':user a supprimé le paiement :payment',
    'activity_14' => ':user a saisi le crédit :credit',
    'activity_15' => ':user a mis à jour le crédit :credit',
    'activity_16' => ':user a archivé le crédit :credit',
    'activity_17' => ':user a supprimé le crédit :credit',
    'activity_18' => ':user a créé la soumission :quote',
    'activity_19' => ':user a mis à jour la soumission :quote',
    'activity_20' => ':user a envoyé par courriel la soumission :quote pour :client à :contact',
    'activity_21' => ':contact a visualisé la soumission :quote',
    'activity_22' => ':user a archivé la soumission :quote',
    'activity_23' => ':user a supprimé la soumission :quote',
    'activity_24' => ':user a restauré la soumission :quote',
    'activity_25' => ':user a restauré la facture :invoice',
    'activity_26' => ':user a restauré le client :client',
    'activity_27' => ':user a restauré le paiement :payment',
    'activity_28' => ':user a restauré le crédit :credit',
    'activity_29' => ':contact a approuvé la soumission :quote pour :client',
    'activity_30' => ':user a créé le fournisseur :vendor',
    'activity_31' => ':user a archivé le fournisseur :vendor',
    'activity_32' => ':user a supprimé le fournisseur :vendor',
    'activity_33' => ':user a restauré le fournisseur :vendor',
    'activity_34' => ':user a créé la dépense :expense',
    'activity_35' => ':user a archivé la dépense :expense',
    'activity_36' => ':user a supprimé la dépense :expense',
    'activity_37' => ':user a restauré la dépense :expense',
    'activity_42' => ':user a créé la tâche :task',
    'activity_43' => ':user a mis à jour la tâche :task',
    'activity_44' => ':user a archivé la tâche :task',
    'activity_45' => ':user a supprimé la tâche :task',
    'activity_46' => ':user a restauré la tâche :task',
    'activity_47' => ':user a mis à jour la dépense :expense',
    'activity_48' => ':user a mis à jour le billet :ticket',
    'activity_49' => ':user a fermé le billet :ticket',
    'activity_50' => ':user a fusionné le billet :ticket',
    'activity_51' => ':user a scindé le billet :ticket',
    'activity_52' => ':contact a ouvert le billet :ticket',
    'activity_53' => ':contact a réouvert le billet :ticket',
    'activity_54' => ':user a réouvert le billet :ticket',
    'activity_55' => ':contact a répondu au billet :ticket',
    'activity_56' => ':user a vu le billet :ticket',

    'payment' => 'Paiement',
    'system' => 'Système',
    'signature' => 'Signature de courriel',
    'default_messages' => 'Message par défaut',
    'quote_terms' => 'Conditions de soumission',
    'default_quote_terms' => 'Conditions par défaut pour les soumissions',
    'default_invoice_terms' => 'Définir comme les conditions par défaut',
    'default_invoice_footer' => 'Définir le pied de facture par défaut',
    'quote_footer' => 'Pied de soumission par défaut',
    'free' => 'Gratuit',
    'quote_is_approved' => 'Approuvé avec succès',
    'apply_credit' => 'Appliquer le crédit',
    'system_settings' => 'Paramètres système',
    'archive_token' => 'Archiver le jeton',
    'archived_token' => 'Le jeton a été archivé avec succès',
    'archive_user' => 'Archiver l\'utilisateur',
    'archived_user' => 'L\'utilisateur a été archivé avec succès',
    'archive_account_gateway' => 'Supprimer la passerelle',
    'archived_account_gateway' => 'La passerelle a été archivée avec succès',
    'archive_recurring_invoice' => 'Archiver la facture récurrente',
    'archived_recurring_invoice' => 'La facture récurrente a été archivée avec succès',
    'delete_recurring_invoice' => 'Supprimer la facture récurrente',
    'deleted_recurring_invoice' => 'La facture récurrente a été supprimée avec succès',
    'restore_recurring_invoice' => 'Restaurer la facture récurrente',
    'restored_recurring_invoice' => 'La facture récurrente a été restaurée avec succès',
    'archive_recurring_quote' => 'Archiver une soumission récurrente',
    'archived_recurring_quote' => 'La soumission récurrente a été archivée avec succès',
    'delete_recurring_quote' => 'Supprimer la soumission récurrente',
    'deleted_recurring_quote' => 'La soumission récurrente a été supprimée avec succès',
    'restore_recurring_quote' => 'Restaurer une soumission récurrente',
    'restored_recurring_quote' => 'La soumission récurrente a été restaurée avec succès',
    'archived' => 'Archivé',
    'untitled_account' => 'Entreprise sans nom',
    'before' => 'Avant',
    'after' => 'Après',
    'reset_terms_help' => 'Remise à zéro',
    'reset_footer_help' => 'Remise à zéro',
    'export_data' => 'Exporter les données',
    'user' => 'Utilisateur',
    'country' => 'Pays',
    'include' => 'Inclus',
    'logo_too_large' => 'Votre logo est :size, pour de meilleures performances PDF, veuillez téléverser une image de moins de 200KB',
    'import_freshbooks' => 'Importer de FreshBooks',
    'import_data' => 'Importer les données',
    'source' => 'Source',
    'csv' => 'CSV',
    'client_file' => 'Fichier des clients',
    'invoice_file' => 'Fichier  des factures',
    'task_file' => 'Fichier des tâches',
    'no_mapper' => 'Aucun liens de champs valides pour ce fichier',
    'invalid_csv_header' => 'Entête CSV invalide',
    'client_portal' => 'Portail client',
    'admin' => 'Admin',
    'disabled' => 'Désactivé',
    'show_archived_users' => 'Afficher les utilisateurs archivés',
    'notes' => 'Notes',
    'invoice_will_create' => 'La facture sera créée',
    'invoices_will_create' => 'Les factures seront créées',
    'failed_to_import' => 'Cet enregistrement n\'a pu être importé',
    'publishable_key' => 'Clé publique',
    'secret_key' => 'Clé secrète',
    'missing_publishable_key' => 'Entrez votre lcé publique de Stripe pour une meilleur expérience de paiement',
    'email_design' => 'Modèle de courriel',
    'due_by' => 'Due pour :date',
    'enable_email_markup' => 'Autoriser le marquage',
    'enable_email_markup_help' => 'rendez le paiement plus facile à vos client en ajoutant à vos courriel, le marquage de schema.org.',
    'template_help_title' => 'Aide pour les modèles',
    'template_help_1' => 'Variables disponibles:',
    'email_design_id' => 'Style de courriel',
    'email_design_help' => 'Rendez vos courriels plus professionnels avec les mises en page HTML',
    'plain' => 'Ordinaire',
    'light' => 'Clair',
    'dark' => 'Foncé',
    'industry_help' => 'Pour des fins de comparaison entre des entreprises de même taille et du même secteur d\'activité.',
    'subdomain_help' => 'Définissez le sous-domaine ou affichez la facture sur votre site web.',
    'website_help' => 'Afficher la facture dans un iFrame sur votre site web',
    'invoice_number_help' => 'Spécifiez un préfixe ou utilisez un modèle personnalisé pour la création du numéro de facture.',
    'quote_number_help' => 'Spécifiez un préfixe ou utilisez un modèle personnalisé pour la création du numéro de soumission.',
    'custom_client_fields_helps' => 'Ajoute un champ lors de la création d\'un client et affiche, de façon optionnelle, le libellé et la valeur dans le PDF.',
    'custom_account_fields_helps' => 'Ajoutez un titre et une valeur à la section des informations de l\'entreprise dans le fichier PDF.',
    'custom_invoice_fields_helps' => 'Ajoute un champ lors de la création d\'une facture et affiche, de façon optionnelle, le libellé et la valeur dans le PDF.',
    'custom_invoice_charges_helps' => 'Ajoutez un champ personnalisé à la page de création/édition de facture pour inclure les frais aux sous-totaux de la facture.',
    'token_expired' => 'Le jeton de validation a expiré. Veuillez réessayer.',
    'invoice_link' => 'Lien de facture',
    'button_confirmation_message' => 'Cliquez pour confirmer votre courriel.',
    'confirm' => 'Confirmer',
    'email_preferences' => 'Préférences courriel',
    'created_invoices' => ':count factures ont été créées avec succès',
    'next_invoice_number' => 'Le prochain numéro de facture est :number.',
    'next_quote_number' => 'Le prochain numéro de soumission est :number.',
    'days_before' => 'jours avant le',
    'days_after' => 'jours après le',
    'field_due_date' => 'Échéance',
    'field_invoice_date' => 'date de la facture',
    'schedule' => 'Calendrier',
    'email_designs' => 'Modèles de courriel',
    'assigned_when_sent' => 'Assignée lors de l\'envoi',
    'white_label_purchase_link' => 'Achetez une licence sans marque',
    'expense' => 'Dépense',
    'expenses' => 'Dépenses',
    'new_expense' => 'Entrer une dépense',
    'enter_expense' => 'Nouvelle dépense',
    'vendors' => 'Fournisseurs',
    'new_vendor' => 'Nouveau fournisseur',
    'payment_terms_net' => 'Net',
    'vendor' => 'Fournisseur',
    'edit_vendor' => 'Éditer le fournisseur',
    'archive_vendor' => 'Archiver le fournisseur',
    'delete_vendor' => 'Supprimer le fournisseur',
    'view_vendor' => 'Voir le fournisseur',
    'deleted_expense' => 'La dépense a été supprimée avec succès',
    'archived_expense' => 'La dépense a été archivée avec succès',
    'deleted_expenses' => 'Les dépenses ont été supprimées avec succès',
    'archived_expenses' => 'Les dépenses ont été archivées avec succès',
    'expense_amount' => 'Montant de la dépense',
    'expense_balance' => 'Solde de la dépense',
    'expense_date' => 'Date de la dépense',
    'expense_should_be_invoiced' => 'Dépense facturée?',
    'public_notes' => 'Notes publiques',
    'invoice_amount' => 'Montant de la facture',
    'exchange_rate' => 'Taux de change',
    'yes' => 'Oui',
    'no' => 'Non',
    'should_be_invoiced' => 'Devrait être facturée',
    'view_expense' => 'Voir la dépense # :expense',
    'edit_expense' => 'Éditer la dépense',
    'archive_expense' => 'Archiver la dépense',
    'delete_expense' => 'Supprimer la dépense',
    'view_expense_num' => 'Dépense # :expense',
    'updated_expense' => 'La dépense a été mise à jour avec succès',
    'created_expense' => 'La dépense a été créée avec succès',
    'enter_expense' => 'Nouvelle dépense',
    'view' => 'Visualiser',
    'restore_expense' => 'Restaurer la dépense',
    'invoice_expense' => 'Facture de dépense',
    'expense_error_multiple_clients' => 'Les dépenses ne peuvent pas appartenir à plusieus clients',
    'expense_error_invoiced' => 'Ces dépenses ont déjà été facturées',
    'convert_currency' => 'Conversion de devise',
    'num_days' => 'Nombre de jours',
    'create_payment_term' => 'Nouveau délai de paiement',
    'edit_payment_terms' => 'Modifier les délais de paiement',
    'edit_payment_term' => 'Modifier le délai de paiement',
    'archive_payment_term' => 'Archiver le délai de paiement',
    'recurring_due_dates' => 'Dates d\'échéances des factures récurrentes',
    'recurring_due_date_help' => '<p>Définissez automatiquement une date d\'échéance pour la facture.</p>
    <p>Les factures de type mensuel ou annuel dont la date d\'échéance est définie le jour même ou le jour précédent de leur création seront dues pour le prochain mois. Les factures dont la date d\'échéance est définie le 29 ou le 30 des mois qui n\'ont pas ces jours seront dues le dernier jour de ce mois.</p>
    <p>Les factures de type hebdomadaire dont la date d\'échéance est définie le jour de la semaine de leur création seront dues pour la semaine suivante.</p>
    <p>par exemple:</p>
    <ul>
    <li>Aujourd\'hui, le 15 du mois, la date d\'échéance est le 1er du mois. La date d\'échéance devrait être définie le 1er du prochain mois.</li>
    <li>Aujourd\'hui, le 15 du mois, la date d\'échéance est le dernier jour du mois. La date d\'échéance sera le dernier de ce mois.</li>
    <li>Aujourd\'hui, le 15 du mois, la date d\'échéance est le 15 de ce mois. La date d\'échéance sera le 15 du <strong>prochain</strong> mois.</li>
    <li>Aujoud\'hui, vendredi, la date d\'échéance est le 1er vendredi suivant. La date d\'échéance sera le prochain vendredi et non aujourd\'hui.</li>
    </ul>',
    'due' => 'Du',
    'next_due_on' => 'Du le: :date',
    'use_client_terms' => 'Termes du client',
    'day_of_month' => ':ordinal jour du mois',
    'last_day_of_month' => 'Dernier jour du mois',
    'day_of_week_after' => ':ordinal :day après',
    'sunday' => 'Dimanche',
    'monday' => 'Lundi',
    'tuesday' => 'Mardi',
    'wednesday' => 'Mercredi',
    'thursday' => 'Jeudi',
    'friday' => 'Vendredi',
    'saturday' => 'Samedi',
    'header_font_id' => 'Police de l\'entête',
    'body_font_id' => 'Police du message',
    'color_font_help' => 'Note: la couleur principale et les polices sont aussi utilisées dans le portail client et dans les modèles de courriels personnalisés.',
    'live_preview' => 'PRÉVISUALISATION',
    'invalid_mail_config' => 'impossible d\'envoyer le courriel, veuillez vérifier vos paramètres courriel.',
    'invoice_message_button' => 'Pour voir la facture de :amount, cliquez sur le bouton ci-dessous.',
    'quote_message_button' => 'Pour voir la soumission de :amount, cliquez sur le bouton ci-dessous.',
    'payment_message_button' => 'Merci pour votre paiement de :amount.',
    'payment_type_direct_debit' => 'Prélèvement automatique',
    'bank_accounts' => 'Comptes bancaires',
    'add_bank_account' => 'Ajouter un compte bancaire',
    'setup_account' => 'Configurer le compte',
    'import_expenses' => 'Importer les dépenses',
    'bank_id' => 'Banque',
    'integration_type' => 'Type d\'intégration',
    'updated_bank_account' => 'Le compte bancaire a été mise à jour avec succès',
    'edit_bank_account' => 'éditer le compte bancaire',
    'archive_bank_account' => 'Archiver le compte bancaire',
    'archived_bank_account' => 'Le compte bancaire a été archivé avec succès',
    'created_bank_account' => 'Le compte bancaire a été créé avec succès',
    'validate_bank_account' => 'Valider le compte bancaire',
    'bank_password_help' => 'Note: votre mot de passe est transmis de façon sécuritaire et n\'est jamais enregistré sur nos serveurs.',
    'bank_password_warning' => 'Avertissement: votre mot de passe pourrait être transmis sans cryptage, pensez à activer HTTPS.',
    'username' => 'Nom d\'utilisateur',
    'account_number' => 'Numéro du compte',
    'account_name' => 'Nom du compte',
    'bank_account_error' => 'Impossible de récupérer les informations de compte, veuillez vérifier les informations entrées.',
    'status_approved' => 'Acceptée',
    'quote_settings' => 'Paramètres des soumissions',
    'auto_convert_quote' => 'Autoconversion',
    'auto_convert_quote_help' => 'Convertir automatiquement une soumission en facture lorsque le client l\'accepte.',
    'validate' => 'Valider',
    'info' => 'Info',
    'imported_expenses' => ':count_vendors fournisseur(s) et :count_expenses dépense(s) ont été créés avec succès',
    'iframe_url_help3' => 'Note: si vous pensez accepter le paiement par carte de crédit, Nous vous recommandons fortement d\'activer le HTTPS.',
    'expense_error_multiple_currencies' => 'La dépense ne peut pas utiliser des devises différentes.',
    'expense_error_mismatch_currencies' => 'La devise du client ne correspond par à la devise de la dépense.',
    'trello_roadmap' => 'Feuille de route Trello',
    'header_footer' => 'Entête/Pied de page',
    'first_page' => 'première page',
    'all_pages' => 'toutes les pages',
    'last_page' => 'dernière page',
    'all_pages_header' => 'Afficher l\'entête sur',
    'all_pages_footer' => 'Afficher le pied de page sur',
    'invoice_currency' => 'Devise de la facture',
    'enable_https' => 'Nous vous recommandons fortement d\'activer le HTTPS pour la réception de paiement par carte de crédit en ligne.',
    'quote_issued_to' => 'La soumission a été émise pour',
    'show_currency_code' => 'Code de devise',
    'free_year_message' => 'Votre compte a été mis à niveau gratuitement vers le Plan Pro pour une année.',
    'trial_message' => 'Vous allez bénéficier d\'un essai gratuit de 2 semaines au Plan Pro.',
    'trial_footer' => 'Vous avez encore :count jours pour votre essai gratuit Pro Plan, :link pour s\'inscrire.',
    'trial_footer_last_day' => 'C\'est le dernier jour de votre essai gratuit Pro Plan, :link pour s\'inscrire.',
    'trial_call_to_action' => 'Démarrez votre essai gratuit',
    'trial_success' => 'Le Plan Pro, version d\'essai gratuit pour 2 semaines a été activé avec succès',
    'overdue' => 'En souffrance',


    'white_label_text' => 'Achetez une licence sans marque d\'UN AN au coût de $:price pour retirer la marque de Invoice Ninja des factures et du portail client.',
    'user_email_footer' => 'Pour modifier vos paramètres de notification par courriel, veuillez visiter :link',
    'reset_password_footer' => 'Si vous n\'avez pas effectué de demande de réinitalisation de mot de passe veuillez contacter notre support : :email',
    'limit_users' => 'Désolé, ceci excédera la limite de :limit utilisateurs',
    'more_designs_self_host_header' => 'Obtenez 6 modèles de factures additionnels pour seulement $:price',
    'old_browser' => 'Veuillez utiliser un :link',
    'newer_browser' => 'navigateur plus récent',
    'white_label_custom_css' => ':link à $:price pour activer les styles personnalisés et supporter notre projet.',
    'bank_accounts_help' => 'Veuillez vous connecter à un compte bancaire pour importer automatiquement les dépenses et créer les fournisseurs. Supporte American Express et :link.',
    'us_banks' => '400+ banques US',

    'pro_plan_remove_logo' => ':link pour supprimer le logo Invoice Ninja en souscrivant au plan pro',
    'pro_plan_remove_logo_link' => 'Cliquez ici',
    'invitation_status_sent' => 'Envoyé',
    'invitation_status_opened' => 'Ouvert',
    'invitation_status_viewed' => 'Consulté',
    'email_error_inactive_client' => 'Aucun courriel ne peut être envoyé à un client inactif',
    'email_error_inactive_contact' => 'Aucun courriel ne peut être envoyé à un contact inactif',
    'email_error_inactive_invoice' => 'Aucun courriel ne peut être envoyé à une facture inactive',
    'email_error_inactive_proposal' => 'Les courriels ne peuvent être envoyés à des propositions inactives',
    'email_error_user_unregistered' => 'Veuillez vous créer un compte pour envoyer des courriels',
    'email_error_user_unconfirmed' => 'Veuillez confirmer votre compte pour pouvoir envoyer des courriels',
    'email_error_invalid_contact_email' => 'Ce courriel est invalide',

    'navigation' => 'Navigation',
    'list_invoices' => 'Liste des factures',
    'list_clients' => 'Liste des clients',
    'list_quotes' => 'Liste des soumissions',
    'list_tasks' => 'Liste des tâches',
    'list_expenses' => 'Liste des factures récurrentes',
    'list_recurring_invoices' => 'Liste des factures récurrentes',
    'list_payments' => 'Liste des paiements',
    'list_credits' => 'Liste des crédits',
    'tax_name' => 'Nom de la taxe',
    'report_settings' => 'Paramètres des rapports',
    'search_hotkey' => 'raccourci /',

    'new_user' => 'Nouvel utilisateur',
    'new_product' => 'Nouveau produit',
    'new_tax_rate' => 'Nouveau taux de taxe',
    'invoiced_amount' => 'Montant facturé',
    'invoice_item_fields' => 'Champs d\'items de facture',
    'custom_invoice_item_fields_help' => 'Ajoutez un champ lors de la création d\'une facture pour afficher le libellé et la valeur du champ sur le PDF.',
    'recurring_invoice_number' => 'Numéro récurrent',
    'recurring_invoice_number_prefix_help' => 'Spécifiez un préfixe au numéro de facture pour les factures récurrentes.',

    // Client Passwords
    'enable_portal_password' => 'Protéger les factures avec un mot de passe',
    'enable_portal_password_help' => 'Permet de spécifier un mot de passe pour chaque contact. Si un mot de passe est spécifié, le contact devra saisir ce mot de passe pour visualiser ses factures.',
    'send_portal_password' => 'Générer automatiquement',
    'send_portal_password_help' => 'Si aucun mot de passe n\'est spécifié, le client recevra un mot de passe autogénéré lors de l\'envoi de la première facture.',

    'expired' => 'Expiré',
    'invalid_card_number' => 'Le numéro de carte de crédit n\'est pas valide.',
    'invalid_expiry' => 'La date d\'expiration n\'est pas valide.',
    'invalid_cvv' => 'Le CVV n\'est pas valide.',
    'cost' => 'Coût',
    'create_invoice_for_sample' => 'Note: créez votre première facture pour la visualiser ici.',

    // User Permissions
    'owner' => 'Propriétaire',
    'administrator' => 'Administrateur',
    'administrator_help' => 'Permet à un utilisateur de gérer d\'autres utilisateurs, modifier les paramètres et tous les enregistrements.',
    'user_create_all' => 'Créer des clients, factures, etc.',
    'user_view_all' => 'Visualiser tous les clients, factures, etc.',
    'user_edit_all' => 'Éditer tous les clients, factures, etc.',
    'gateway_help_20' => ':link pour s\'inscrire à Sage Pay.',
    'gateway_help_21' => ':link pour s\'inscrire à Sage Pay.',
    'partial_due' => 'Montant partiel du',
    'restore_vendor' => 'Restaurer un fournisseur ',
    'restored_vendor' => 'Le fournisseur  a été restauré avec succès',
    'restored_expense' => 'La dépense a été restaurée avec succès',
    'permissions' => 'Permissions',
    'create_all_help' => 'Autoriser un utilisateur à créer et modifier ses enregistrements',
    'view_all_help' => 'Autoriser un utilisateur à visualiser des enregistrements d\'autres utilisateurs',
    'edit_all_help' => 'Autoriser un utilisateur à modifier des enregistrements d\'autres utilisateurs',
    'view_payment' => 'Visualiser un paiement',

    'january' => 'Janvier',
    'february' => 'Février',
    'march' => 'Mars',
    'april' => 'Avril',
    'may' => 'Mai',
    'june' => 'Juin',
    'july' => 'Juillet',
    'august' => 'Août',
    'september' => 'Septembre',
    'october' => 'Octobre',
    'november' => 'Novembre',
    'december' => 'Décembre',

    // Documents
    'documents_header' => 'Documents:',
    'email_documents_header' => 'Documents:',
    'email_documents_example_1' => 'Recu du widget.pdf',
    'email_documents_example_2' => 'Livraison finale.zip',
    'quote_documents' => 'Justificatifs de soumission',
    'invoice_documents' => 'Justificatifs de facturation',
    'expense_documents' => 'Justificatifs de dépense',
    'invoice_embed_documents' => 'Documents intégrés',
    'invoice_embed_documents_help' => 'Inclure les images jointes dans la facture.',
    'document_email_attachment' => 'Documents joints',
    'ubl_email_attachment' => 'Joindre un UBL',
    'download_documents' => 'Télécharger les documents (:size)',
    'documents_from_expenses' => 'Des dépenses:',
    'dropzone_default_message' => 'Glissez-déposez ou cliquez pour téléverser des fichiers',
    'dropzone_default_message_disabled' => 'Téléversements désactivés',
    'dropzone_fallback_message' => 'Votre navigateur ne supporte pas le glisser-déposer de documents pour le téléversement.',
    'dropzone_fallback_text' => 'Veuillez utiliser le formulaire ci-dessous pour téléverser vos fichiers de la veille façon.',
    'dropzone_file_too_big' => 'Le fichier est tros lourd ({{filesize}}MiB). Taille maximale: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Vous ne pouvez pas téléverser des fichiers de ce type.',
    'dropzone_response_error' => 'Le serveur a répondu avec le code {{statusCode}}.',
    'dropzone_cancel_upload' => 'Téléversement annulé',
    'dropzone_cancel_upload_confirmation' => 'Souhaitez-vous vraiment annuler ce téléversement?',
    'dropzone_remove_file' => 'Retirer le fichier',
    'documents' => 'Documents',
    'document_date' => 'Date du document',
    'document_size' => 'Taille',

    'enable_client_portal' => 'Portail client',
    'enable_client_portal_help' => 'Afficher/masquer le portail client.',
    'enable_client_portal_dashboard' => 'Tableau de bord',
    'enable_client_portal_dashboard_help' => 'Afficher/masquer la page du tableau de bord dans le portail client.',

    // Plans
    'account_management' => 'Gestion du compte',
    'plan_status' => 'État du plan',

    'plan_upgrade' => 'Mise à jour',
    'plan_change' => 'Changer de plan',
    'pending_change_to' => 'Changer pour',
    'plan_changes_to' => ':plan le :date',
    'plan_term_changes_to' => ':plan (:term) le :date',
    'cancel_plan_change' => 'Annuler',
    'plan' => 'Plan',
    'expires' => 'Expiration',
    'renews' => 'Renouvellement',
    'plan_expired' => 'Le plan :plan est expiré',
    'trial_expired' => 'L\'essai du plan :plan est terminé',
    'never' => 'Jamais',
    'plan_free' => 'Gratuit',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Autohébergé (sans marque)',
    'plan_free_self_hosted' => 'Autohébergé (gratuit)',
    'plan_trial' => 'Essai',
    'plan_term' => 'Terme',
    'plan_term_monthly' => 'Mensuel',
    'plan_term_yearly' => 'Annuel',
    'plan_term_month' => 'Mois',
    'plan_term_year' => 'Année',
    'plan_price_monthly' => '$:price/mois',
    'plan_price_yearly' => '$:price/année',
    'updated_plan' => 'Paramètres de mise à jour du plan',
    'plan_paid' => 'Terme depuis le',
    'plan_started' => 'Plan depuis le',
    'plan_expires' => 'Plan expire le',

    'white_label_button' => 'Sans marque',

    'pro_plan_year_description' => 'Abonnement à une année du plan Invoice Ninja Pro.',
    'pro_plan_month_description' => 'Abonnement à un mois du plan Invoice Ninja Pro.',
    'enterprise_plan_product' => 'Plan Enterprise',
    'enterprise_plan_year_description' => 'Abonnement à une année du plan Invoice Ninja Enterprise.',
    'enterprise_plan_month_description' => 'Abonnement à une année du plan Invoice Ninja Enterprise.',
    'plan_credit_product' => 'Crédit',
    'plan_credit_description' => 'Crédit inutilisé',
    'plan_pending_monthly' => 'Passer au plan mensuel le :date',
    'plan_refunded' => 'Un remboursement vous a été émis.',

    'live_preview' => 'PRÉVISUALISATION',
    'page_size' => 'Taille de page',
    'live_preview_disabled' => 'La prévisualisation en direct a été désactivée pour cette police',
    'invoice_number_padding' => 'Remplissage (padding)',
    'preview' => 'PRÉVISUALISATION',
    'list_vendors' => 'Liste des fournisseurs',
    'add_users_not_supported' => 'Mettre à jour vers le plan Enterprise plan pour ajouter des utilisateurs à votre compte.',
    'enterprise_plan_features' => 'Le Plan entreprise offre le support pour de multiple utilisateurs ainsi que l\'ajout de pièces jointes, :link pour voir la liste complète des fonctionnalités.',
    'return_to_app' => 'Retour à l\'app',


    // Payment updates
    'refund_payment' => 'Remboursement',
    'refund_max' => 'Max:',
    'refund' => 'Rembousement',
    'are_you_sure_refund' => 'Rembourser les paiements sélectionnés?',
    'status_pending' => 'En attente',
    'status_completed' => 'Terminée',
    'status_failed' => 'Échouée',
    'status_partially_refunded' => 'Remboursement partiel',
    'status_partially_refunded_amount' => ':amount remboursé',
    'status_refunded' => 'Remboursé',
    'status_voided' => 'Annulé',
    'refunded_payment' => 'Paiement remboursé',
    'activity_39' => ':user a annulé un paiement :payment de :payment_amount',
    'activity_40' => ':user a remboursé :adjustment d\'un paiement :payment de :payment_amount ',
    'card_expiration' => 'Exp:&nbsp:expire',

    'card_creditcardother' => 'Inconnu',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accepter les transferts de banques US',
    'stripe_ach_help' => 'Le support ACH doit aussi être activé dans :link.',
    'ach_disabled' => 'Une autre passerelle est déjà configurée pour le prélèvement automatique.',

    'plaid' => 'Plaid',
    'client_id' => 'ID du client',
    'secret' => 'Secret',
    'public_key' => 'Clé publique',
    'plaid_optional' => '(optionel)',
    'plaid_environment_help' => 'Lorsqu\'une clé d\'essai Stripe est émise, l\'environnement (tartan) de développement Plaid est utilisé.',
    'other_providers' => 'Autres fournisseurs',
    'country_not_supported' => 'Ce pays n\'est pas supporté',
    'invalid_routing_number' => 'Le numéro de routage n\'est pas valide',
    'invalid_account_number' => 'Le numéro de compte n\'est pas valide',
    'account_number_mismatch' => 'Les numéros de compte ne correspondent pas',
    'missing_account_holder_type' => 'Veuillez sélectionner le type de compte (personnel / entreprise)',
    'missing_account_holder_name' => 'Veuillez entrer le nom du détenteur du compte',
    'routing_number' => 'Numéro de routage',
    'confirm_account_number' => 'Veuillez confirmer le numéro de compte',
    'individual_account' => 'Compte personnel',
    'company_account' => 'Compte d\'entreprise',
    'account_holder_name' => 'Nom du détenteur',
    'add_account' => 'Ajouter un compte',
    'payment_methods' => 'Modes de paiement',
    'complete_verification' => 'Compléter la vérification',
    'verification_amount1' => 'Montant 1',
    'verification_amount2' => 'Montant 2',
    'payment_method_verified' => 'La vérification a été complétée avec succès',
    'verification_failed' => 'La vérification a échoué',
    'remove_payment_method' => 'Retirer le mode de paiement',
    'confirm_remove_payment_method' => 'Souhaitez-vous vraiment retirer ce mode de paiement?',
    'remove' => 'Retirer',
    'payment_method_removed' => 'Mode de paiement retiré',
    'bank_account_verification_help' => 'Nous avons fait deux dépôts dans votre compte avec la description "VERIFICATION". Ces dépôts prendront 1-2 jours ouvrables pour apparaître sur le relevé. Veuillez entrer les montants ci-dessous.',
    'bank_account_verification_next_steps' => 'Nous avons fait deux dépôts dans votre compte avec la description "VERIFICATION". Ces dépôts prendront 1-2 jours ouvrables pour apparaître sur votre relevé.
Lorsque les montant apparaîtront sur votre relevé, veuillez revenir sur cette page et cliquez sur "Compléter la vérification" à côté du compte.',
    'unknown_bank' => 'Banque inconnue',
    'ach_verification_delay_help' => 'Vous serez en mesure d\'utiliser le compte après avoir terminé la vérification.  La vérification prend habituellement 1-2 jours ouvrables.',
    'add_credit_card' => 'Ajouter une carte de crédit',
    'payment_method_added' => 'Ajouter un mode de paiement',
    'use_for_auto_bill' => 'Utiliser pour les factures automatiques',
    'used_for_auto_bill' => 'Mode de paiement de factures automatiques',
    'payment_method_set_as_default' => 'Configurer le mode de paiement des factures automatiques.',
    'activity_41' => 'Le paiement de :payment_amount a échoué (:payment)',
    'webhook_url' => 'URL Webhook',
    'stripe_webhook_help' => 'Vous devez :link.',
    'stripe_webhook_help_link_text' => 'ajouter cette URL comme une terminaison avec Stripe',
    'gocardless_webhook_help_link_text' => 'ajoute cette URL comme une terminaison dans GoCardless',
    'payment_method_error' => 'Une erreur s\'est produite en ajoutant votre méthode de paiement. Veuillez réessayer plus tard.',
    'notification_invoice_payment_failed_subject' => 'Le paiement a échoué pour la facture :invoice',
    'notification_invoice_payment_failed' => 'Un paiement fait par le client :client pour la facture :invoice à échoué.  Le paiement a été marqué comme échoué et :amount a été ajouté au solde du client.',
    'link_with_plaid' => 'Lier le compte instantanément avec Plaid',
    'link_manually' => 'Lier manuellement',
    'secured_by_plaid' => 'Sécurisé par Plaid',
    'plaid_linked_status' => 'Votre compte de banque à :bank',
    'add_payment_method' => 'Ajouter un mode de paiement',
    'account_holder_type' => 'Type de compte du détenteur',
    'ach_authorization' => 'J\'autorise :company à utiliser mon compte bancaire pour les paiements futurs et, si nécessaire, créditer électroniquement mon compte pour corriger d\'éventuels débits erronés. Je comprends que je peux annuler cette autorisation à tout moment en supprimant le mode de paiement ou en contactant :email.',
    'ach_authorization_required' => 'Vous devez consentir aux transactions ACH.',
    'off' => 'Fermé',
    'opt_in' => 'Activer',
    'opt_out' => 'Désactiver',
    'always' => 'Toujours',
    'opted_out' => 'Désactivé',
    'opted_in' => 'Activé',
    'manage_auto_bill' => 'Gérer les factures automatiques',
    'enabled' => 'Activé',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Activer les paiements PayPal via BrainTree',
    'braintree_paypal_disabled_help' => 'La passerelle PayPal traite les paiements PayPal',
    'braintree_paypal_help' => 'Vous devez aussi :link.',
    'braintree_paypal_help_link_text' => 'lier PayPal à votre compte BrainTree',
    'token_billing_braintree_paypal' => 'Sauvegarder les détails du paiement',
    'add_paypal_account' => 'Ajouter un compte PayPal',


    'no_payment_method_specified' => 'Aucun mode de paiement spécifié',
    'chart_type' => 'Type de graphique',
    'format' => 'Format',
    'import_ofx' => 'Importer OFX',
    'ofx_file' => 'Fichier OFX',
    'ofx_parse_failed' => 'Le traitement du fichier OFX a échoué',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'S\'enregistrer avec WePay',
    'use_another_provider' => 'Utiliser un autre fournisseur',
    'company_name' => 'Nom de l\'entreprise',
    'wepay_company_name_help' => 'Ceci apparaitra sur le relevé de carte de crédit du client',
    'wepay_description_help' => 'Le but de ce compte.',
    'wepay_tos_agree' => 'J\'accepte les :link.',
    'wepay_tos_link_text' => 'Conditions d\'utilisation de WePay',
    'resend_confirmation_email' => 'Renvoyer le courriel de confirmation',
    'manage_account' => 'Gérer votre compte',
    'action_required' => 'Action requise',
    'finish_setup' => 'Terminer la configuration',
    'created_wepay_confirmation_required' => 'Veuillez vérifier vos courriel et confirmer votre adresse courriel avec WePay.',
    'switch_to_wepay' => 'Changer pour WePay',
    'switch' => 'Changer',
    'restore_account_gateway' => 'Restaurer la passerelle de paiement',
    'restored_account_gateway' => 'La passerelle de paiement a été restaurée avec succès',
    'united_states' => 'États-Unis',
    'canada' => 'Canada',
    'accept_debit_cards' => 'Accepter les cartes de débit',
    'debit_cards' => 'Cartes de débit',

    'warn_start_date_changed' => 'La prochaine facture sera envoyée à la date spécifiée',
    'warn_start_date_changed_not_sent' => 'La prochaine facture sera créée à la date spécifiée.',
    'original_start_date' => 'Première date de départ',
    'new_start_date' => 'Nouvelle date de départ',
    'security' => 'Sécurité',
    'see_whats_new' => 'Voir les nouveautés dans la version v:version',
    'wait_for_upload' => 'Veuillez patienter pendant le téléversement du fichier',
    'upgrade_for_permissions' => 'Adhérez à notre Plan entreprise pour activer les permissions.',
    'enable_second_tax_rate' => 'Activer la gestion d\'un <b>second taux de taxe</b>',
    'payment_file' => 'Fichier de paiement',
    'expense_file' => 'Fichier de dépense',
    'product_file' => 'Fichier de produit',
    'import_products' => 'Importer des produits',
    'products_will_create' => 'produits seront créés',
    'product_key' => 'Produit',
    'created_products' => ':count produit(s) ont été crées / mis à jour avec succès',
    'export_help' => 'Utilisez JSON si vous prévoyez importer les données dans Invoice Ninja.<br/>Ceci inclut les clients, les produits, les factures, les soumissions et les paiements.',
    'selfhost_export_help' => 'Nous recommandons de faire un mysqldump pour effectuer une sauvegarde complète.',
    'JSON_file' => 'Fichier JSON',

    'view_dashboard' => 'Voir Tableau de bord',
    'client_session_expired' => 'Session expirée',
    'client_session_expired_message' => 'Votre session a expirée. Veuillez cliquer sur le lien dans votre courriel.',

    'auto_bill_notification' => 'Cette facture sera automatiquement facturée à votre :payment_method au dossier le :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'compte de banque',
    'auto_bill_payment_method_credit_card' => 'carte de crédit',
    'auto_bill_payment_method_paypal' => 'compte PayPal',
    'auto_bill_notification_placeholder' => 'Cette facture sera automatiquement facturée à votre carte de crédit inscrite au dossier à la date d\'échéance.',
    'payment_settings' => 'Paramètres de paiement',

    'on_send_date' => 'À la date d\'envoi',
    'on_due_date' => 'À la date d\'échéance',
    'auto_bill_ach_date_help' => 'ACH sera toujours facturé automatiquement à la date d\'échéance.',
    'warn_change_auto_bill' => 'Selon les règles de NACHA, les changements à cette facture pourrait prévenir l\'autofacturation de ACH.',

    'bank_account' => 'Compte de banque',
    'payment_processed_through_wepay' => 'Les paiements ACH seront traités avec WePay.',
    'wepay_payment_tos_agree' => 'J\'accepte les conditions d\'utilisation et la politique de confidentialité de WePay',
    'privacy_policy' => 'Politique de confidentialité',
    'wepay_payment_tos_agree_required' => 'Vous devez accepter les conditions d\'utilisation et la politique de confidentialité de WePay',
    'ach_email_prompt' => 'Veuillez entrer votre adresse courriel:',
    'verification_pending' => 'En attente de vérification',

    'update_font_cache' => 'Veuillez actualiser la page pour mettre à jour le cache de la police de caractères',
    'more_options' => 'Plus d\'options',
    'credit_card' => 'Carte de crédit',
    'bank_transfer' => 'Virement bancaire',
    'no_transaction_reference' => 'Nous n\'avons pas reçu de référence de transaction de paiement de la passerelle.',
    'use_bank_on_file' => 'Utiliser la banque inscrite au dossier',
    'auto_bill_email_message' => 'Cette facture sera automatiquement facturée à votre mode de paiement inscrit au dossier à la date d\'échéance.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Ajouté le :date',
    'failed_remove_payment_method' => 'La suppression du mode de paiement a échoué',
    'gateway_exists' => 'La passerelle existe déjà',
    'manual_entry' => 'Saisie manuelle',
    'start_of_week' => 'Premier jour de la semaine',

    // Frequencies
    'freq_inactive' => 'Inactif',
    'freq_daily' => 'Quotidienne',
    'freq_weekly' => 'Hebdomadaire',
    'freq_biweekly' => 'Bihebdomadaire',
    'freq_two_weeks' => 'Aux deux semaines',
    'freq_four_weeks' => 'Aux quatre semaines',
    'freq_monthly' => 'Mensuelle',
    'freq_three_months' => 'Trimestrielle',
    'freq_four_months' => '4 mois',
    'freq_six_months' => 'Semestrielle',
    'freq_annually' => 'Annuelle',
    'freq_two_years' => 'Deux ans',

    // Payment types
    'payment_type_Apply Credit' => 'Appliquer le crédit',
    'payment_type_Bank Transfer' => 'Virement bancaire',
    'payment_type_Cash' => 'Comptant',
    'payment_type_Debit' => 'Débit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover',
    'payment_type_Diners Card' => 'Diners Club',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Autre carte de crédit',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Chèque',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Débit direct',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Administration',
    'industry_Advertising' => 'Publicité',
    'industry_Aerospace' => 'Aérospatial',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automobile',
    'industry_Banking & Finance' => 'Finances',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Médiadiffusion',
    'industry_Business Services' => 'Services aux entreprises',
    'industry_Commodities & Chemicals' => 'Matières premières',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Électronique',
    'industry_Defense' => 'Défense',
    'industry_Energy' => 'Energie',
    'industry_Entertainment' => 'Divertissement',
    'industry_Government' => 'Gouvernement',
    'industry_Healthcare & Life Sciences' => 'Santé',
    'industry_Insurance' => 'Assurance',
    'industry_Manufacturing' => 'Industrie manufacturière',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Médias',
    'industry_Nonprofit & Higher Ed' => 'Organisme sans but lucratif',
    'industry_Pharmaceuticals' => 'Pharmaceutique',
    'industry_Professional Services & Consulting' => 'Services Professionnels et Conseil',
    'industry_Real Estate' => 'Immobilier',
    'industry_Restaurant & Catering' => 'Restauration',
    'industry_Retail & Wholesale' => 'Détail en gros',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Voyage',
    'industry_Other' => 'Autre',
    'industry_Photography' => 'Photographie',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albanie',
    'country_Antarctica' => 'Antartique',
    'country_Algeria' => 'Algérie',
    'country_American Samoa' => 'Samoa américaines',
    'country_Andorra' => 'Andorre',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua-et-Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentine',
    'country_Australia' => 'Australie',
    'country_Austria' => 'Autriche',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahreïn',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Arménie',
    'country_Barbados' => 'Barbade',
    'country_Belgium' => 'Belgique',
    'country_Bermuda' => 'Bermudes',
    'country_Bhutan' => 'Bhoutan',
    'country_Bolivia, Plurinational State of' => 'Bolivie',
    'country_Bosnia and Herzegovina' => 'Bosnie Herzégovine',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Île Bouvet',
    'country_Brazil' => 'Brésil',
    'country_Belize' => 'Bélize',
    'country_British Indian Ocean Territory' => 'Territoire britannique de l\'océan Indien',
    'country_Solomon Islands' => 'Iles Salomon',
    'country_Virgin Islands, British' => 'Îles Vierges britanniques',
    'country_Brunei Darussalam' => 'Brunei',
    'country_Bulgaria' => 'Bulgarie',
    'country_Myanmar' => 'Birmanie',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Biélorussie',
    'country_Cambodia' => 'Cambodge',
    'country_Cameroon' => 'Cameroun',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cap-Vert',
    'country_Cayman Islands' => 'Iles Cayman',
    'country_Central African Republic' => 'République Centrafricaine',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Tchad',
    'country_Chile' => 'Chili',
    'country_China' => 'Chine',
    'country_Taiwan, Province of China' => 'Taïwan',
    'country_Christmas Island' => 'Île Christmas',
    'country_Cocos (Keeling) Islands' => 'Îles Cocos (Keeling)',
    'country_Colombia' => 'Colombie',
    'country_Comoros' => 'Comores',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'République démocratique du Congo',
    'country_Cook Islands' => 'Îles Cook',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatie',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Chypre',
    'country_Czech Republic' => 'République tchèque',
    'country_Benin' => 'Bénin',
    'country_Denmark' => 'Danemark',
    'country_Dominica' => 'Dominique',
    'country_Dominican Republic' => 'République dominicaine',
    'country_Ecuador' => 'Équateur',
    'country_El Salvador' => 'Salvador',
    'country_Equatorial Guinea' => 'Guinée équatoriale',
    'country_Ethiopia' => 'Éthiopie',
    'country_Eritrea' => 'Érythrée',
    'country_Estonia' => 'Estonie',
    'country_Faroe Islands' => 'Îles Féroé',
    'country_Falkland Islands (Malvinas)' => 'Îles Malouines',
    'country_South Georgia and the South Sandwich Islands' => 'Géorgie du Sud-et-les Îles Sandwich du Sud',
    'country_Fiji' => 'Fidji',
    'country_Finland' => 'Finlande',
    'country_Åland Islands' => 'Åland',
    'country_France' => 'France',
    'country_French Guiana' => 'Guyane française',
    'country_French Polynesia' => 'Polynésie française',
    'country_French Southern Territories' => 'Terres australes et antarctiques françaises',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Géorgie',
    'country_Gambia' => 'Gambie',
    'country_Palestinian Territory, Occupied' => 'Territoires palestiniens occupés',
    'country_Germany' => 'Allemagne',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grèce',
    'country_Greenland' => 'Groenland',
    'country_Grenada' => 'Grenade',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinée',
    'country_Guyana' => 'Guyane',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Îles Heard-et-MacDonald',
    'country_Holy See (Vatican City State)' => 'Vatican',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hongrie',
    'country_Iceland' => 'Islande',
    'country_India' => 'Inde',
    'country_Indonesia' => 'Indonésie',
    'country_Iran, Islamic Republic of' => 'Iran',
    'country_Iraq' => 'Irak',
    'country_Ireland' => 'Irlande',
    'country_Israel' => 'Israël',
    'country_Italy' => 'Italie',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaique',
    'country_Japan' => 'Japon',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordanie',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Corée du Nord',
    'country_Korea, Republic of' => 'Corée du Sud',
    'country_Kuwait' => 'Koweit',
    'country_Kyrgyzstan' => 'Kirghizistan',
    'country_Lao People\'s Democratic Republic' => 'Laos',
    'country_Lebanon' => 'Liban',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Lettonie',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libye',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lituanie',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaisie',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malte',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritanie',
    'country_Mauritius' => 'Maurice',
    'country_Mexico' => 'Mexique',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolie',
    'country_Moldova, Republic of' => 'Moldavie',
    'country_Montenegro' => 'Monténégro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Maroc',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibie',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Népal',
    'country_Netherlands' => 'Pays-Bas',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Saint-Martin (partie Pays-Bas)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Pays-Bas caribéens',
    'country_New Caledonia' => 'Nouvelle-Calédonie',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Nouvelle-Zélande',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Île Norfolk',
    'country_Norway' => 'Norvège',
    'country_Northern Mariana Islands' => 'Îles Mariannes du Nord',
    'country_United States Minor Outlying Islands' => 'Îles mineures éloignées des États-Unis',
    'country_Micronesia, Federated States of' => 'Micronésie',
    'country_Marshall Islands' => 'Îles Marshall',
    'country_Palau' => 'Palaos',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papouasie-Nouvelle-Guinée',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Pérou',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Îles Pitcairn',
    'country_Poland' => 'Pologne',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinée-Bissau',
    'country_Timor-Leste' => 'Timor oriental',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'La Réunion',
    'country_Romania' => 'Roumanie',
    'country_Russian Federation' => 'Fédération Russe',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Sainte-Hélène, Ascension et Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint-Kitts-et-Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Sainte-Lucie',
    'country_Saint Martin (French part)' => 'Saint-Martin (partie française)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre et Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint-Vincent-et-les-Grenadines',
    'country_San Marino' => 'Saint-Marin',
    'country_Sao Tome and Principe' => 'Sao Tomé-et-Principe',
    'country_Saudi Arabia' => 'Arabie Saoudite',
    'country_Senegal' => 'Sénégal',
    'country_Serbia' => 'Serbie',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovaquie',
    'country_Viet Nam' => 'Viêt Nam',
    'country_Slovenia' => 'Slovénie',
    'country_Somalia' => 'Somalie',
    'country_South Africa' => 'Afrique du Sud',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Espagne',
    'country_South Sudan' => 'Soudan du Sud',
    'country_Sudan' => 'Soudan',
    'country_Western Sahara' => 'Sahara occidental',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard et Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Suède',
    'country_Switzerland' => 'Suisse',
    'country_Syrian Arab Republic' => 'Syrie',
    'country_Tajikistan' => 'Tadjikistan',
    'country_Thailand' => 'Thaïlande',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinité-et-Tobago',
    'country_United Arab Emirates' => 'Émirats arabes unis',
    'country_Tunisia' => 'Tunisie',
    'country_Turkey' => 'Turquie',
    'country_Turkmenistan' => 'Turkménistan',
    'country_Turks and Caicos Islands' => 'Îles Turques-et-Caïques',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Ouganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macédoine',
    'country_Egypt' => 'Égypte',
    'country_United Kingdom' => 'Royaume-Uni',
    'country_Guernsey' => 'Guersney',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Île de Man',
    'country_Tanzania, United Republic of' => 'Tanzanie',
    'country_United States' => 'États-Unis',
    'country_Virgin Islands, U.S.' => 'Îles Vierges des États-Unis',
    'country_Burkina Faso' => 'Burkina faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Ouzbékistan',
    'country_Venezuela, Bolivarian Republic of' => 'Vénézuela',
    'country_Wallis and Futuna' => 'Wallis et Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yémen',
    'country_Zambia' => 'Zambie',

    // Languages
    'lang_Brazilian Portuguese' => 'Portuguais - Brésil',
    'lang_Croatian' => 'Croate',
    'lang_Czech' => 'Tchèque',
    'lang_Danish' => 'Danois',
    'lang_Dutch' => 'Néerlandais',
    'lang_English' => 'Anglais',
    'lang_French' => 'Français',
    'lang_French - Canada' => 'Français - Canada',
    'lang_German' => 'Allemand',
    'lang_Italian' => 'Italien',
    'lang_Japanese' => 'Japonais',
    'lang_Lithuanian' => 'Lituanien',
    'lang_Norwegian' => 'Norvégien',
    'lang_Polish' => 'Polonais',
    'lang_Spanish' => 'Espagnol',
    'lang_Spanish - Spain' => 'Espagnol - Espagne',
    'lang_Swedish' => 'Suédois',
    'lang_Albanian' => 'Albanien',
    'lang_Greek' => 'Grec',
    'lang_English - United Kingdom' => 'Anglais - Royaume Uni',
    'lang_English - Australia' => 'Anglais - Australie',
    'lang_Slovenian' => 'Slovénien',
    'lang_Finnish' => 'Finlandais',
    'lang_Romanian' => 'Roumain',
    'lang_Turkish - Turkey' => 'Turc - Turquie',
    'lang_Portuguese - Brazilian' => 'Portugais - Brésil',
    'lang_Portuguese - Portugal' => 'Portugais - Portugal',
    'lang_Thai' => 'Baht thaïlandais',
    'lang_Macedonian' => 'Macédonien',
    'lang_Chinese - Taiwan' => 'Chinois - Taiwan',
    'lang_Serbian' => 'Serbe',
    'lang_Bulgarian' => 'Bulgare',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Administration',
    'industry_Advertising' => 'Publicité',
    'industry_Aerospace' => 'Aérospatial',
    'industry_Agriculture' => 'Agriculture',
    'industry_Automotive' => 'Automobile',
    'industry_Banking & Finance' => 'Finances',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Médiadiffusion',
    'industry_Business Services' => 'Services aux entreprises',
    'industry_Commodities & Chemicals' => 'Matières premières',
    'industry_Communications' => 'Communications',
    'industry_Computers & Hightech' => 'Électronique',
    'industry_Defense' => 'Défense',
    'industry_Energy' => 'Energie',
    'industry_Entertainment' => 'Divertissement',
    'industry_Government' => 'Gouvernement',
    'industry_Healthcare & Life Sciences' => 'Santé',
    'industry_Insurance' => 'Assurance',
    'industry_Manufacturing' => 'Industrie manufacturière',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Médias',
    'industry_Nonprofit & Higher Ed' => 'Organisme sans but lucratif',
    'industry_Pharmaceuticals' => 'Pharmaceutique',
    'industry_Professional Services & Consulting' => 'Services Professionnels et Conseil',
    'industry_Real Estate' => 'Immobilier',
    'industry_Retail & Wholesale' => 'Détail en gros',
    'industry_Sports' => 'Sports',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Voyage',
    'industry_Other' => 'Autre',
    'industry_Photography' => 'Photographie',

    'view_client_portal' => 'Voir le portail client',
    'view_portal' => 'Voir le portail',
    'vendor_contacts' => 'Contacts du fournisseur',
    'all' => 'Tous',
    'selected' => 'Sélectionnés',
    'category' => 'Catégorie',
    'categories' => 'Catégories',
    'new_expense_category' => 'Nouvelle catégorie de dépense',
    'edit_category' => 'Éditer la catégorie',
    'archive_expense_category' => 'Archiver la catégorie',
    'expense_categories' => 'Catégories de dépense',
    'list_expense_categories' => 'Liste des catégories de dépense',
    'updated_expense_category' => 'La catégorie de dépense a été mise à jour avec succès',
    'created_expense_category' => 'La catégorie de dépense a été créé avec succès',
    'archived_expense_category' => 'La catégorie de dépense a été archivée avec succès',
    'archived_expense_categories' => ':count catégories de dépense ont été archivées avec succès',
    'restore_expense_category' => 'Rétablir la catégorie de dépense',
    'restored_expense_category' => 'La catégorie de dépense a été rétablie avec succès',
    'apply_taxes' => 'Appliquer les taxes',
    'min_to_max_users' => ':min de :max utilisateurs',
    'max_users_reached' => 'Le nombre maximum d\'utilisateur a été atteint',
    'buy_now_buttons' => 'Boutons Achetez maintenant',
    'landing_page' => 'Page d\'accueil',
    'payment_type' => 'Type de paiement',
    'form' => 'Formulaire',
    'link' => 'Lien',
    'fields' => 'Champs',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Note: Le client et la facture sont créés même si la transaction n\'est pas complétée.',
    'buy_now_buttons_disabled' => 'Cette fonctionnalité requiert qu\'un produit soit créé et qu\'une passerelle de paiement soit configurée.',
    'enable_buy_now_buttons_help' => 'Activer les boutons Achetez maintenant',
    'changes_take_effect_immediately' => 'Note: Les changements s\'appliquent immédiatement',
    'wepay_account_description' => 'Passerelle de paiement pour Invoice Ninja',
    'payment_error_code' => 'Il y a eu une erreur lors du traitement de paiement [:code]. Veuillez réessayer.',
    'standard_fees_apply' => 'Frais: 2.9%/1.2% [Carte de crédit/Virement bancaire] + $0.30 par transaction réussie.',
    'limit_import_rows' => 'Les données nécessitent d\'être importées en lots de :count rangées ou moins.',
    'error_title' => 'Il y a eu une erreur',
    'error_contact_text' => 'Si vous avez besoin d\'aide, veuillez nous contacter à :mailaddress',
    'no_undo' => 'Avertissement: Ceci ne peut être annulé.',
    'no_contact_selected' => 'Veuillez sélectionner un contact',
    'no_client_selected' => 'Veuillez sélectionner un client',

    'gateway_config_error' => 'Cela pourrait aider de définir de nouveau mots de passe ou générer de nouvelles clés API.',
    'payment_type_on_file' => ':type inscrit au dossier',
    'invoice_for_client' => 'Facture :invoice pour :client',
    'intent_not_found' => 'Désolé, je ne comprend pas bien ce que vous souhaitez. ',
    'intent_not_supported' => 'Désolé, je ne peux pas faire cela.',
    'client_not_found' => 'Je n\'ai pu trouvé le client',
    'not_allowed' => 'Désolé, vous n\'avez pas les permissions requises',
    'bot_emailed_invoice' => 'La facture a été envoyée.',
    'bot_emailed_notify_viewed' => 'Recevez un courriel lorsqu\'elle sera vue.',
    'bot_emailed_notify_paid' => 'Recevez un courriel lorsqu\'elle sera payée.',
    'add_product_to_invoice' => 'Ajouter 1 :product',
    'not_authorized' => 'Vous n\'êtes pas autorisé',
    'bot_get_email' => 'Salut! (wave)<br/>Merci d\'essayer le Bot de Invoice Ninja.<br/>Envoie-moi l\'adresse courriel de ton compte pour commencer.',
    'bot_get_code' => 'Merci! Je vous ai envoyé un courriel avec votre code de sécurité.',
    'bot_welcome' => 'Ça y est, votre compte est maintenant vérifié.>br/>',
    'email_not_found' => 'Je n\'ai pas pu trouver un compte disponible pour :email',
    'invalid_code' => 'Le code n\'est pas valide',
    'security_code_email_subject' => 'Code de sécurité pour le Bot de Invoice Ninja',
    'security_code_email_line1' => 'Ceci est votre code de sécurité pour le Bot de Invoice Ninja.',
    'security_code_email_line2' => 'Note: il expirera dans 10 minutes.',
    'bot_help_message' => 'Je supporte actuellement:<br/>• Créer\mettre à jour\envoyer une facture<br/>• Lister les produits<br/>Par exemple:<br/><i>Facturer 2 billets à Simon, définir la date d\'échéance au prochain jeudi et l\'escompte à 10 %</i>',
    'list_products' => 'Liste des produits',

    'include_item_taxes_inline' => 'Inclure une <b>ligne de taxes dans la ligne total</b>',
    'created_quotes' => ':count soumission(s) ont été créées avec succès',
    'limited_gateways' => 'Note: Nous supportons une passerelle de carte de crédit par entreprise',

    'warning' => 'Avertissement',
    'self-update' => 'Mettre à jour',
    'update_invoiceninja_title' => 'Mettre à jour Invoice Ninja',
    'update_invoiceninja_warning' => 'Invoice Ninja crée une sauvegarde de votre base de données et de vos fichiers avant la mise à jour.',
    'update_invoiceninja_available' => 'Une nouvelle version de Invoice Ninja est disponible.',
    'update_invoiceninja_unavailable' => 'Aucune mise à jour de Invoice Ninja disponible.',
    'update_invoiceninja_instructions' => 'Veuillez installer la nouvelle version <strong>:version</strong> en cliquant sur le bouton <em>Mettre à jour</em> ci-dessous. Ensuite, vous serez redirigé vers le tableau de bord.',
    'update_invoiceninja_update_start' => 'Mettre à jour',
    'update_invoiceninja_download_start' => 'Télécharger :version',
    'create_new' => 'Créer',

    'toggle_navigation' => 'Basculer la navigation',
    'toggle_history' => 'Basculer l\'historique',
    'unassigned' => 'Non assigné',
    'task' => 'Tâche',
    'contact_name' => 'Nom du contact',
    'city_state_postal' => 'Ville/Prov/CP',
    'custom_field' => 'Champ personnalisé',
    'account_fields' => 'Champs pour entreprise',
    'facebook_and_twitter' => 'Facebook et Twitter',
    'facebook_and_twitter_help' => 'Suivez-nous pour nous soutenir notre projet',
    'reseller_text' => 'Note: La licence sans marque est réservée pour un usage personnel. Veuillez prendre contact avec nous à :email si vous souhaitez revendre l\'application.',
    'unnamed_client' => 'Client sans nom',

    'day' => 'Jour',
    'week' => 'Semaine',
    'month' => 'Mois',
    'inactive_logout' => 'Vous avez été déconnecté en raison de l\'inactivité.',
    'reports' => 'Rapports',
    'total_profit' => 'Total des profits',
    'total_expenses' => 'Dépenses',
    'quote_to' => 'Soumission pour',

    // Limits
    'limit' => 'Limite',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Aucune limite',
    'set_limits' => 'Définir les limites de :gateway_type',
    'enable_min' => 'Activer min',
    'enable_max' => 'Activer max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Cette facture ne rencontre pas les limites définies pour ce type de paiement.',

    'date_range' => 'Intervalle de dates',
    'raw' => 'Brut',
    'raw_html' => 'HTML brut',
    'update' => 'Mise à jour',
    'invoice_fields_help' => 'Cliquez et déplacez les champs pour modifier leur ordre et emplacement',
    'new_category' => 'Nouvelle catégorie',
    'restore_product' => 'Restaurer le produit',
    'blank' => 'Vide',
    'invoice_save_error' => 'Il y a eu une erreur lors de la sauvegarde de votre facture',
    'enable_recurring' => 'Activer la récurrence',
    'disable_recurring' => 'Désactiver la récurrence',
    'text' => 'Texte',
    'expense_will_create' => 'dépense sera créée',
    'expenses_will_create' => 'dépenses seront créée',
    'created_expenses' => ':count dépense(s) ont été créée(s) avec succès',

    'translate_app' => 'Aidez-nous à améliorer nos traductions avec :link',
    'expense_category' => 'Catégorie de dépense',

    'go_ninja_pro' => 'Devenez Ninja Pro',
    'go_enterprise' => 'Devenez Entreprise!',
    'upgrade_for_features' => 'Mise à jour pour plus de fonctionnalités',
    'pay_annually_discount' => 'Payez annuellement pour 10 mois + 2 gratuits',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'votrenom.invoiceninja.com',
    'pro_upgrade_feature2' => 'Personnalisez tous les aspects de votre facture',
    'enterprise_upgrade_feature1' => 'Définissez les permissions pour plusieurs utilisateurs',
    'enterprise_upgrade_feature2' => 'Ajoutez des fichiers joints aux factures et dépenses',
    'much_more' => 'Encore plus!',
    'all_pro_fetaures' => 'Plus toutes les fonctionnalités Pro!',

    'currency_symbol' => 'Symbole',
    'currency_code' => 'Code',

    'buy_license' => 'Acheter une licence',
    'apply_license' => 'Activer la licence',
    'submit' => 'Envoyer',
    'white_label_license_key' => 'Clé de la licence',
    'invalid_white_label_license' => 'La licence sans marque n\'est pas valide',
    'created_by' => 'Créé par :name',
    'modules' => 'Modules',
    'financial_year_start' => 'Premier mois de l\'année',
    'authentication' => 'Authentification',
    'checkbox' => 'Case à cocher',
    'invoice_signature' => 'Signature',
    'show_accept_invoice_terms' => 'Case à cocher pour les conditions de facturation',
    'show_accept_invoice_terms_help' => 'Requiert du client qu\'il confirme et accepte les conditions de facturation',
    'show_accept_quote_terms' => 'Case à cocher pour les conditions de soumssion',
    'show_accept_quote_terms_help' => 'Requiert du client qu\'il confirme et accepte les conditions de soumission',
    'require_invoice_signature' => 'Signature de facture',
    'require_invoice_signature_help' => 'Requiert une signature du client',
    'require_quote_signature' => 'Signature de soumission',
    'require_quote_signature_help' => 'Requiert une signature du client',
    'i_agree' => 'J\'accepte les conditions',
    'sign_here' => 'Veuillez signer ici:',
    'authorization' => 'Autorisation',
    'signed' => 'Signé',

    // BlueVine
    'bluevine_promo' => 'Obtenez des marges de crédit et d\'affacturages d\'affaires flexible en utilisant BlueVIne.',
    'bluevine_modal_label' => 'Inscrivez-vous avec BlueVine',
    'bluevine_modal_text' => '<h3>Financement rapide pour votre entreprise. Pas de paperasse.</h3>
<ul><li>Marges de crédit et affacturage d\'affaires flexibles.</li></ul>',
    'bluevine_create_account' => 'Créer un compte',
    'quote_types' => 'Obtenir une soumission pour',
    'invoice_factoring' => 'Affacturage',
    'line_of_credit' => 'Marge de crédit',
    'fico_score' => 'Votre pointage de crédit',
    'business_inception' => 'Date de création de l\'entreprise',
    'average_bank_balance' => 'Solde moyen de compte bancaire',
    'annual_revenue' => 'Revenu annuel',
    'desired_credit_limit_factoring' => 'Affacturage désiré',
    'desired_credit_limit_loc' => 'Marge de crédit désirée',
    'desired_credit_limit' => 'Limite de crédit désirée',
    'bluevine_credit_line_type_required' => 'Faites au moins un choix',
    'bluevine_field_required' => 'Ce champs est requis',
    'bluevine_unexpected_error' => 'Une erreur inattendue s\'est produite.',
    'bluevine_no_conditional_offer' => 'Vous devez fournir plus d\'information afin d\'obtenir une soumission. Veuillez cliquer ci-dessous.',
    'bluevine_invoice_factoring' => 'Affacturage',
    'bluevine_conditional_offer' => 'Offre conditionnelle',
    'bluevine_credit_line_amount' => 'Marge de crédit',
    'bluevine_advance_rate' => 'Taux de l\'accompte',
    'bluevine_weekly_discount_rate' => 'Taux de remise hebdomadaire',
    'bluevine_minimum_fee_rate' => 'Frais minimaux',
    'bluevine_line_of_credit' => 'Marge de crédit',
    'bluevine_interest_rate' => 'Taux d\'intérêt',
    'bluevine_weekly_draw_rate' => 'Taux hebdomadaire de retrait',
    'bluevine_continue' => 'Continuer vers BlueVine',
    'bluevine_completed' => 'Inscription complètée avec BlueVIne',

    'vendor_name' => 'Fournisseur',
    'entity_state' => 'Statut',
    'client_created_at' => 'Date de création',
    'postmark_error' => 'Il y a eu un problème en envoyant le courriel par Postmark: :link',
    'project' => 'Projet',
    'projects' => 'Projets',
    'new_project' => 'Nouveau projet',
    'edit_project' => 'Éditer le projet',
    'archive_project' => 'Archiver le projet',
    'list_projects' => 'Lister les projets',
    'updated_project' => 'Le projet a été mis à  jour avec succès',
    'created_project' => 'Le projet a été créé avec succès',
    'archived_project' => 'Le projet a été archivé avec succès',
    'archived_projects' => ':count projets ont été archivés avec succès',
    'restore_project' => 'Restaurer le projet',
    'restored_project' => 'Le projet a été restauré avec succès',
    'delete_project' => 'Supprimer le projet',
    'deleted_project' => 'Le projet a été supprimé avec succès',
    'deleted_projects' => ':count projets ont été supprimés avec succès',
    'delete_expense_category' => 'Supprimer la catégorie',
    'deleted_expense_category' => 'La catégorie a été supprimée avec succès',
    'delete_product' => 'Supprimer le produit',
    'deleted_product' => 'Le produit a été supprimé avec succès',
    'deleted_products' => ':count produits ont été supprimés avec succès',
    'restored_product' => 'Le produit a été restauré avec succès',
    'update_credit' => 'Mettre à jour un crédit',
    'updated_credit' => 'Le crédit a été mis à jour avec succès',
    'edit_credit' => 'Éditer le crédit',
    'realtime_preview' => 'Prévisualisation en temps réel',
    'realtime_preview_help' => 'Prévisualisation en temps réel de l\'actualisation PDF sur la page de facture lors de l\'édition.<br/>Désactivez cette option pour améliorer les performances lorsque vous éditez les factures.',
    'live_preview_help' => 'Affiche une prévisualisation PDF en temps réel sur la page d\'édition de facture.',
    'force_pdfjs_help' => 'Remplacer le lecteur PDF intégré dans :chrome_link et dans :firefox_link.<br/>Activer cette fonctionnalité si votre navigateur télécharge automatiquement les fichiers PDF.',
    'force_pdfjs' => 'Empêcher le téléchargement',
    'redirect_url' => 'URL de redirection',
    'redirect_url_help' => 'Veuillez spécifier une URL optionnelle de redirection après la saisi d\'un paiement.',
    'save_draft' => 'Sauvegarder le brouillon',
    'refunded_credit_payment' => 'Paiement de crédit remboursés',
    'keyboard_shortcuts' => 'Raccourcis clavier',
    'toggle_menu' => 'Basculer la navigation',
    'new_...' => 'Nouveau ...',
    'list_...' => 'Liste ...',
    'created_at' => 'Créé le',
    'contact_us' => 'Nous joindre',
    'user_guide' => 'Guide de l\'utilisateur',
    'promo_message' => 'Profitez de l\'offre avant le :expires et épargnez :amount sur la première année de notre plan Pro ou Entreprise.',
    'discount_message' => 'L\'offre de :amount expire le :expires',
    'mark_paid' => 'Marquer payée',
    'marked_sent_invoice' => 'La facture marquée a été envoyée avec succès',
    'marked_sent_invoices' => 'Les factures marquées ont été envoyées avec succès',
    'invoice_name' => 'Facture',
    'product_will_create' => 'produit sera créé',
    'contact_us_response' => 'Nous avons bien reçu votre message. Nous y répondrons dans les plus bref délais.. Merci !',
    'last_7_days' => '7 derniers jours',
    'last_30_days' => '30 derniers jours',
    'this_month' => 'Mois en cours',
    'last_month' => 'Mois dernier',
    'current_quarter' => 'Trimestre en cours',
    'last_quarter' => 'Dernier trimestre',
    'last_year' => 'Dernière année',
    'custom_range' => 'Personnalisé',
    'url' => 'URL',
    'debug' => 'Débogage',
    'https' => 'HTTPS',
    'require' => 'Obligatoire',
    'license_expiring' => 'Note: Votre licence va expirer dans :count jours, :link pour la renouveler.',
    'security_confirmation' => 'Votre adresse courriel a été confirmée.',
    'white_label_expired' => 'Votre licence sans marque a expiré. Merci de la renouveler pour soutenir notre projet.',
    'renew_license' => 'Renouveler la licence',
    'iphone_app_message' => 'Avez-vous penser télécharger notre :link',
    'iphone_app' => 'App iPhone',
    'android_app' => 'App Android',
    'logged_in' => 'Connecté',
    'switch_to_primary' => 'Veuillez basculer vers votre entreprise initiale (:name) pour gérer votre plan d\'abonnement.',
    'inclusive' => 'Inclusif',
    'exclusive' => 'Exclusif',
    'postal_city_state' => 'Ville/Province/Code postal',
    'phantomjs_help' => 'Dans certains cas, l\'application utilise :link_phantom pour générer le PDF. Installez :link_docs pour le générer localement.',
    'phantomjs_local' => 'Utilise PhantomJS local',
    'client_number' => 'Numéro de client',
    'client_number_help' => 'Spécifiez un préfixe ou utilisez un modèle personnalisé pour la création du numéro de client.',
    'next_client_number' => 'Le prochain numéro de client est :number.',
    'generated_numbers' => 'Nombres générés',
    'notes_reminder1' => 'Premier rappel',
    'notes_reminder2' => 'Deuxième rappel',
    'notes_reminder3' => 'Troisième rappel',
    'notes_reminder4' => 'Rappel',
    'bcc_email' => 'Courriel CCI',
    'tax_quote' => 'Taxe de soumission',
    'tax_invoice' => 'Taxe de facture',
    'emailed_invoices' => 'Les factures ont été envoyées par courriel avec succès',
    'emailed_quotes' => 'Les soumissions ont été envoyées par courriel avec succès',
    'website_url' => 'URL du site web',
    'domain' => 'Domaine',
    'domain_help' => 'Utilisé sur le portail du client lors de l\'envoi des courriels.',
    'domain_help_website' => 'Utilisé lors de l\'envoi des courriels.',
    'import_invoices' => 'Importer les factures',
    'new_report' => 'Nouveau rapport',
    'edit_report' => 'Éditer le rapport',
    'columns' => 'Colonnes',
    'filters' => 'Filtres',
    'sort_by' => 'Trié par',
    'draft' => 'Brouillon',
    'unpaid' => 'Impayé',
    'aging' => 'Impayés',
    'age' => 'Âge',
    'days' => 'Jours',
    'age_group_0' => '0 - 30 jours',
    'age_group_30' => '30 - 60 jours',
    'age_group_60' => '60 - 90 jours',
    'age_group_90' => '90 - 120 jours',
    'age_group_120' => '120+ jours',
    'invoice_details' => 'Détails de facture',
    'qty' => 'Quantité',
    'profit_and_loss' => 'Profit et perte',
    'revenue' => 'Revenu',
    'profit' => 'Profit',
    'group_when_sorted' => 'Trier par groupe',
    'group_dates_by' => 'Grouper les dates par',
    'year' => 'Année',
    'view_statement' => 'Visualiser le relevé',
    'statement' => 'Relevé',
    'statement_date' => 'Date du relevé',
    'mark_active' => 'Cocher actif',
    'send_automatically' => 'Envoyer automatiquement',
    'initial_email' => 'Courriel initial',
    'invoice_not_emailed' => 'Cette facture n\'a pas été envoyé par courriel.',
    'quote_not_emailed' => 'Cette soumission n\'a pas été envoyé par courriel.',
    'sent_by' => 'Envoyé par :user',
    'recipients' => 'destinataires',
    'save_as_default' => 'Sauvegarder comme défaut',
    'start_of_week_help' => 'Utilisé par les sélecteurs de <b>date</b>',
    'financial_year_start_help' => 'Utilisé par les sélecteurs d\'<b>écart de date</b>',
    'reports_help' => 'MAJ + Clic pour filtrer plusieurs colonnes. CRTL + Clic pour annuler le groupement.',
    'this_year' => 'Cette année',

    // Updated login screen
    'ninja_tagline' => 'Créer, envoyer et encaissez.',
    'login_or_existing' => 'Ou connectez-vous avec un compte connecté.',
    'sign_up_now' => 'Inscrivez-vous maintenant',
    'not_a_member_yet' => 'Pas encore membre?',
    'login_create_an_account' => 'Créer un compte',

    // New Client Portal styling
    'invoice_from' => 'Factures de:',
    'email_alias_message' => 'Chaque entreprise doit avoir une adresse courriel unique.
<br/>Vous pouvez utiliser un alias, ex. email+label@example.com',
    'full_name' => 'Nom complet',
    'month_year' => 'MOIS/ANNÉE',
    'valid_thru' => 'Valide\nthru',

    'product_fields' => 'Champs produit',
    'custom_product_fields_help' => 'Ajoute un champ lors de la création d\'un produit ou d\'une facture et affiche l\'étiquette et la valeur sur la visualisation PDF.',
    'freq_two_months' => 'Deux mois',
    'freq_yearly' => 'Annuellement',
    'profile' => 'Profil',
    'payment_type_help' => 'Définit le <b>type de paiement manuel<b/> par défaut.',
    'industry_Construction' => 'Construction',
    'your_statement' => 'Votre relevé',
    'statement_issued_to' => 'Relevé émis pour',
    'statement_to' => 'Relevé à',
    'customize_options' => 'Personnaliser les options',
    'created_payment_term' => 'Le délai de paiement a été cré avec succès',
    'updated_payment_term' => 'Le délai de paiement a été mis à jour avec succès',
    'archived_payment_term' => 'Le délai de paiement a été archivé avec succès',
    'resend_invite' => 'Renvoyer l\'invitation',
    'credit_created_by' => 'Le crédit a été créé par le paiement :transaction_reference',
    'created_payment_and_credit' => 'Le paiement et le crédit ont été créés avec succès',
    'created_payment_and_credit_emailed_client' => 'Le paiement et le crédit ont été créés et envoyés par courriel au client avec succès',
    'create_project' => 'Créer un projet',
    'create_vendor' => 'Créer un fournisseur',
    'create_expense_category' => 'Créer une catégorie',
    'pro_plan_reports' => ':link pour activer les rapports en joignant le Plan Pro',
    'mark_ready' => 'Marquer comme prêt',

    'limits' => 'Limites',
    'fees' => 'Frais',
    'fee' => 'Frais',
    'set_limits_fees' => 'Définit les limites/frais de :gateway_type ',
    'fees_tax_help' => 'Activer les taxes par article pour définir les taux de taxes.',
    'fees_sample' => 'Les frais pour une facture de :amount serait :total.',
    'discount_sample' => 'Le rabais pour une facture de :amount serait de :total.',
    'no_fees' => 'Aucun frais',
    'gateway_fees_disclaimer' => 'Avertissement: Toutes les passerelles de paiement ou provinces n\'autorisent pas l\'ajout de frais. Veuillez vous renseigner auprès des autorités compétentes.',
    'percent' => 'Pourcent',
    'location' => 'Endroit',
    'line_item' => 'Ligne d\'article',
    'surcharge' => 'surcharge',
    'location_first_surcharge' => 'Activer - Première surcharge',
    'location_second_surcharge' => 'Activer - Deuxième surcharge',
    'location_line_item' => 'Activer - Ligne d\'article',
    'online_payment_surcharge' => 'Surcharge de paiement en ligne',
    'gateway_fees' => 'Frais de passerelle',
    'fees_disabled' => 'Frais désactivés',
    'gateway_fees_help' => 'Ajoute automatiquement un paiement en ligne de surcharge/remise.',
    'gateway' => 'Passerelle',
    'gateway_fee_change_warning' => 'S\'il y a des factures impayées avec des frais, elles doivent être mises à jour manuellement.',
    'fees_surcharge_help' => 'Personnaliser surcharge :link.',
    'label_and_taxes' => 'Libellé et taxes',
    'billable' => 'Facturable',
    'logo_warning_too_large' => 'Le fichier image est trop gros.',
    'logo_warning_fileinfo' => 'Avertissement: L\'extension PHP fileinfo doit être activée pour utiliser les gifs',
    'logo_warning_invalid' => 'Il y a eu un problème avec le fichier image. Veuillez essayer avec un autre format.',

    'error_refresh_page' => 'Une erreur est survenue. Veuillez actualiser la page et essayer de nouveau.',
    'data' => 'Données',
    'imported_settings' => 'Les paramètres ont été inmportés avec succès',
    'reset_counter' => 'Remettre à zéro le compteur',
    'next_reset' => 'Prochaine remise à zéro',
    'reset_counter_help' => 'Remettre automatiquement à zéro les compteurs de facture et de soumission.',
    'auto_bill_failed' => 'La facturation automatique de :invoice_number a échouée.',
    'online_payment_discount' => 'Remise de paiement en ligne',
    'created_new_company' => 'La nouvelle entreprise a été créée avec succès',
    'fees_disabled_for_gateway' => 'Les frais sont désactivés pour cette passerelle.',
    'logout_and_delete' => 'Déconnexion/Suppression du compte',
    'tax_rate_type_help' => 'Lorsque sélectionné, les taux de taxes inclusifs ajustent le coût de l\'article de chaque ligne.<br/>Seulement les taux de taxes exclusifs peuvent être utilisé comme défaut.',
    'invoice_footer_help' => 'Utilisez $pageNumber et $pageCount pour afficher les informations de la page.',
    'credit_note' => 'Note de crédit',
    'credit_issued_to' => 'Crédit accordé à',
    'credit_to' => 'Crédit à',
    'your_credit' => 'Votre crédit',
    'credit_number' => 'Numéro de crédit',
    'create_credit_note' => 'Créer une note de crédit',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Erreur: Les tables de passerelle ont des ID incorrectes.',
    'purge_data' => 'Purger les données',
    'delete_data' => 'Supprimer les données',
    'purge_data_help' => 'Supprime définitivement toutes les données, mais garde les paramètres et le compte.',
    'cancel_account_help' => 'Supprime le compte et toutes les données et paramètres de façon définitive.',
    'purge_successful' => 'Toutes les données de l\'entreprise ont été purgées avec succès',
    'forbidden' => 'Vous n\'avez pas l\'autorisation',
    'purge_data_message' => 'Avertissement: Cette action est irréversible et va supprimer vos données de façon définitive.',
    'contact_phone' => 'Téléphone du contact',
    'contact_email' => 'Courriel du contact',
    'reply_to_email' => 'Courriel de réponse',
    'reply_to_email_help' => 'Spécifie une adresse courriel de réponse',
    'bcc_email_help' => 'Inclut de façon privée cette adresse avec les courriels du client.',
    'import_complete' => 'L\'importation a été complétée avec succès.',
    'confirm_account_to_import' => 'Veuillez confirmer votre compte pour l\'importation des données.',
    'import_started' => 'L\'importation est en cours. Vous recevrez un courriel lorsqu\'elle sera complétée.',
    'listening' => 'En écoute...',
    'microphone_help' => 'Dites "nouvelle facture pour [client]" ou "montre-moi les paiements archivés pour [client]"',
    'voice_commands' => 'Commandes vocales',
    'sample_commands' => 'Exemples de commandes',
    'voice_commands_feedback' => 'Nous travaillons activement à l\'amélioration de cette fonctionnalité. Si vous souhaitez l\'ajout d\'une commande sépcifique, veuillez nous contacter par courriel à :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Mandat poste',
    'archived_products' => ':count produits archivés avec succès',
    'recommend_on' => 'Il est recommandé d\'<b>activer</b> cette option.',
    'recommend_off' => 'Il est recommandé de <b>désactiver</b> cette option.',
    'notes_auto_billed' => 'Autofacturation',
    'surcharge_label' => 'Intitulé de surcharge',
    'contact_fields' => 'Champs de contact',
    'custom_contact_fields_help' => 'Ajoute un champ lors de la création d\'un contrat et affiche, de façon optionnelle, le libellé et la valeur dans le PDF.',
    'datatable_info' => ':start entrées sur :end',
    'credit_total' => 'Total du crédit',
    'mark_billable' => 'Marquer comme facturable',
    'billed' => 'Facturé',
    'company_variables' => 'Variables de la compagnie',
    'client_variables' => 'Variables du client',
    'invoice_variables' => 'Variables de facture',
    'navigation_variables' => 'Variables de navigation',
    'custom_variables' => 'Variables personnalisées',
    'invalid_file' => 'Type de fichier invalide',
    'add_documents_to_invoice' => 'Ajouter des documents aux factures',
    'mark_expense_paid' => 'Marquer comme payé',
    'white_label_license_error' => 'La validation de la licence n\'a pas fonctionné. Veuillez consulter storage/logs/laravel-error.log pour plus d\'information.',
    'plan_price' => 'Tarification',
    'wrong_confirmation' => 'Code de confirmation incorrect',
    'oauth_taken' => 'Ces comptes ont déjà été enregistrés',
    'emailed_payment' => 'Le paiement a été envoyé par courriel avec succès',
    'email_payment' => 'Courriel de paiement',
    'invoiceplane_import' => 'Utilisez ce :link pour importer vos données de InvoicePlane.',
    'duplicate_expense_warning' => 'Avertissement: Ce :link pourrait être un doublon',
    'expense_link' => 'dépense',
    'resume_task' => 'Poursuivre la tâche',
    'resumed_task' => 'La tâche a été reprise avec succès',
    'quote_design' => 'Design de soumission',
    'default_design' => 'Design standard',
    'custom_design1' => 'Design personnalisé 1',
    'custom_design2' => 'Design personnalisé 2',
    'custom_design3' => 'Design personnalisé 3',
    'empty' => 'Vide',
    'load_design' => 'Charger le design',
    'accepted_card_logos' => 'Logos des cartes acceptées',
    'phantomjs_local_and_cloud' => 'Utilise PhantomJS local et en second, phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Clé Analytics',
    'analytics_key_help' => 'Suivre les paiements en utilisant :link',
    'start_date_required' => 'La date de début est requise',
    'application_settings' => 'Paramètres de l\'application',
    'database_connection' => 'Connexion base de données',
    'driver' => 'Pilote',
    'host' => 'Hôte',
    'database' => 'Base de données',
    'test_connection' => 'Test de connexion',
    'from_name' => 'Nom de',
    'from_address' => 'Adresse de',
    'port' => 'Port',
    'encryption' => 'Cryptage',
    'mailgun_domain' => 'Domaine Mailgun',
    'mailgun_private_key' => 'Clé privée Mailgun',
    'send_test_email' => 'Envoyer un courriel test',
    'select_label' => 'Sélectionnez le libellé',
    'label' => 'Libellé',
    'service' => 'Service',
    'update_payment_details' => 'Mettre à jour les infos de paiement',
    'updated_payment_details' => 'Les infos de paiement ont été mis à jour avec succès',
    'update_credit_card' => 'Mettre à jour la carte de crédit',
    'recurring_expenses' => 'Dépenses récurrentes',
    'recurring_expense' => 'Dépense récurrente',
    'new_recurring_expense' => 'Nouvelle dépense récurrente',
    'edit_recurring_expense' => 'Éditer la dépense récurrente',
    'archive_recurring_expense' => 'Archiver la dépense récurrente',
    'list_recurring_expense' => 'Lister les dépenses récurrentes',
    'updated_recurring_expense' => 'La dépense récurrente a été mise à jour avec succès',
    'created_recurring_expense' => 'La dépense récurrente a été créée avec succès',
    'archived_recurring_expense' => 'La dépense récurrente a été archivée avec succès',
    'restore_recurring_expense' => 'Restaurer la dépense récurrente',
    'restored_recurring_expense' => 'La dépense récurrente a été restaurée avec succès',
    'delete_recurring_expense' => 'Supprimer la dépense récurrente',
    'deleted_recurring_expense' => 'Le projet a été supprimé avec succès',
    'view_recurring_expense' => 'Visualiser la dépense récurrente',
    'taxes_and_fees' => 'Taxes et frais',
    'import_failed' => 'L\'importation a échoué',
    'recurring_prefix' => 'Préfixe récurrent',
    'options' => 'Options',
    'credit_number_help' => 'Spécifiez un préfixe ou utilisez un modèle personnalisé pour définir de façon dynamique le numéro de crédit pour les factures négatives.',
    'next_credit_number' => 'Le prochain numéro de crédit est :number.',
    'padding_help' => 'Le nombre de zéro précédant le numéro.',
    'import_warning_invalid_date' => 'Avertissement: Le format de la date n\'est pas valide.',
    'product_notes' => 'Notes du produit',
    'app_version' => 'Version de l\'app',
    'ofx_version' => 'Version OFX',
    'gateway_help_23' => ':link pour obtenir vos clés API Stripe.',
    'error_app_key_set_to_default' => 'Erreur: APP_KEY est défini avec une valeur par défaut. Pour la mettre à jour, faite une sauvegarde de votre base de données et exécutez <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Appliquer des frais de retard',
    'late_fee_amount' => 'Frais de retard',
    'late_fee_percent' => 'Pourcentage de frais de retard',
    'late_fee_added' => 'Les frais de retard ont été ajouté le :date',
    'download_invoice' => 'Télécharger la facture',
    'download_quote' => 'Télécharger la soumission',
    'invoices_are_attached' => 'Les factures PDF sont jointes.',
    'downloaded_invoice' => 'Un courriel sera envoyé avec la facture PDF',
    'downloaded_quote' => 'Un courriel sera envoyé avec la soumission PDF',
    'downloaded_invoices' => 'Un courriel sera envoyé avec les factures PDF',
    'downloaded_quotes' => 'Un courriel sera envoyé avec les soumissions PDF',
    'clone_expense' => 'Dupliquer la dépense',
    'default_documents' => 'Documents par défaut',
    'send_email_to_client' => 'Envoyer un courriel au client',
    'refund_subject' => 'Remboursement réussi',
    'refund_body' => 'Vous avez été remboursé du montant de :amount pour la facture :invoice_number.',

    'currency_us_dollar' => 'Dollar américain',
    'currency_british_pound' => 'Livre sterling anglaise',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'Rand sud-africain',
    'currency_danish_krone' => 'Couronne danoise',
    'currency_israeli_shekel' => 'Shekel Israélien',
    'currency_swedish_krona' => 'Couronne suédoise',
    'currency_kenyan_shilling' => 'Shilling kényan',
    'currency_canadian_dollar' => 'Dollar canadien',
    'currency_philippine_peso' => 'Peso philippin',
    'currency_indian_rupee' => 'Roupie indienne',
    'currency_australian_dollar' => 'Dollar australien',
    'currency_singapore_dollar' => 'Dollar de Singapour',
    'currency_norske_kroner' => 'Couronne norvégienne',
    'currency_new_zealand_dollar' => 'Dollar néo-zélandais',
    'currency_vietnamese_dong' => 'Dong vietnamien',
    'currency_swiss_franc' => 'Franc suisse',
    'currency_guatemalan_quetzal' => 'Quetzal guatémaltèque',
    'currency_malaysian_ringgit' => 'Ringgit malaisien',
    'currency_brazilian_real' => 'Réal brésilien',
    'currency_thai_baht' => 'Baht thaïlandais',
    'currency_nigerian_naira' => 'Naira nigérian',
    'currency_argentine_peso' => 'Peso argentin',
    'currency_bangladeshi_taka' => 'Taka bengali',
    'currency_united_arab_emirates_dirham' => 'Dirham des Émirats arabes unis',
    'currency_hong_kong_dollar' => 'Dollar de Hong Kong',
    'currency_indonesian_rupiah' => 'Roupie indonésienne',
    'currency_mexican_peso' => 'Peso mexicain',
    'currency_egyptian_pound' => 'Livre égyptienne',
    'currency_colombian_peso' => 'peso colombien',
    'currency_west_african_franc' => 'Franc ouest-africain',
    'currency_chinese_renminbi' => 'Renminbi chinois',
    'currency_rwandan_franc' => 'Franc rwandais',
    'currency_tanzanian_shilling' => 'Shilling tanzanien',
    'currency_netherlands_antillean_guilder' => 'Guilder des Antilles néerlandaises',
    'currency_trinidad_and_tobago_dollar' => 'Dollar de Trinité-et-Tobago',
    'currency_east_caribbean_dollar' => 'Dollar des Caraïbes orientales',
    'currency_ghanaian_cedi' => 'Cedi ghanéen',
    'currency_bulgarian_lev' => 'Lev bulgare',
    'currency_aruban_florin' => 'Florin arubais',
    'currency_turkish_lira' => 'Livre turque',
    'currency_romanian_new_leu' => 'Leu roumain',
    'currency_croatian_kuna' => 'Kuna croate',
    'currency_saudi_riyal' => 'Riyal saoudien',
    'currency_japanese_yen' => 'Yen japonais',
    'currency_maldivian_rufiyaa' => 'Rufiyaa maldivien',
    'currency_costa_rican_colon' => 'Colón costaricien',
    'currency_pakistani_rupee' => 'Roupie pakistanaise',
    'currency_polish_zloty' => 'Złoty polonaise',
    'currency_sri_lankan_rupee' => 'Roupie srilankaise',
    'currency_czech_koruna' => 'Couronne tchèque',
    'currency_uruguayan_peso' => 'Peso uruguayen',
    'currency_namibian_dollar' => 'Dollar namibien',
    'currency_tunisian_dinar' => 'Dinar tunisien',
    'currency_russian_ruble' => 'Rouble russe',
    'currency_mozambican_metical' => 'Metical Mozambicain',
    'currency_omani_rial' => 'Rial omanais',
    'currency_ukrainian_hryvnia' => 'Hryvnia ukrénien',
    'currency_macanese_pataca' => 'Pataca  Macanais',
    'currency_taiwan_new_dollar' => 'Nouveau dollar de Taïwan',
    'currency_dominican_peso' => 'Peso dominicain',
    'currency_chilean_peso' => 'Peso chilien',
    'currency_icelandic_krona' => 'Couronne islandaise',
    'currency_papua_new_guinean_kina' => 'Kina papouasien néo-guinéen',
    'currency_jordanian_dinar' => 'Dinar jordanien',
    'currency_myanmar_kyat' => 'Kyat birman',
    'currency_peruvian_sol' => 'Nouveau sol péruvien',
    'currency_botswana_pula' => 'Pula botswanais',
    'currency_hungarian_forint' => 'Forint hongrois',
    'currency_ugandan_shilling' => 'Shilling ougandais',
    'currency_barbadian_dollar' => 'Dollar barbadien',
    'currency_brunei_dollar' => 'Dollar de Brunei',
    'currency_georgian_lari' => 'Lari géorgien',
    'currency_qatari_riyal' => 'Riyal qatarien',
    'currency_honduran_lempira' => 'Lempira hondurien',
    'currency_surinamese_dollar' => 'Dollar du Suriname',
    'currency_bahraini_dinar' => 'Dinar bahreïni',
    'currency_venezuelan_bolivars' => 'Bolivar vénézuélien',
    'currency_south_korean_won' => 'Won sud-coréen',
    'currency_moroccan_dirham' => 'Dirham marocain',
    'currency_jamaican_dollar' => 'Dollar jamaicain',
    'currency_angolan_kwanza' => 'Kwanza angolais',
    'currency_haitian_gourde' => 'Gourde haïtienne',
    'currency_zambian_kwacha' => 'Kwacha zambien',
    'currency_nepalese_rupee' => 'Roupie népalaise',
    'currency_cfp_franc' => 'Franc Pacifique',
    'currency_mauritian_rupee' => 'Roupie mauricienne',
    'currency_cape_verdean_escudo' => 'Escudo cap-verdien',
    'currency_kuwaiti_dinar' => 'Dinar koweïtien',
    'currency_algerian_dinar' => 'Dinar algérien',
    'currency_macedonian_denar' => 'Denar macédonien',
    'currency_fijian_dollar' => 'Dollar de Fidji',
    'currency_bolivian_boliviano' => 'Boliviano',
    'currency_albanian_lek' => 'Lek albanais',
    'currency_serbian_dinar' => 'Dinar serbe',
    'currency_lebanese_pound' => 'Livre libanaise',
    'currency_armenian_dram' => 'Dram arménien',
    'currency_azerbaijan_manat' => 'Manat azerbaïdjanais',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Mark convertible de Bosnie-Herzégovine',
    'currency_belarusian_ruble' => 'Rouble biélorusse',
    'currency_moldovan_leu' => 'Leu moldave',
    'currency_kazakhstani_tenge' => 'Tenge kazakh',
    'currency_gibraltar_pound' => 'Livre de Gibraltar',

    'review_app_help' => 'Nous espérons que votre utilisation de cette application vous est agréable.<br/>Un commentaire de votre part serait grandement apprécié!',
    'writing_a_review' => 'rédiger un commentaire',

    'use_english_version' => 'Veuillez vous assurer d\'utiliser la version anglaise des fichiers.<br/>Les entêtes de colonnes sont utilisées pour correspondre aux champs.',
    'tax1' => 'Première taxe',
    'tax2' => 'Deuxième taxe',
    'fee_help' => 'Les frais de la passerelle sont les coûts facturés pour l\'accès aux réseaux financiers qui traitent le traitement des paiements en ligne.',
    'format_export' => 'Format d\'exportation',
    'custom1' => 'Personnalisation 1',
    'custom2' => 'Personnalisation 2',
    'contact_first_name' => 'Prénom du contact',
    'contact_last_name' => 'Nom du contact',
    'contact_custom1' => 'Personnalisation 1 du contact',
    'contact_custom2' => 'Personnalisation 2 du contact',
    'currency' => 'Devise',
    'ofx_help' => 'Pour résoudre un problème, consultez les commentaires sur :ofxhome_link  et testez avec :ofxget_link.',
    'comments' => 'commentaires',

    'item_product' => 'Produit de l\'article',
    'item_notes' => 'Notes de l\'article',
    'item_cost' => 'Coût de l\'article',
    'item_quantity' => 'Quantité de l\'article',
    'item_tax_rate' => 'Taux de taxe de l\'article',
    'item_tax_name' => 'Nom de taxe de l\'article',
    'item_tax1' => 'Taxe 1 de l\'article',
    'item_tax2' => 'Taxe 2 de l\'article',

    'delete_company' => 'Supprimer l\'entreprise',
    'delete_company_help' => 'Cette action supprime définitivement l\'entreprise et toutes les données associées.',
    'delete_company_message' => 'Avertissement: Cette entreprise sera définitivement supprimée. ',

    'applied_discount' => 'Le coupon a été appliqué, le prix du plan est réduit de :discount%.',
    'applied_free_year' => 'Le coupon a été appliqué, votre compte est maintenant au plan Pro pour une année.',

    'contact_us_help' => 'Si vous devez rapporter une erreur, veuillez inclure toute information pertinente que vous trouverez dans les fichiers logs à storage/logs/laravel-error.log',
    'include_errors' => 'Inclure les erreurs',
    'include_errors_help' => 'Inclure le :link de storage/logs/laravel-error.log',
    'recent_errors' => 'erreurs récentes',
    'customer' => 'Client',
    'customers' => 'Clients',
    'created_customer' => 'Le client a été créé avec succès',
    'created_customers' => ':count clients ont été créés avec succès',

    'purge_details' => 'Les données de votre entreprise (:account) ont été supprimées avec succès.',
    'deleted_company' => 'L\'entreprise a été supprimée avec succès',
    'deleted_account' => 'Le compte a été supprimé avec succès',
    'deleted_company_details' => 'Votre entreprise (:account) a été supprimée avec succès.',
    'deleted_account_details' => 'Votre compte (:account) a été supprimé avec succès.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Débit direct',
    'enable_alipay' => 'Accepter Alipay',
    'enable_sofort' => 'Accepter les tranferts de banques EU',
    'stripe_alipay_help' => 'Ces passerelles doivent aussi être activées dans :link.',
    'calendar' => 'Calendrier',
    'pro_plan_calendar' => ':link pour activer le calendrier en joignant le Plan Pro',

    'what_are_you_working_on' => 'Sur quoi travaillez-vous ?',
    'time_tracker' => 'Minuteur',
    'refresh' => 'Actualiser',
    'filter_sort' => 'Filtrer/trier',
    'no_description' => 'Aucune description',
    'time_tracker_login' => 'Connexion au minuteur',
    'save_or_discard' => 'Sauvegarder ou annuler les changements',
    'discard_changes' => 'Annuler les changements',
    'tasks_not_enabled' => 'Les tâches ne sont pas activées.',
    'started_task' => 'La tâche a démaré avec succès',
    'create_client' => 'Créer un client',

    'download_desktop_app' => 'Télécharger l\'app. de bureau',
    'download_iphone_app' => 'Télécharger l\'app. iPhone',
    'download_android_app' => 'Télécharger l\'app. Android',
    'time_tracker_mobile_help' => 'Double-tapez une tâche pour la sélectionner',
    'stopped' => 'Arrêtée',
    'ascending' => 'Ascendant',
    'descending' => 'Descendant',
    'sort_field' => 'Trié par',
    'sort_direction' => 'Direction',
    'discard' => 'Annuler',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'min',
    'time_hr' => 'h',
    'time_hrs' => 'hrs',
    'clear' => 'Remettre à zéro',
    'warn_payment_gateway' => 'Note: pour accepter un paiement en ligne, il faut une passerelle de paiements, :link pour en ajouter une.',
    'task_rate' => 'Taux  de tâche',
    'task_rate_help' => 'Défini le taux par défaut pour les tâches facturées.',
    'past_due' => 'En souffrance',
    'document' => 'Justificatifs',
    'invoice_or_expense' => 'Facture/Dépense',
    'invoice_pdfs' => 'Facture en PDF',
    'enable_sepa' => 'Accepter SEPA',
    'enable_bitcoin' => 'Accepter Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'En fournissant votre IBAN et en confirmant ce paiement, vous autorisez :company et Stripe, notre fournisseur de service de paiement, à envoyer une demande à votre institution bancaire pour un prélèvement sur votre compte conformément à ces instructions. Vous pouvez demander un remboursement à votre institution bancaire selon les conditions de votre entente avec institution bancaire. Une demande de remboursement doit être faite dans les 8 semaines à partir du jour de la transaction.',
    'recover_license' => 'Récupérer la licence',
    'purchase' => 'Acheter',
    'recover' => 'Récupérer',
    'apply' => 'Appliquer',
    'recover_white_label_header' => 'Récupérer la licence Sans marque',
    'apply_white_label_header' => 'Appliquer la licence Sans marque',
    'videos' => 'Vidéos',
    'video' => 'Vidéo',
    'return_to_invoice' => 'Retour à la facture',
    'gateway_help_13' => 'Pour utiliser ITN, laissez le champ de la clé PDT vide.',
    'partial_due_date' => 'Date d\'échéance paiement partiel',
    'task_fields' => 'Champs de tâche',
    'product_fields_help' => 'Glisser et déposer les champs pour changer l\'ordre',
    'custom_value1' => 'Valeur par défaut',
    'custom_value2' => 'Valeur par défaut',
    'enable_two_factor' => 'Authentification à deux facteurs',
    'enable_two_factor_help' => 'Utilisez votre téléphone pour confirmer votre identité lors de la connexion',
    'two_factor_setup' => 'Configuration de l\'authentification à deux facteurs',
    'two_factor_setup_help' => 'Scannez le code barre avec une :link app compatible.',
    'one_time_password' => 'Mot de passe à usage unique',
    'set_phone_for_two_factor' => 'Indiquez votre numéro de cellulaire pour activer.',
    'enabled_two_factor' => 'Vous avez activé authentification à deux facteurs avec succès.',
    'add_product' => 'Ajouter un produit',
    'email_will_be_sent_on' => 'Note: le courriel sera envoyé le :date.',
    'invoice_product' => 'Produit de facture',
    'self_host_login' => 'Nom d\'utilisateur auto-hébergement',
    'set_self_hoat_url' => 'URL auto-hébergement',
    'local_storage_required' => 'Erreur: le stockage local n\'est pas accessible.',
    'your_password_reset_link' => 'Remise à zéro votre mot de passe',
    'subdomain_taken' => 'Ce sous-domaine est déjà utilisé',
    'client_login' => 'Connexion client',
    'converted_amount' => 'Montant converti',
    'default' => 'Par défaut',
    'shipping_address' => 'Adresse de livraison',
    'bllling_address' => 'Adresse de facturation',
    'billing_address1' => 'Rue de facturation',
    'billing_address2' => 'App. de facturation',
    'billing_city' => 'Ville de facturation',
    'billing_state' => 'Province de facturation',
    'billing_postal_code' => 'Code postal de facturation',
    'billing_country' => 'Pays de facturation',
    'shipping_address1' => 'Rue de livraison',
    'shipping_address2' => 'App. de livraison',
    'shipping_city' => 'Ville de livraison',
    'shipping_state' => 'Province de livraison',
    'shipping_postal_code' => 'Code postal de livraison',
    'shipping_country' => 'Pays de livraison',
    'classify' => 'Classer',
    'show_shipping_address_help' => 'Le client doit fournir une adresse de livraison',
    'ship_to_billing_address' => 'Livrer à l\'adresse de facturation',
    'delivery_note' => 'Note de livraison',
    'show_tasks_in_portal' => 'Afficher les tâches dans le portail client',
    'cancel_schedule' => 'Annuler la planification',
    'scheduled_report' => 'Rapport planifié',
    'scheduled_report_help' => 'Envoyer le rapport :report au :format à :email',
    'created_scheduled_report' => 'Le rapport est planifié avec succès',
    'deleted_scheduled_report' => 'Le rapport planifié a été annulé avec succès',
    'scheduled_report_attached' => 'Votre rapport planifié :type est joint.',
    'scheduled_report_error' => 'La création du rapport planifié a échoué',
    'invalid_one_time_password' => 'Mot de passe unique invalide',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accepter Apple Pay et payer avec Google',
    'requires_subdomain' => 'Ce type de paiement nécessite un :link.',
    'subdomain_is_set' => 'ce sous-domaine est défini',
    'verification_file' => 'Fichier de vérification',
    'verification_file_missing' => 'Le fichier de vérification est nécessaire pour accepter les paiements.',
    'apple_pay_domain' => 'Utiliser <code>:domain</code> pour le domaine dans :link.',
    'apple_pay_not_supported' => 'Désolé, Appel/Google Pay n\'est pas supporté par votre navigateur',
    'optional_payment_methods' => 'Modes de paiement optionnels',
    'add_subscription' => 'Ajouter un abonnement',
    'target_url' => 'Cible',
    'target_url_help' => 'Lorsque l\'événement sélectionné advient, l\'app va l\'envoyer à l\'URL spécifiée.',
    'event' => 'Événement',
    'subscription_event_1' => 'Client créé',
    'subscription_event_2' => 'Facture créée',
    'subscription_event_3' => 'Soumission créée',
    'subscription_event_4' => 'Paiement créé',
    'subscription_event_5' => 'Fournisseur créé',
    'subscription_event_6' => 'Soumission mise à jour',
    'subscription_event_7' => 'Soumission supprimée',
    'subscription_event_8' => 'Facture mise à jour',
    'subscription_event_9' => 'Facture supprimée',
    'subscription_event_10' => 'Client mis à jour',
    'subscription_event_11' => 'Client supprimé',
    'subscription_event_12' => 'Paiement supprimé',
    'subscription_event_13' => 'Fournisseur mis à jour',
    'subscription_event_14' => 'Fournisseur supprimé',
    'subscription_event_15' => 'Dépense créée',
    'subscription_event_16' => 'Dépense mise à jour',
    'subscription_event_17' => 'Dépense supprimée',
    'subscription_event_18' => 'Tâche créée',
    'subscription_event_19' => 'Tâche mise à jour',
    'subscription_event_20' => 'Tâche supprimée',
    'subscription_event_21' => 'Soumission approuvée',
    'subscriptions' => 'Abonnements',
    'updated_subscription' => 'Abonnement mis à jour avec succès',
    'created_subscription' => 'Abonnement créé avec succès',
    'edit_subscription' => 'Éditer l\'abonnement',
    'archive_subscription' => 'Archiver l\'abonnement',
    'archived_subscription' => 'Abonnement archivé avec succès',
    'project_error_multiple_clients' => 'Les projets ne peuvent pas être associés à plus d\'un client',
    'invoice_project' => 'Facturer le projet',
    'module_recurring_invoice' => 'Factures récurrentes',
    'module_credit' => 'Crédits',
    'module_quote' => 'Soumission et propositions',
    'module_task' => 'Tâches et projets',
    'module_expense' => 'Dépenses et fournisseurs',
    'module_ticket' => 'Billets',
    'reminders' => 'Rappels',
    'send_client_reminders' => 'Envoyer des rappels par courriel',
    'can_view_tasks' => 'Les tâches sont visibles sur le portail',
    'is_not_sent_reminders' => 'Les rappels ne sont pas envoyés',
    'promotion_footer' => 'Votre promotion va arriver à échéance bientôt, :link pour mettre à jour.',
    'unable_to_delete_primary' => 'Note: vous devez supprimer toutes les entreprises liées avant de supprimer cette entreprise.',
    'please_register' => 'Veuillez vous inscrire',
    'processing_request' => 'Requête en cours',
    'mcrypt_warning' => 'Avertissement: Mcrypt est obsolète, exécutez :command popur mettre à jour le chiffrement.',
    'edit_times' => 'Éditer les temps',
    'inclusive_taxes_help' => 'Inclure les <b>taxes dans le coût</b>',
    'inclusive_taxes_notice' => 'Ce paramètre ne peut pas être changé lorsqu\'une facture a été créée.',
    'inclusive_taxes_warning' => 'Avertissement: les factures existantes devront être sauvegardées à nouveau',
    'copy_shipping' => 'Copier livraison',
    'copy_billing' => 'Copier facturation',
    'quote_has_expired' => 'La soumission est expirée. Veuillez contacter le commerçant.',
    'empty_table_footer' => '0 entrées sur 0',
    'do_not_trust' => 'Ne pas ce souvenir de cet appaeil',
    'trust_for_30_days' => 'Faire confiance pour 30 jours',
    'trust_forever' => 'Toujours faire confiance',
    'kanban' => 'Kanban',
    'backlog' => 'En retard',
    'ready_to_do' => 'Prêt à exécuter',
    'in_progress' => 'En cours',
    'add_status' => 'Ajouter un statut',
    'archive_status' => 'Archiver le statut',
    'new_status' => 'Nouveau statut',
    'convert_products' => 'Convertir les produits',
    'convert_products_help' => 'Convertir automatiquement le prix des produits dans la devise du client',
    'improve_client_portal_link' => 'Définit un sous-domaine pour raccourcir le lie du portail client.',
    'budgeted_hours' => 'Heures budgétées',
    'progress' => 'Avancement',
    'view_project' => 'Visualiser le projet',
    'summary' => 'Sommaire',
    'endless_reminder' => 'Rappel perpétuel',
    'signature_on_invoice_help' => 'Ajoutez le code suivant pour afficher la signature du client sur le PDF.',
    'signature_on_pdf' => 'Afficher sur le PDF',
    'signature_on_pdf_help' => 'Afficher la signature du client sur la facture/soumission PDF.',
    'expired_white_label' => 'La licence sans marque a expirée',
    'return_to_login' => 'Retour à la connexion',
    'convert_products_tip' => 'Note: ajouter un :link intitulé ":name" pour voir le taux de change.',
    'amount_greater_than_balance' => 'Le montant est plus grand que le solde de la facture. Un crédit sera créé avec le montant restant.',
    'custom_fields_tip' => 'Utilisez <code>Étiquette|Option1,Option2</code> pour afficher une boîte de sélection.',
    'client_information' => 'Information du client',
    'updated_client_details' => 'Les informations du client ont été mises à jour avec succès',
    'auto' => 'Auto',
    'tax_amount' => 'Montant de taxe',
    'tax_paid' => 'Taxe payée',
    'none' => 'Aucun',
    'proposal_message_button' => 'Pour visualiser votre proposition pour :amount, cliquez le bouton ci-dessous.',
    'proposal' => 'Proposition',
    'proposals' => 'Propositions',
    'list_proposals' => 'Liste des propositions',
    'new_proposal' => 'Nouvelle proposition',
    'edit_proposal' => 'Éditer la proposition',
    'archive_proposal' => 'Archiver la proposition',
    'delete_proposal' => 'Supprimer la proposition',
    'created_proposal' => 'La proposition a été créée avec succès',
    'updated_proposal' => 'La proposition a été mise à jour avec succès',
    'archived_proposal' => 'La proposition a été archivée avec succès',
    'deleted_proposal' => 'La proposition a été archivée avec succès',
    'archived_proposals' => ':count propositions ont été archivées avec succès',
    'deleted_proposals' => ':count propositions ont été archivées avec succès',
    'restored_proposal' => 'La proposition a été restaurée avec succès',
    'restore_proposal' => 'Restaurer la proposition',
    'snippet' => 'Fragment',
    'snippets' => 'Fragments',
    'proposal_snippet' => 'Fragment',
    'proposal_snippets' => 'Fragments',
    'new_proposal_snippet' => 'Nouveau fragment',
    'edit_proposal_snippet' => 'Éditer le fragment',
    'archive_proposal_snippet' => 'Archiver le frament',
    'delete_proposal_snippet' => 'Supprimer le fragment',
    'created_proposal_snippet' => 'Le fragment a été créé avec succès',
    'updated_proposal_snippet' => 'Le fragment a été mis à jour avec succès',
    'archived_proposal_snippet' => 'Le fragment a été archivé avec succès',
    'deleted_proposal_snippet' => 'Le fragment a été archivé avec succès',
    'archived_proposal_snippets' => ':count fragments ont été archivés avec succès',
    'deleted_proposal_snippets' => ':count fragments ont été archivés avec succès',
    'restored_proposal_snippet' => 'Le fragment  a été restauré avec succès',
    'restore_proposal_snippet' => 'Restaurer le fragment',
    'template' => 'Modèle',
    'templates' => 'Modèles',
    'proposal_template' => 'Modèle',
    'proposal_templates' => 'Modèles',
    'new_proposal_template' => 'Nouveau modèle',
    'edit_proposal_template' => 'Éditer le modèle',
    'archive_proposal_template' => 'Archiver le modèle',
    'delete_proposal_template' => 'Supprimer le modèle',
    'created_proposal_template' => 'Le modèle a été créé avec succès',
    'updated_proposal_template' => 'Le modèle a été mis à jour avec succès',
    'archived_proposal_template' => 'Le modèle a été archivé avec succès',
    'deleted_proposal_template' => 'Le modèle a été archivé avec succès',
    'archived_proposal_templates' => ':count modèles ont été archivés avec succès',
    'deleted_proposal_templates' => ':count modèles ont été archivés avec succès',
    'restored_proposal_template' => 'Le modèle a été restauré avec succès',
    'restore_proposal_template' => 'Restaurer le modèle',
    'proposal_category' => 'Catégorie',
    'proposal_categories' => 'Catégories',
    'new_proposal_category' => 'Nouvelle catégorie',
    'edit_proposal_category' => 'Éditer la catégorie',
    'archive_proposal_category' => 'Archiver la catégorie',
    'delete_proposal_category' => 'Supprimer la catégorie',
    'created_proposal_category' => 'La catégorie a été créée avec succès',
    'updated_proposal_category' => 'La catégorie a été mise à jour avec succès',
    'archived_proposal_category' => 'La catégorie a été archivée avec succès',
    'deleted_proposal_category' => 'La catégorie a été archivée avec succès',
    'archived_proposal_categories' => ':count catégories ont été archivées avec succès',
    'deleted_proposal_categories' => ':count catégories ont été archivées avec succès',
    'restored_proposal_category' => 'La catégorie a été restaurée',
    'restore_proposal_category' => 'Restaurer la catégorie',
    'delete_status' => 'État de suppression',
    'standard' => 'Standard',
    'icon' => 'Icône',
    'proposal_not_found' => 'La proposition demandée n\'est pas accessible',
    'create_proposal_category' => 'Créer une catégorie',
    'clone_proposal_template' => 'Cloner un modèle',
    'proposal_email' => 'Courriel de proposition',
    'proposal_subject' => 'Nouvelle proposition :number pour :account',
    'proposal_message' => 'Pour visualiser votre proposition de :amount, suivez le lien ci-dessous.',
    'emailed_proposal' => 'La proposition a été envoyée par courriel avec succès',
    'load_template' => 'Charger le modèle',
    'no_assets' => 'Aucune image, glisser-déposer pour la téléverser',
    'add_image' => 'Ajouter une image',
    'select_image' => 'Sélectionner une image',
    'upgrade_to_upload_images' => 'Passer au plan Entreprise pour téléverser des images',
    'delete_image' => 'Supprimer une image',
    'delete_image_help' => 'Avertissement: la suppression de cette image va la supprimer de toutes les propositions.',
    'amount_variable_help' => 'Note: le champ $amount de la facture utilisera le champ partiel/dépôt. Il utilisera le solde de la facture, si spécifié autrement.',
    'taxes_are_included_help' => 'Note : Les taxes inclusives ont été activées.',
    'taxes_are_not_included_help' => 'Note : Les taxes inclusives n\'ont pas été activées.',
    'change_requires_purge' => 'Modifier ce paramètre requière de :link les données du compte.',
    'purging' => 'Purge en cours',
    'warning_local_refund' => 'Le remboursement sera enregistré dans l\'application, mais NE SERA PAS traité par la passerelle de paiement.',
    'email_address_changed' => 'L\'adresse courriel a été modifiée',
    'email_address_changed_message' => 'L\'adresse courriel associée à votre compte a été modifiée de :old_email à :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'L\'exportation vers ZIP requiert l\'extension GMP',
    'email_history' => 'Historique des courriels',
    'loading' => 'Chargement',
    'no_messages_found' => 'Aucun message',
    'processing' => 'En cours',
    'reactivate' => 'Réactiver',
    'reactivated_email' => 'L\'adresse courriel a été réactivée',
    'emails' => 'Courriels',
    'opened' => 'Ouverts',
    'bounced' => 'Rejetés',
    'total_sent' => 'Total envoyés',
    'total_opened' => 'Total ouverts',
    'total_bounced' => 'Total rejetés',
    'total_spam' => 'Total spams',
    'platforms' => 'Plateformes',
    'email_clients' => 'Gestionnaires de courriels',
    'mobile' => 'Mobile',
    'desktop' => 'Fixe',
    'webmail' => 'Webmail',
    'group' => 'Groupe',
    'subgroup' => 'Sous-groupe',
    'unset' => 'Désactivation',
    'received_new_payment' => 'Vous avez reçu un nouveau paiement !',
    'slack_webhook_help' => 'Recevoir les notifications de paiement en utilisant :link.',
    'slack_incoming_webhooks' => 'Webhooks web entrants de Slack',
    'accept' => 'Accepter',
    'accepted_terms' => 'Les plus récentes conditions d\'utilisation ont été acceptées avec succès',
    'invalid_url' => 'URL invalide',
    'workflow_settings' => 'Paramètres de flux de travail',
    'auto_email_invoice' => 'Envoi automatique',
    'auto_email_invoice_help' => 'Envoi automatiquement les factures récurrentes lorsqu\'elles sont créées.',
    'auto_archive_invoice' => 'Autoarchivage',
    'auto_archive_invoice_help' => 'Archive automatiquement les soumissions lorsqu\'elles sont converties.',
    'auto_archive_quote' => 'Autoarchivage',
    'auto_archive_quote_help' => 'Archive automatiquement les soumissions lorsqu\'elles sont converties.',
    'require_approve_quote' => 'Approbation de soumission requise',
    'require_approve_quote_help' => 'Soumissions approuvées par le client requise.',
    'allow_approve_expired_quote' => 'Autoriser l\'approbation de soumissions expirées',
    'allow_approve_expired_quote_help' => 'Autoriser les clients à approuver les soumissions expirées',
    'invoice_workflow' => 'Flux de facturation',
    'quote_workflow' => 'Flux de soumission',
    'client_must_be_active' => 'Erreur : le client doit être actif',
    'purge_client' => 'Purger client',
    'purged_client' => 'Le client a été purgé avec succès',
    'purge_client_warning' => 'Tous les enregistrements (factures, tâches, dépenses, documents, etc...) seront aussi supprimés.',
    'clone_product' => 'Cloner le produit',
    'item_details' => 'Détails de l\'article',
    'send_item_details_help' => 'Envoyer les détails de l\'article à la passerelle de paiement.',
    'view_proposal' => 'Voir la proposition',
    'view_in_portal' => 'Voir dans le portail',
    'cookie_message' => 'Ce site web utilise des témoins pour vous offrir la meilleure expérience sur notre site web.',
    'got_it' => 'J\'ai compris !',
    'vendor_will_create' => 'fournisseur sera créé',
    'vendors_will_create' => 'fournisseurs seront créés',
    'created_vendors' => ':count fournisseur(s) ont été créé(s) avec succès',
    'import_vendors' => 'Importer des fournisseurs',
    'company' => 'Entreprise',
    'client_field' => 'Champ Client',
    'contact_field' => 'Champ Contact',
    'product_field' => 'Champ Produit',
    'task_field' => 'Champ Tâche',
    'project_field' => 'Champ Projet',
    'expense_field' => 'Champ Dépense',
    'vendor_field' => 'Champ Fournisseur',
    'company_field' => 'Champ Entreprise',
    'invoice_field' => 'Champ Facture',
    'invoice_surcharge' => 'Surcharge de facture',
    'custom_task_fields_help' => 'Ajouter un champ lors de la création d\'une tâche.',
    'custom_project_fields_help' => 'Ajouter un champ lors de la création d\'un projet.',
    'custom_expense_fields_help' => 'Ajouter un champ lors de la création d\'une dépense.',
    'custom_vendor_fields_help' => 'Ajouter un champ lors de la création d\'un fournisseur.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Facture impayée',
    'paid_invoice' => 'Facture payée',
    'unapproved_quote' => 'Soumission non approuvée',
    'unapproved_proposal' => 'Proposition non approuvée',
    'autofills_city_state' => 'Autoremplissage ville/prov',
    'no_match_found' => 'Aucun résultat',
    'password_strength' => 'Force du mot de passe',
    'strength_weak' => 'Faible',
    'strength_good' => 'Bon',
    'strength_strong' => 'Fort',
    'mark' => 'Marquer',
    'updated_task_status' => 'Le statut de la tâche a été mis à jour avec succès',
    'background_image' => 'Image de fond',
    'background_image_help' => 'Utilisé ce :link pour gérer vos images. Nous recommandons l\'utilisation d\'un petit fichier.',
    'proposal_editor' => 'éditeur de proposition',
    'background' => 'Fond',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Article de frais de passerelle',
    'gateway_fee_description' => 'Surcharge de frais de passerelle',
    'gateway_fee_discount_description' => 'Remise de frais de passerelle',
    'show_payments' => 'Afficher les paiements',
    'show_aging' => 'Afficher les impayés',
    'reference' => 'Référence',
    'amount_paid' => 'Montant payé',
    'send_notifications_for' => 'Envoyer des notifications pour',
    'all_invoices' => 'Toutes les factures',
    'my_invoices' => 'Mes factures',
    'payment_reference' => 'Référence de paiement',
    'maximum' => 'Maximum',
    'sort' => 'Trier',
    'refresh_complete' => 'Actualisation complétée',
    'please_enter_your_email' => 'Veuillez saisir votre courriel',
    'please_enter_your_password' => 'Veuillez saisir votre mot de passe',
    'please_enter_your_url' => 'Veuillez saisir votre URL',
    'please_enter_a_product_key' => 'Veuillez saisir la clé de produit',
    'an_error_occurred' => 'Il y a eu une erreur',
    'overview' => 'Survol',
    'copied_to_clipboard' => ':value a été copié au presse-papier',
    'error' => 'Erreur',
    'could_not_launch' => 'Lancement impossible',
    'additional' => 'Additionnel',
    'ok' => 'Ok',
    'email_is_invalid' => 'Le courriel est invalide',
    'items' => 'Articles',
    'partial_deposit' => 'Partiel/dépôt',
    'add_item' => 'Ajouter un article',
    'total_amount' => 'Montant total',
    'pdf' => 'PDF',
    'invoice_status_id' => 'État de la facture',
    'click_plus_to_add_item' => 'Cliquez + pour ajouter un article',
    'count_selected' => ':count sélectionnés',
    'dismiss' => 'Annuler',
    'please_select_a_date' => 'Veuillez saisir une date',
    'please_select_a_client' => 'Veuillez sélectionner un client',
    'language' => 'Langue',
    'updated_at' => 'Mis à jour',
    'please_enter_an_invoice_number' => 'Veuillez saisir un numéro de facture',
    'please_enter_a_quote_number' => 'Veuillez saisir un numéro de soumission',
    'clients_invoices' => 'Factures de :client\'s',
    'viewed' => 'Vue',
    'approved' => 'Approuvée',
    'invoice_status_1' => 'Brouillon',
    'invoice_status_2' => 'Envoyée',
    'invoice_status_3' => 'Vue',
    'invoice_status_4' => 'Approuvée',
    'invoice_status_5' => 'Partielle',
    'invoice_status_6' => 'Payée',
    'marked_invoice_as_sent' => 'La facture a été marquée comme envoyée avec succès',
    'please_enter_a_client_or_contact_name' => 'Veuillez saisir un nom de client ou de contact',
    'restart_app_to_apply_change' => 'Redémarrez l\'app pour mettre à jour les changements',
    'refresh_data' => 'Actualiser les données',
    'blank_contact' => 'Contact vide',
    'no_records_found' => 'Aucun enregistrement trouvé',
    'industry' => 'Entreprise',
    'size' => 'Taille',
    'net' => 'Net',
    'show_tasks' => 'Afficher les tâches',
    'email_reminders' => 'Courriel de rappel',
    'reminder1' => 'Premier rappel',
    'reminder2' => 'Deuxième rappel',
    'reminder3' => 'Troisième rappel',
    'send' => 'Envoyer',
    'auto_billing' => 'Facturation automatique',
    'button' => 'Bouton',
    'more' => 'Plus',
    'edit_recurring_invoice' => 'Éditer la facture récurrente',
    'edit_recurring_quote' => 'Éditer la soumission récurrente',
    'quote_status' => 'État de la soumission',
    'please_select_an_invoice' => 'Veuillez sélectionner une facture',
    'filtered_by' => 'Filtrée par',
    'payment_status' => 'État du paiement',
    'payment_status_1' => 'Em attente',
    'payment_status_2' => 'Annulée',
    'payment_status_3' => 'Échouée',
    'payment_status_4' => 'Complétée',
    'payment_status_5' => 'Partiellement remboursée',
    'payment_status_6' => 'Remboursée',
    'send_receipt_to_client' => 'Envoyer un reçu au client',
    'refunded' => 'Remboursée',
    'marked_quote_as_sent' => 'La soumission a été marquée comme envoyée avec succès',
    'custom_module_settings' => 'Paramètres personnalisés de modules',
    'ticket' => 'Billet',
    'tickets' => 'Billets',
    'ticket_number' => 'Billet #',
    'new_ticket' => 'Nouveau billet',
    'edit_ticket' => 'Éditer le billet',
    'view_ticket' => 'Voir le billet',
    'archive_ticket' => 'Archiver le billet',
    'restore_ticket' => 'Restaurer le billet',
    'delete_ticket' => 'Supprimer le billet',
    'archived_ticket' => 'Le billet a été archivé avec succès',
    'archived_tickets' => 'Les billets ont été archivés avec succès',
    'restored_ticket' => 'Le billet a été restauré avec succès',
    'deleted_ticket' => 'Le billet a été supprimé avec succès',
    'open' => 'Ouvert',
    'new' => 'Nouveau',
    'closed' => 'Fermé',
    'reopened' => 'Réouvert',
    'priority' => 'Priorité',
    'last_updated' => 'Dernière mise à jour',
    'comment' => 'Commentaires',
    'tags' => 'Libellés',
    'linked_objects' => 'Objets liés',
    'low' => 'Basse',
    'medium' => 'Moyenne',
    'high' => 'Haute',
    'no_due_date' => 'Aucune date d\'échéance spécifiée',
    'assigned_to' => 'Assigné à',
    'reply' => 'Répondre',
    'awaiting_reply' => 'En attente de réponse',
    'ticket_close' => 'Fermer le billet',
    'ticket_reopen' => 'Réouvrir le billet',
    'ticket_open' => 'Ouvrir le billet',
    'ticket_split' => 'Scinder le billet',
    'ticket_merge' => 'Fusionner le billet',
    'ticket_update' => 'Mettre à jour le billet',
    'ticket_settings' => 'Paramètres des billets',
    'updated_ticket' => 'Billet mis à jour',
    'mark_spam' => 'Marquer comme spam',
    'local_part' => 'Partie locale',
    'local_part_unavailable' => 'Nom déjà pris',
    'local_part_available' => 'Nom disponible',
    'local_part_invalid' => 'Nom invalide (alphanumérique seulement, aucun espace',
    'local_part_help' => 'Personnaliser la première partie de votre adresse courriel de support. ex. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'DE est l\'expéditeur reconnu qui est affiché au lieu de l\'adresse courriel, ex. Centre de soutien',
    'local_part_placeholder' => 'VOTRE_NOM',
    'from_name_placeholder' => 'Centre de soutien',
    'attachments' => 'Pièces jointes',
    'client_upload' => 'Téléversements des clients',
    'enable_client_upload_help' => 'Autoriser les clients à téléverser des documents ou des fichiers attachés',
    'max_file_size_help' => 'La taille maximale d\'un fichier (Ko) est limitée par les variables post_max_size et upload_max_filesize spécifiées dans votre fichier PHI.INI',
    'max_file_size' => 'Taille maximale de fichier',
    'mime_types' => 'Type MIME',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Liste séparée par une virgule pour les types MIME autorisés. Laissant vide pour tout autoriser',
    'ticket_number_start_help' => 'Le numéro du billet doit être plus grand que le billet en cours',
    'new_ticket_template_id' => 'Nouveau billet',
    'new_ticket_autoresponder_help' => 'En sélectionnant un modèle, une réponse automatique sera envoyée à un client/contact lorsqu\'un nouveau billet est créé',
    'update_ticket_template_id' => 'Billet mis à jour',
    'update_ticket_autoresponder_help' => 'En sélectionnant un modèle, une réponse automatique sera envoyée à un client/contact lorsqu\'un billet est mis à jour',
    'close_ticket_template_id' => 'Billet fermé',
    'close_ticket_autoresponder_help' => 'En sélectionnant un modèle, une réponse automatique sera envoyée à un client/contact lorsqu\'un billet est fermé',
    'default_priority' => 'Priorité par défaut',
    'alert_new_comment_id' => 'Nouveau commentaire',
    'alert_comment_ticket_help' => 'En sélectionnant un modèle, une notification (à l\'agent) sera envoyée lorsqu\'un commentaire est fait',
    'alert_comment_ticket_email_help' => 'Courriels séparés par une virgule pour CCI sur un nouveau commentaire.',
    'new_ticket_notification_list' => 'Notifications de nouveaux billets additionnels',
    'update_ticket_notification_list' => 'Notifications de nouveaux commentaires additionnels',
    'comma_separated_values' => 'admin@exemple.com, supervisor@exemple.com',
    'alert_ticket_assign_agent_id' => 'Assignation de billet',
    'alert_ticket_assign_agent_id_hel' => 'En sélectionnant un modèle, une notification (à l\'agent) sera envoyée lorsqu\'un billet est assigné.',
    'alert_ticket_assign_agent_id_notifications' => 'Notifications de billets assignés additionnels',
    'alert_ticket_assign_agent_id_help' => 'Courriels séparés par une virgule pour CCI pour un billet assigné.',
    'alert_ticket_transfer_email_help' => 'Courriels séparés par une virgule pour CCI sur un billet transféré.',
    'alert_ticket_overdue_agent_id' => 'Billet en retard',
    'alert_ticket_overdue_email' => 'Notifications de billets en retard additionnels',
    'alert_ticket_overdue_email_help' => 'Courriels séparés par une virgule pour CCI sur un billet en retard.',
    'alert_ticket_overdue_agent_id_help' => 'En sélectionnant un modèle, une notification (à l\'agent) sera envoyée lorsqu\'un billet est en retard.',
    'ticket_master' => 'Gestionnaire de billet',
    'ticket_master_help' => 'Peut assigner et transférer les billets. Assigné par défaut pour tous les billets.',
    'default_agent' => 'Agent par défaut',
    'default_agent_help' => 'Cette sélection va automatiquement être assignée à tous les courriels entrants',
    'show_agent_details' => 'Afficher les informations de l\'agent dans les réponses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Retirer l\'avatar',
    'ticket_not_found' => 'Billet introuvable',
    'add_template' => 'Ajouter un modèle',
    'ticket_template' => 'Modèle de billet',
    'ticket_templates' => 'Modèles de billets',
    'updated_ticket_template' => 'Modèle de billets mise à jour',
    'created_ticket_template' => 'Modèle de billet créés',
    'archive_ticket_template' => 'Archiver le modèle',
    'restore_ticket_template' => 'Restaurer le modèle',
    'archived_ticket_template' => 'Le modèle a été archivé avec succès',
    'restored_ticket_template' => 'Le modèle a été restauré avec succès',
    'close_reason' => 'Faites-nous savoir pourquoi vous fermez ce billet',
    'reopen_reason' => 'Faites-nous savoir pourquoi vous souhaitez réouvrir ce billet',
    'enter_ticket_message' => 'Veuillez entrer un message pour mettre à jour ce billet',
    'show_hide_all' => 'Afficher / masquer tout',
    'subject_required' => 'Objet requis',
    'mobile_refresh_warning' => 'Si vous utilisez l\'app mobile, vous devez faire une actualisation complète.',
    'enable_proposals_for_background' => 'Pour téléverser une image de fond :link pour activer le module de propositions.',
    'ticket_assignment' => 'Le billet :ticket_number a été assigné à :agent',
    'ticket_contact_reply' => 'Le billet :ticket_number a été mis à jour par le client :contact',
    'ticket_new_template_subject' => 'Le billet :ticket_number a été créé.',
    'ticket_updated_template_subject' => 'Le billet :ticket_number a été mis à jour.',
    'ticket_closed_template_subject' => 'Le billet :ticket_number a été fermé.',
    'ticket_overdue_template_subject' => 'Le biller :ticket_number est en retard',
    'merge' => 'Fusionner',
    'merged' => 'Fusionné',
    'agent' => 'Agent',
    'parent_ticket' => 'Billet parent',
    'linked_tickets' => 'Billets liés',
    'merge_prompt' => 'Veuillez saisir un numéro de billet pour fusionner',
    'merge_from_to' => 'Le billet #:old_ticket a été fusionné avec le billet #:new_ticket',
    'merge_closed_ticket_text' => 'Le billet #:old_ticket a été fermé et fusionner avec le billet #:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Le billet #:old_ticket a été fermé et fusionné avec ce billet',
    'merge_placeholder' => 'Fusionner le billet #:ticket avec le billet suivant',
    'select_ticket' => 'Sélectionner le billet',
    'new_internal_ticket' => 'Nouveau billet interne',
    'internal_ticket' => 'Billet interne',
    'create_ticket' => 'Créer un billet',
    'allow_inbound_email_tickets_external' => 'Nouveaux billets par courriel (client)',
    'allow_inbound_email_tickets_external_help' => 'Autoriser les clients à créer de nouveaux billets par courriel',
    'include_in_filter' => 'Inclure dans le filtre',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Comparer',
    'hosted_login' => 'Connexion hébergée',
    'selfhost_login' => 'Connexion autohébergée',
    'google_login' => 'Connexion Google',
    'thanks_for_patience' => 'Merci de votre patience pendant que nous travaillons à l\'implémentation de ces fonctionnalités.\n\nNous espérons compléter cette implémentation dans les prochains mois.\n\nPendant ce temps, nous continuerons de supporter ',
    'legacy_mobile_app' => 'Ancienne App mobile',
    'today' => 'Aujourd\'hui',
    'current' => 'En cours',
    'previous' => 'Précédent',
    'current_period' => 'Période en cours',
    'comparison_period' => 'Période de comparaison',
    'previous_period' => 'Période précédente',
    'previous_year' => 'Année précédente',
    'compare_to' => 'Comparer à',
    'last_week' => 'Dernière semaine',
    'clone_to_invoice' => 'Cloner en facture',
    'clone_to_quote' => 'Cloner en soumission',
    'convert' => 'Convertir',
    'last7_days' => '7 derniers jours',
    'last30_days' => '30 derniers jours',
    'custom_js' => 'JS personnalisé',
    'adjust_fee_percent_help' => 'Ajuster le frais de pourcentage au compte',
    'show_product_notes' => 'Afficher le détail des produits',
    'show_product_notes_help' => 'Inclure la <b>description et le coût</b> dans le menu déroulant du produit',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Merci d\'utiliser notre app!',
    'if_you_like_it' => 'Si vous appréciez, merci',
    'to_rate_it' => 'd\'évaluer notre app.',
    'average' => 'Moyenne',
    'unapproved' => 'Non approuvé',
    'authenticate_to_change_setting' => 'Veuillez vous connecter pour changer ce paramètre',
    'locked' => 'Verrouillé',
    'authenticate' => 'Connexion',
    'please_authenticate' => 'Veuillez vous connecter',
    'biometric_authentication' => 'Connexion biométrique',
    'auto_start_tasks' => 'Démarrage de tâches automatique',
    'budgeted' => 'Budgété',
    'please_enter_a_name' => 'Veuillez entrer un nom',
    'click_plus_to_add_time' => 'Cliquez sur + pour ajouter du temps',
    'design' => 'Conception',
    'password_is_too_short' => 'Le mot de passe est trop court',
    'failed_to_find_record' => 'Enregistrement introuvable',
    'valid_until_days' => 'Valable jusque',
    'valid_until_days_help' => 'Définit automatiquement la valeur <b>Valable jusque</b> sur les soumissions pour autant de jours à venir.  Laissez vide pour désactiver.',
    'usually_pays_in_days' => 'Jours',
    'requires_an_enterprise_plan' => 'Le plan Entreprise est requis',
    'take_picture' => 'Prendre un photo',
    'upload_file' => 'Téléverser un fichier',
    'new_document' => 'Nouveau document',
    'edit_document' => 'Éditer un document',
    'uploaded_document' => 'Le document a été téléversé avec succès',
    'updated_document' => 'Le document a été mis à jour avec succès',
    'archived_document' => 'Le document a été archivé avec succès',
    'deleted_document' => 'Le document a été supprimé avec succès',
    'restored_document' => 'Le document a été restauré avec succès',
    'no_history' => 'Aucun historique',
    'expense_status_1' => 'Connecté',
    'expense_status_2' => 'En attente',
    'expense_status_3' => 'Facturé',
    'no_record_selected' => 'Aucun enregistrement sélectionné',
    'error_unsaved_changes' => 'Veuillez sauvegarder ou annuler vos modifications',
    'thank_you_for_your_purchase' => 'Merci de votre achat!',
    'redeem' => 'Rembourser',
    'back' => 'Retour',
    'past_purchases' => 'Achats précédents',
    'annual_subscription' => 'Abonnement annuel',
    'pro_plan' => 'Plan Pro',
    'enterprise_plan' => 'Plan Entreprise',
    'count_users' => ':count utilisateurs',
    'upgrade' => 'Mettre à niveau',
    'please_enter_a_first_name' => 'Veuillez entrer votre prénom',
    'please_enter_a_last_name' => 'Veuillez entrer votre nom',
    'please_agree_to_terms_and_privacy' => 'Vous devez accepter les conditions et la politique de confidentialité pour créer un compte.',
    'i_agree_to_the' => 'J\'accepte',
    'terms_of_service_link' => 'les conditions',
    'privacy_policy_link' => 'la politique de confidentialité',
    'view_website' => 'Visiter le site web',
    'create_account' => 'Créer un compte',
    'email_login' => 'Courriel de connexion',
    'late_fees' => 'Frais de retard',
    'payment_number' => 'Numéro de paiement',
    'before_due_date' => 'Avant l\'échéance',
    'after_due_date' => 'Après l\'échéance',
    'after_invoice_date' => 'Après la date de facturation',
    'filtered_by_user' => 'Filtré par utilisateur',
    'created_user' => 'L\'utilisateur a été créé avec succès',
    'primary_font' => 'Fonte principale',
    'secondary_font' => 'Fonte secondaire',
    'number_padding' => 'Marge interne du nombre',
    'general' => 'Général',
    'surcharge_field' => 'Champ Surcharge',
    'company_value' => 'Valeur de compagnie',
    'credit_field' => 'Champ Crédit',
    'payment_field' => 'Champ Paiement',
    'group_field' => 'Champ Groupe',
    'number_counter' => 'Compteur de nombre',
    'number_pattern' => 'Modèle de nombre',
    'custom_javascript' => 'JavaScript personnalisé',
    'portal_mode' => 'Mode portail',
    'attach_pdf' => 'Joindre un PDF',
    'attach_documents' => 'Joindre un document',
    'attach_ubl' => 'Joindre UBL',
    'email_style' => 'Style de courriel',
    'processed' => 'Traité',
    'fee_amount' => 'Montant des frais',
    'fee_percent' => 'Pourcentage des frais',
    'fee_cap' => 'Limite des frais',
    'limits_and_fees' => 'Limites/Frais',
    'credentials' => 'Identifiants',
    'require_billing_address_help' => 'Le client doit fournir son adresse de facturation',
    'require_shipping_address_help' => 'Le client doit fournir son adresse de livraison',
    'deleted_tax_rate' => 'Le taux de taxe a été supprimé avec succès',
    'restored_tax_rate' => 'Le taux de taxe a été restauré avec succès',
    'provider' => 'Fournisseur',
    'company_gateway' => 'Passerelle de paiement',
    'company_gateways' => 'Passerelles de paiement',
    'new_company_gateway' => 'Nouvelle passerelle',
    'edit_company_gateway' => 'Éditer la passerelle',
    'created_company_gateway' => 'La passerelle a été créée avec succès',
    'updated_company_gateway' => 'La passerelle a été mise à jour avec succès',
    'archived_company_gateway' => 'La passerelle a été archivée avec succès',
    'deleted_company_gateway' => 'La passerelle a été supprimée avec succès',
    'restored_company_gateway' => 'La passerelle a été restaurée avec succès',
    'continue_editing' => 'Continuez l\'édition',
    'default_value' => 'Valeur par défaut',
    'currency_format' => 'Format de devise',
    'first_day_of_the_week' => 'Premier jour de la semaine',
    'first_month_of_the_year' => 'Premier mois de l\'année',
    'symbol' => 'Symbole',
    'ocde' => 'Code',
    'date_format' => 'Format de date',
    'datetime_format' => 'Format date/heure',
    'send_reminders' => 'Envoyer des rappels',
    'timezone' => 'Fuseau horaire',
    'filtered_by_group' => 'Filtrer par groupe',
    'filtered_by_invoice' => 'Filtrer par facture',
    'filtered_by_client' => 'Filtrer par client',
    'filtered_by_vendor' => 'Filtrer par fournisseur',
    'group_settings' => 'Paramètres des groupes',
    'groups' => 'Groupes',
    'new_group' => 'Nouveau groupe',
    'edit_group' => 'Éditer le groupe',
    'created_group' => 'Le groupe a été créé avec succès',
    'updated_group' => 'Le groupe a été mis à jour avec succès',
    'archived_group' => 'Le groupe a été archivé avec succès',
    'deleted_group' => 'Le groupe a été supprimé avec succès',
    'restored_group' => 'Le groupe a été restauré avec succès',
    'upload_logo' => 'Téléverser le logo',
    'uploaded_logo' => 'Le logo a été téléversé avec succès',
    'saved_settings' => 'Les paramètres ont été sauvegardés avec succès',
    'device_settings' => 'Paramètres de l\'appareil',
    'credit_cards_and_banks' => 'Cartes de crédit et banques',
    'price' => 'Prix',
    'email_sign_up' => 'Inscription par courriel',
    'google_sign_up' => 'Inscription avec Google',
    'sign_up_with_google' => 'Inscrivez-vous avec Google',
    'long_press_multiselect' => 'Multisélection par pression longue',
    'migrate_to_next_version' => 'Migrer vers la nouvelle version de Invoice Ninja',
    'migrate_intro_text' => 'Nous avons travaillé sur une nouvelle version de Invoice Ninja. Cliquez sur le bouton ci-dessous pour démarrer la migration.',
    'start_the_migration' => 'Démarrer la migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Bienvenue dans la nouvelle version de Invoice Ninja',
    'next_step_data_download' => 'Lors de la prochaine étape, nous pourrez télécharger vos données pour la migration.',
    'download_data' => 'Téléchargez vos données en cliquant sur le bouton ci-dessous.',
    'migration_import' => 'Super! Vous êtes prêt pour l\'importation de votre migration. Allez dans votre nouvelle installation pour l\'importation de vos données.',
    'continue' => 'Continuez',
    'company1' => 'Entreprise personnalisée 1',
    'company2' => 'Entreprise personnalisée 2',
    'company3' => 'Entreprise personnalisée 3',
    'company4' => 'Entreprise personnalisée 4',
    'product1' => 'Produit personnalisé 1',
    'product2' => 'Produit personnalisé 2',
    'product3' => 'Produit personnalisé 3',
    'product4' => 'Produit personnalisé 4',
    'client1' => 'Client personnalisé 1',
    'client2' => 'Client personnalisé 2',
    'client3' => 'Client personnalisé 3',
    'client4' => 'Client personnalisé 4',
    'contact1' => 'Contact personnalisé 1',
    'contact2' => 'Contact personnalisé 2',
    'contact3' => 'Contact personnalisé 3',
    'contact4' => 'Contact personnalisé 4',
    'task1' => 'Tâche personnalisée 1',
    'task2' => 'Tâche personnalisée 2',
    'task3' => 'Tâche personnalisée 3',
    'task4' => 'Tâche personnalisée 4',
    'project1' => 'Projet personnalisé 1',
    'project2' => 'Projet personnalisé 2',
    'project3' => 'Projet personnalisé 3',
    'project4' => 'Projet personnalisé 4',
    'expense1' => 'Dépense personnalisée 1',
    'expense2' => 'Dépense personnalisée 2',
    'expense3' => 'Dépense personnalisée 3',
    'expense4' => 'Dépense personnalisée 4',
    'vendor1' => 'Fournisseur personnalisé 1',
    'vendor2' => 'Fournisseur personnalisé 2',
    'vendor3' => 'Fournisseur personnalisé 3',
    'vendor4' => 'Fournisseur personnalisé 4',
    'invoice1' => 'Facture personnalisée 1',
    'invoice2' => 'Facture personnalisée 2',
    'invoice3' => 'Facture personnalisée 3',
    'invoice4' => 'Facture personnalisée 4',
    'payment1' => 'Paiement personnalisé 1',
    'payment2' => 'Facture personnalisée 2',
    'payment3' => 'Facture personnalisée 3',
    'payment4' => 'Facture personnalisée 4',
    'surcharge1' => 'Surcharge personnalisée 1',
    'surcharge2' => 'Surcharge personnalisée 2',
    'surcharge3' => 'Surcharge personnalisée 3',
    'surcharge4' => 'Surcharge personnalisée 4',
    'group1' => 'Groupe personnalisé 1',
    'group2' => 'Groupe personnalisé 2',
    'group3' => 'Groupe personnalisé 3',
    'group4' => 'Groupe personnalisé 4',
    'number' => 'Numéro',
    'count' => 'Compteur',
    'is_active' => 'Actif',
    'contact_last_login' => 'Dernière connexion du contact',
    'contact_full_name' => 'Nom complet du contact',
    'contact_custom_value1' => 'Valeur personnalisée du contact 1',
    'contact_custom_value2' => 'Valeur personnalisée du contact 2',
    'contact_custom_value3' => 'Valeur personnalisée du contact 3',
    'contact_custom_value4' => 'Valeur personnalisée du contact 4',
    'assigned_to_id' => 'Assigné à ID',
    'created_by_id' => 'Créé par ID',
    'add_column' => 'Ajouter colonne',
    'edit_columns' => 'Éditer colonne',
    'to_learn_about_gogle_fonts' => 'en savoir plus sur Google Fonts',
    'refund_date' => 'Date de remboursement',
    'multiselect' => 'Sélection multiple',
    'verify_password' => 'Vérifier le mot de passe',
    'applied' => 'Publié',
    'include_recent_errors' => 'Inclut les erreurs récentes des journaux système',
    'your_message_has_been_received' => 'Nous avons reçu votre message et vous répondrons rapidement.',
    'show_product_details' => 'Afficher les détails du produit',
    'show_product_details_help' => 'Veuillez inclure la description et le coût dans la liste déroulante du produit',
    'pdf_min_requirements' => 'Le moteur de rendu PDF nécessite :version',
    'adjust_fee_percent' => 'Ajuster le pourcentage de frais',
    'configure_settings' => 'Configurer les paramètres',
    'about' => 'À propos',
    'credit_email' => 'Courriel pour le crédit',
    'domain_url' => 'URL de domaine',
    'password_is_too_easy' => 'Le mot de passe doit contenir une majuscule et un nombre',
    'client_portal_tasks' => 'Tâches du portail client',
    'client_portal_dashboard' => 'Tableau de bord du portail client',
    'please_enter_a_value' => 'Veuillez saisir une valeur',
    'deleted_logo' => 'Le logo a été supprimé avec succès',
    'generate_number' => 'Générer un nombre',
    'when_saved' => 'Lors de la sauvegarde',
    'when_sent' => 'Lors de l\'envoi',
    'select_company' => 'Sélectionnez une entreprise',
    'float' => 'Flottant',
    'collapse' => 'Réduire',
    'show_or_hide' => 'Afficher/masquer',
    'menu_sidebar' => 'Menu latéral',
    'history_sidebar' => 'Historique latéral',
    'tablet' => 'Tablette',
    'layout' => 'Affichage',
    'module' => 'Module',
    'first_custom' => 'Premier personnalisé',
    'second_custom' => 'Second personnalisé',
    'third_custom' => 'Troisième latéral',
    'show_cost' => 'Afficher le coût',
    'show_cost_help' => 'Afficher un champ de coût du produit pour suivre le profit',
    'show_product_quantity' => 'Afficher la quantité de produit',
    'show_product_quantity_help' => 'Afficher un champ Quantité de produit. 1 par défaut.',
    'show_invoice_quantity' => 'Afficher la quantité de facture',
    'show_invoice_quantity_help' => 'Afficher un champ Quantité d\'article par ligne. 1 par défaut.',
    'default_quantity' => 'Quantité par défaut',
    'default_quantity_help' => 'Définit automatiquement la quantité d\'article par ligne à 1.',
    'one_tax_rate' => 'Un taux de taxe',
    'two_tax_rates' => 'Deux taux de taxe',
    'three_tax_rates' => 'Trois taux de taxes',
    'default_tax_rate' => 'Taux de taxe par défaut',
    'invoice_tax' => 'Taxe de facture',
    'line_item_tax' => 'Taxe d\'article par ligne',
    'inclusive_taxes' => 'Taxes incluses',
    'invoice_tax_rates' => 'Taux de taxe de facture',
    'item_tax_rates' => 'Taux de taxe par article',
    'configure_rates' => 'Configuration des taux',
    'tax_settings_rates' => 'Taux de taxe',
    'accent_color' => 'Couleur de mise en évidence',
    'comma_sparated_list' => 'Liste séparée par virgule',
    'single_line_text' => 'Ligne de texte simple',
    'multi_line_text' => 'Multiligne de texte',
    'dropdown' => 'Liste déroulante',
    'field_type' => 'Type de champ',
    'recover_password_email_sent' => 'Un courriel a été envoyé pour la récupération du mot de passe',
    'removed_user' => 'L\'utilisateur a été retiré avec succès',
    'freq_three_years' => 'Trois ans',
    'military_time_help' => 'Affichage 24h',
    'click_here_capital' => 'Cliquez ici',
    'marked_invoice_as_paid' => 'La facture a été marquée comme envoyée avec succès',
    'marked_invoices_as_sent' => 'Les factures ont été marquées comme envoyées avec succès',
    'marked_invoices_as_paid' => 'Les factures ont été marquées comme envoyées avec succès',
    'activity_57' => 'Le système n\'a pas pu envoyer le courriel de la facture :invoice',
    'custom_value3' => 'Valeur personnalisée 3',
    'custom_value4' => 'Valeur personnalisée 4',
    'email_style_custom' => 'Style de courriel personnalisé',
    'custom_message_dashboard' => 'Message personnalisé du tableau de bord',
    'custom_message_unpaid_invoice' => 'Message personnalisé pour facture impayée',
    'custom_message_paid_invoice' => 'Message personnalisé pour facture payée',
    'custom_message_unapproved_quote' => 'Message personnalisé pour soumission non approuvée',
    'lock_sent_invoices' => 'Verrouiller les factures envoyées',
    'translations' => 'Traductions',
    'task_number_pattern' => 'Modèle du numéro de tâche',
    'task_number_counter' => 'Compteur du numéro de tâche',
    'expense_number_pattern' => 'Modèle du numéro de dépense',
    'expense_number_counter' => 'Compteur du numéro de dépense',
    'vendor_number_pattern' => 'Modèle du numéro de fournisseur',
    'vendor_number_counter' => 'Compteur du numéro de fournisseur',
    'ticket_number_pattern' => 'Modèle du numéro de billet',
    'ticket_number_counter' => 'Compteur du numéro de billet',
    'payment_number_pattern' => 'Modèle du numéro de paiement',
    'payment_number_counter' => 'Compteur du numéro de paiement',
    'invoice_number_pattern' => 'Modèle du numéro de facture',
    'quote_number_pattern' => 'Modèle du numéro de soumission',
    'client_number_pattern' => 'Modèle du numéro de crédit',
    'client_number_counter' => 'Compteur du numéro de crédit',
    'credit_number_pattern' => 'Modèle du numéro de crédit',
    'credit_number_counter' => 'Compteur du numéro de crédit',
    'reset_counter_date' => 'Remise à zéro du compteur de date',
    'counter_padding' => 'Espacement du compteur',
    'shared_invoice_quote_counter' => 'Compteur partagé pour les factures et les soumissions',
    'default_tax_name_1' => 'Nom de taxe par défaut 1',
    'default_tax_rate_1' => 'Taux de taxe par défaut 1',
    'default_tax_name_2' => 'Nom de taxe par défaut 2',
    'default_tax_rate_2' => 'Taux de taxe par défaut 2',
    'default_tax_name_3' => 'Nom de taxe par défaut 3',
    'default_tax_rate_3' => 'Taux de taxe par défaut 3',
    'email_subject_invoice' => 'Objet du courriel de facture',
    'email_subject_quote' => 'Objet du courriel de soumission',
    'email_subject_payment' => 'Objet du courriel de paiement',
    'switch_list_table' => 'Basculer à table de liste',
    'client_city' => 'Ville du client',
    'client_state' => 'Province du client',
    'client_country' => 'Pays du client',
    'client_is_active' => 'Client actif',
    'client_balance' => 'Solde du client',
    'client_address1' => 'Rue du clients',
    'client_address2' => 'Apt/Suite',
    'client_shipping_address1' => 'Rue d\'expédition',
    'client_shipping_address2' => 'Expédition Apt/Suite',
    'tax_rate1' => 'Taux de taxe 1',
    'tax_rate2' => 'Taux de taxe 2',
    'tax_rate3' => 'Taux de taxe 3',
    'archived_at' => 'Archivé à',
    'has_expenses' => 'A Dépenses',
    'custom_taxes1' => 'Taxes personnalisées 1',
    'custom_taxes2' => 'Taxes personnalisées 2',
    'custom_taxes3' => 'Taxes personnalisées 3',
    'custom_taxes4' => 'Taxes personnalisées 4',
    'custom_surcharge1' => 'Surcharge personnalisée 1',
    'custom_surcharge2' => 'Surcharge personnalisée 2',
    'custom_surcharge3' => 'Surcharge personnalisée 3',
    'custom_surcharge4' => 'Surcharge personnalisée 4',
    'is_deleted' => 'Est supprimé',
    'vendor_city' => 'Ville du fournisseur',
    'vendor_state' => 'Province du fournisseur',
    'vendor_country' => 'Pays du fournisseur',
    'credit_footer' => 'Pied de page pour crédit',
    'credit_terms' => 'Conditions d\'utilisation pour crédit',
    'untitled_company' => 'Entreprise sans nom',
    'added_company' => 'L\'entreprise a été ajoutée avec succès',
    'supported_events' => 'Événements pris en charge',
    'custom3' => 'Troisième personnalisé',
    'custom4' => 'Quatrième personnalisée',
    'optional' => 'Optionnel',
    'license' => 'Licence',
    'invoice_balance' => 'Solde de facture',
    'saved_design' => 'Le modèle a été sauvegardé avec succès',
    'client_details' => 'Informations du client',
    'company_address' => 'Adresse de l\'entreprise',
    'quote_details' => 'Informations de la soumission',
    'credit_details' => 'Informations de crédit',
    'product_columns' => 'Colonnes produit',
    'task_columns' => 'Colonnes tâches',
    'add_field' => 'Ajouter un champ',
    'all_events' => 'Ajouter un événement',
    'owned' => 'Propriétaire',
    'payment_success' => 'Paiement réussi',
    'payment_failure' => 'Le paiement a échoué',
    'quote_sent' => 'Soumission envoyée',
    'credit_sent' => 'Crédit envoyé',
    'invoice_viewed' => 'Facture visualisée',
    'quote_viewed' => 'Soumission visualisée',
    'credit_viewed' => 'Crédit visualisé',
    'quote_approved' => 'Soumission approuvée',
    'receive_all_notifications' => 'Recevoir toutes les notifications',
    'purchase_license' => 'Acheter une licence',
    'enable_modules' => 'Activer les modules',
    'converted_quote' => 'La soumission a été convertie avec succès',
    'credit_design' => 'Design de crédit',
    'includes' => 'Inclue',
    'css_framework' => 'Framework CSS',
    'custom_designs' => 'Designs personnalisés',
    'designs' => 'Designs',
    'new_design' => 'Nouveau design',
    'edit_design' => 'Éditer le design',
    'created_design' => 'Le modèle a été créé avec succès',
    'updated_design' => 'Le modèle a été mis à jour avec succès',
    'archived_design' => 'Le modèle a été archivé avec succès',
    'deleted_design' => 'Le modèle a été supprimé avec succès',
    'removed_design' => 'Le modèle a été retiré avec succès',
    'restored_design' => 'Le modèle a été restauré avec succès',
    'recurring_tasks' => 'Tâches récurrentes',
    'removed_credit' => 'Le crédit a été retiré avec succès',
    'latest_version' => 'Dernière version',
    'update_now' => 'Mettre à jour',
    'a_new_version_is_available' => 'Une nouvelle version de l\'application web est disponible',
    'update_available' => 'Mise à jour disponible',
    'app_updated' => 'La mise à jour a été complétée avec succès',
    'integrations' => 'Intégrations',
    'tracking_id' => 'ID de suivi',
    'slack_webhook_url' => 'URL du Webhook Slack',
    'partial_payment' => 'Paiement partiel',
    'partial_payment_email' => 'Courriel du paiement partiel',
    'clone_to_credit' => 'Cloner au crédit',
    'emailed_credit' => 'Le crédit a envoyé par courriel avec succès',
    'marked_credit_as_sent' => 'Le crédit a été marqué comme envoyé avec succès',
    'email_subject_payment_partial' => 'Sujet du courriel de paiement partiel',
    'is_approved' => 'Est approuvé',
    'migration_went_wrong' => 'Oups, quelque chose n\'a pas bien fonctionné! Veuillez vous assurer que vous avez bien configuré une instance de Invoice Ninja v5 avant de commencer la migration.',
    'cross_migration_message' => 'La migration entre comptes n\'est pas autorisée. Pour en savoir plus: <a href="https://invoiceninja.github.io/cross-site-migration.html">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Crédit par courriel',
    'client_email_not_set' => 'Le client n\'a pas d\'adresse courriel définie',
    'ledger' => 'Grand livre',
    'view_pdf' => 'Voir PDF',
    'all_records' => 'Tous les enregistrements',
    'owned_by_user' => 'Propriété de l\'utilisateur',
    'credit_remaining' => 'Crédit restant',
    'use_default' => 'Utiliser le défaut',
    'reminder_endless' => 'Rappels infinis',
    'number_of_days' => 'Nombre de jours',
    'configure_payment_terms' => 'Configuration des délais de paiements',
    'payment_term' => 'Délai de paiement',
    'new_payment_term' => 'Nouveau délai de paiement',
    'deleted_payment_term' => 'Le délai de paiement a été supprimé avec succès',
    'removed_payment_term' => 'Le délai de paiement a été retiré avec succès',
    'restored_payment_term' => 'Le délai de paiement a été restauré avec succès',
    'full_width_editor' => 'Éditeur pleine hauteur',
    'full_height_filter' => 'Filtre pleine hauteur',
    'email_sign_in' => 'Connexion par courriel',
    'change' => 'Basculer',
    'change_to_mobile_layout' => 'Basculer vers l\'affichage mobile',
    'change_to_desktop_layout' => 'Basculer vers l\'affichage ordinateur',
    'send_from_gmail' => 'Envoyer avec Gmail',
    'reversed' => 'Inversé',
    'cancelled' => 'Annulé',
    'quote_amount' => 'Montant de la soumission',
    'hosted' => 'Hébergé',
    'selfhosted' => 'Auto-hébergé',
    'hide_menu' => 'Masquer le menu',
    'show_menu' => 'Afficher le menu',
    'partially_refunded' => 'Partiellement remboursé',
    'search_documents' => 'Recherche de documents',
    'search_designs' => 'Recherche de designs',
    'search_invoices' => 'Recherche de factures',
    'search_clients' => 'Recherche de clients',
    'search_products' => 'Recherche de produits',
    'search_quotes' => 'Recherche de soumissions',
    'search_credits' => 'Recherche de crédits',
    'search_vendors' => 'Recherche de fournisseurs',
    'search_users' => 'Recherche d\'utilisateurs',
    'search_tax_rates' => 'Recherche de taux de taxe',
    'search_tasks' => 'Recherche de tâches',
    'search_settings' => 'Recherche de paramètres',
    'search_projects' => 'Recherche de projets',
    'search_expenses' => 'Recherche de dépenses',
    'search_payments' => 'Recherche de paiements',
    'search_groups' => 'Recherche de groupes',
    'search_company' => 'Recherche d\'entreprises',
    'cancelled_invoice' => 'La facture a été annulée avec succès',
    'cancelled_invoices' => 'Les factures ont été annulées avec succès',
    'reversed_invoice' => 'La facture a été inversée avec succès',
    'reversed_invoices' => 'Les factures ont été inversées avec succès',
    'reverse' => 'Inverse',
    'filtered_by_project' => 'Filtrer par projet',
    'google_sign_in' => 'Connexion avec Google',
    'activity_58' => ':user a inversé la facture :invoice',
    'activity_59' => ':user a annulé la facture :invoice',
    'payment_reconciliation_failure' => 'Conciliation non réussie',
    'payment_reconciliation_success' => 'Conciliation réussie',
    'gateway_success' => 'Passerelle réussie',
    'gateway_failure' => 'Échec de passerelle',
    'gateway_error' => 'Erreur de passerelle',
    'email_send' => 'Envoi de courriel',
    'email_retry_queue' => 'File d\'envoi de courriel',
    'failure' => 'Échec',
    'quota_exceeded' => 'Quota dépassé',
    'upstream_failure' => 'Échec en amont',
    'system_logs' => 'Journaux système',
    'copy_link' => 'Copier le lien',
    'welcome_to_invoice_ninja' => 'Bienvenue dans Invoice Ninja',
    'optin' => 'Adhésion',
    'optout' => 'Désadhésion',
    'auto_convert' => 'Conversion automatique',
    'reminder1_sent' => 'Rappel 1 envoyé',
    'reminder2_sent' => 'Rappel 2 envoyé',
    'reminder3_sent' => 'Rappel 3 envoyé',
    'reminder_last_sent' => 'Dernier envoi de rappel',
    'pdf_page_info' => 'Page :current de :total',
    'emailed_credits' => 'Les crédits ont été envoyés par courriel avec succès',
    'view_in_stripe' => 'Voir dans Stripe',
    'rows_per_page' => 'Rangées par page',
    'apply_payment' => 'Appliquer le paiement',
    'unapplied' => 'Non appliqué',
    'custom_labels' => 'Libellés personnalisés',
    'record_type' => 'Type d\'enregistrement',
    'record_name' => 'Non d\'enregistrement',
    'file_type' => 'Type de fichier',
    'height' => 'Hauteur',
    'width' => 'Largeur',
    'health_check' => 'État de santé',
    'last_login_at' => 'Dernière connexion à',
    'company_key' => 'Clé d\'entreprise',
    'storefront' => 'Vitrine',
    'storefront_help' => 'Activer les applications externes à créer des factures',
    'count_records_selected' => ':count enregistrements sélectionnés',
    'count_record_selected' => ':count enregistrement sélectionné',
    'client_created' => 'Client créé',
    'online_payment_email' => 'Courriel de paiement en ligne',
    'manual_payment_email' => 'Courriel de paiement manuel',
    'completed' => 'Complété',
    'gross' => 'Brut',
    'net_amount' => 'Montant net',
    'net_balance' => 'Solde net',
    'client_settings' => 'Paramètres clients',
    'selected_invoices' => 'Factures sélectionnées',
    'selected_payments' => 'Paiements sélectionnés',
    'selected_quotes' => 'Soumissions sélectionnées',
    'selected_tasks' => 'Tâches sélectionnées',
    'selected_expenses' => 'Dépenses sélectionnées',
    'past_due_invoices' => 'Factures impayées',
    'create_payment' => 'Créer un paiement',
    'update_quote' => 'Mettre à jour la soumission',
    'update_invoice' => 'Mettre à jour la facture',
    'update_client' => 'Mettre à jour le client',
    'update_vendor' => 'Mettre à jour le fournisseur',
    'create_expense' => 'Créer une dépense',
    'update_expense' => 'Mettre à jour la dépense',
    'update_task' => 'Mettre à jour la tâche',
    'approve_quote' => 'Approuver la tâche',
    'when_paid' => 'Lors du paiement',
    'expires_on' => 'Expiration le',
    'show_sidebar' => 'Afficher la barre latérale',
    'hide_sidebar' => 'Masquer la barre latérale',
    'event_type' => 'Type d\'événement',
    'copy' => 'Copier',
    'must_be_online' => 'Veuillez redémarrer l\'application lorsque vous serez connecté à internet',
    'crons_not_enabled' => 'Les crons doivent être activés',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Recherche de :count Webhooks',
    'search_webhook' => 'Recherche de 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'Nouveau Webhook',
    'edit_webhook' => 'Éditer le Webhook',
    'created_webhook' => 'Le webhook a été créé avec succès',
    'updated_webhook' => 'Le webhook a été mis à jour avec succès',
    'archived_webhook' => 'Le webhook a été archivé avec succès',
    'deleted_webhook' => 'Le webhook a été supprimé avec succès',
    'removed_webhook' => 'Le webhook a été retiré avec succès',
    'restored_webhook' => 'Le webhook a été restauré avec succès',
    'search_tokens' => 'Recherche de :count jetons',
    'search_token' => 'Recherche de 1 jeton',
    'new_token' => 'Nouveau jeton',
    'removed_token' => 'Le jeton a été retiré avec succès',
    'restored_token' => 'Le jeton a été restauré avec succès',
    'client_registration' => 'Enregistrement d\'un client',
    'client_registration_help' => 'Autoriser le client à s\'inscrire sur le portail',
    'customize_and_preview' => 'Personnaliser et prévisualiser',
    'search_document' => 'Recherche de 1 document',
    'search_design' => 'Recherche de 1 design',
    'search_invoice' => 'Recherche de 1 facture',
    'search_client' => 'Recherche de 1 client',
    'search_product' => 'Recherche de 1 produit',
    'search_quote' => 'Recherche de 1 soumission',
    'search_credit' => 'Recherche de 1 crédit',
    'search_vendor' => 'Recherche de 1 entreprise',
    'search_user' => 'Recherche de 1 utilisateur',
    'search_tax_rate' => 'Recherche de 1 taux de taxe',
    'search_task' => 'Recherche de 1 tâche',
    'search_project' => 'Recherche de 1 projet',
    'search_expense' => 'Recherche de 1 dépense',
    'search_payment' => 'Recherche de 1 paiement',
    'search_group' => 'Recherche de 1 groupe',
    'created_on' => 'Créé le',
    'payment_status_-1' => 'Non appliqué',
    'lock_invoices' => 'Verrouiller les factures',
    'show_table' => 'Affiche la table',
    'show_list' => 'Afficher la liste',
    'view_changes' => 'Visualiser les changements',
    'force_update' => 'Forcer la mise à jour',
    'force_update_help' => 'Vous êtes sur la dernière version, mais il peut y avoir encore quelques mises à jour en cours',
    'mark_paid_help' => 'Suivez les dépenses qui ont été payées',
    'mark_invoiceable_help' => 'Activer la facturation des dépenses',
    'add_documents_to_invoice_help' => 'Rend visibles les documents',
    'convert_currency_help' => 'Définir un taux d\'échange',
    'expense_settings' => 'Paramètres des dépenses',
    'clone_to_recurring' => 'Cloner en récurrence',
    'crypto' => 'Crypto',
    'user_field' => 'Champs utilisateur',
    'variables' => 'Variables',
    'show_password' => 'Afficher le mot de passe',
    'hide_password' => 'Masquer le mot de passe',
    'copy_error' => 'Erreur de copie',
    'capture_card' => 'Carte saisie',
    'auto_bill_enabled' => 'Autofacturation activée',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Ligne Taxes',
    'total_fields' => 'Total Champs',
    'stopped_recurring_invoice' => 'La facture récurrente a été arrêtée avec succès',
    'started_recurring_invoice' => 'La facture récurrente a été démarrée avec succès',
    'resumed_recurring_invoice' => 'La facture récurrente a été reprise avec succès',
    'gateway_refund' => 'Remboursement de passerelle',
    'gateway_refund_help' => 'Procéder au remboursement avec la passerelle de paiement',
    'due_date_days' => 'Date d\'échéance',
    'paused' => 'En pause',
    'day_count' => 'Jour :count',
    'first_day_of_the_month' => 'Premier jour du mois',
    'last_day_of_the_month' => 'Dernier jour du mois',
    'use_payment_terms' => 'Utiliser les délais de paiement',
    'endless' => 'Sans fin',
    'next_send_date' => 'Prochaine date d\'envoi',
    'remaining_cycles' => 'Cycles restants',
    'created_recurring_invoice' => 'La facture récurrente a été créée avec succès',
    'updated_recurring_invoice' => 'La facture récurrente a été mise à jour avec succès',
    'removed_recurring_invoice' => 'La facture récurrente a été retirée avec succès',
    'search_recurring_invoice' => 'Recherche 1 facture récurrente',
    'search_recurring_invoices' => 'Recherche :count factures récurrentes',
    'send_date' => 'Date d\'envoi',
    'auto_bill_on' => 'Autofacturer le',
    'minimum_under_payment_amount' => 'Montant minimum de sous-paiement',
    'allow_over_payment' => 'Accepter Sur-paiement',
    'allow_over_payment_help' => 'Accepter paiement supplémentaire pour pourboire',
    'allow_under_payment' => 'Accepter Sous-paiement',
    'allow_under_payment_help' => 'Accepter paiement au minimum le montant partiel/dépôt',
    'test_mode' => 'Mode test',
    'calculated_rate' => 'Taux calculé',
    'default_task_rate' => 'Taux de tâche par défaut',
    'clear_cache' => 'Vider le cache',
    'sort_order' => 'Ordre de tri',
    'task_status' => 'État',
    'task_statuses' => 'États de tâche',
    'new_task_status' => 'Nouvel état de tâche',
    'edit_task_status' => 'Édition de l\'état de tâche',
    'created_task_status' => 'L\'état de tâche a été créé avec succès',
    'archived_task_status' => 'L\'état de tâche a été archivé avec succès',
    'deleted_task_status' => 'L\'état de tâche a été supprimé avec succès',
    'removed_task_status' => 'L\'état de tâche a été retiré avec succès',
    'restored_task_status' => 'L\'état de tâche a été restauré avec succès',
    'search_task_status' => 'Recherche 1 état de tâche',
    'search_task_statuses' => 'Recherche :count états de tâche',
    'show_tasks_table' => 'Afficher le tableau des tâches',
    'show_tasks_table_help' => 'Toujours afficher la section des tâches lors de la création de factures',
    'invoice_task_timelog' => 'Facturer le journal du temps des tâches',
    'invoice_task_timelog_help' => 'Ajouter les détails de temps aux lignes d\'articles des factures',
    'auto_start_tasks_help' => 'Démarrer les tâches avant de sauvegarder',
    'configure_statuses' => 'Configurer les états',
    'task_settings' => 'Paramètres des tâches',
    'configure_categories' => 'Configurer les catégories',
    'edit_expense_category' => 'Éditer la catégorie Dépense',
    'removed_expense_category' => 'La catégorie de dépense a été retirée avec succès',
    'search_expense_category' => 'Recherche 1 catégorie de dépense',
    'search_expense_categories' => 'Recherche :count catégorie de dépense',
    'use_available_credits' => 'Utiliser les crédits disponibles',
    'show_option' => 'Afficher les options',
    'negative_payment_error' => 'Le montant du crédit ne peut pas excéder le montant du paiement',
    'should_be_invoiced_help' => 'Activer la facturation de la dépense',
    'configure_gateways' => 'Configurer les passerelles',
    'payment_partial' => 'Paiement partiel',
    'is_running' => 'En cours',
    'invoice_currency_id' => 'ID de la devise de facturation',
    'tax_name1' => 'Nom de la taxe 1',
    'tax_name2' => 'Nom de la taxe 2',
    'transaction_id' => 'ID de transaction',
    'invoice_late' => 'facture en retard',
    'quote_expired' => 'Soumission expirée',
    'recurring_invoice_total' => 'Total de facture',
    'actions' => 'Actions',
    'expense_number' => 'Numéro de dépense',
    'task_number' => 'Numéro de tâche',
    'project_number' => 'Numéro de projet',
    'view_settings' => 'Voir les paramètres',
    'company_disabled_warning' => 'Avertissement: Cette entreprise n\'a pas encore été activée',
    'late_invoice' => 'Facture en retard',
    'expired_quote' => 'Soumission expirée',
    'remind_invoice' => 'Rappeler la facture',
    'client_phone' => 'Téléphone du client',
    'required_fields' => 'Champs requis',
    'enabled_modules' => 'Modules activés',
    'activity_60' => ':contact a vu la soumission :quote',
    'activity_61' => ':user a mis à jour le client :client',
    'activity_62' => ':user a mis à jour le fournisseur :vendor',
    'activity_63' => ':user a envoyé le premier rappel pour la facture :invoice de :contact',
    'activity_64' => ':user a envoyé le deuxième rappel pour la facture :invoice de :contact',
    'activity_65' => ':user a envoyé le troisième rappel pour la facture :invoice de :contact',
    'activity_66' => ':user a envoyé un rappel sans fin pour la facture :invoice de :contact',
    'expense_category_id' => 'ID de catégorie de dépense',
    'view_licenses' => 'Voir les licences',
    'fullscreen_editor' => 'Éditeur plein écran',
    'sidebar_editor' => 'Éditeur de barre latérale',
    'please_type_to_confirm' => 'Veuillez saisir ":value" pour confirmer',
    'purge' => 'Purger',
    'clone_to' => 'Cloner vers',
    'clone_to_other' => 'Cloner vers Autre',
    'labels' => 'Étiquettes',
    'add_custom' => 'Ajout personnalisé',
    'payment_tax' => 'Paiement de taxe',
    'white_label' => 'Sans marque',
    'sent_invoices_are_locked' => 'Les factures envoyées sont verrouillées',
    'paid_invoices_are_locked' => 'Les factures payées sont verrouillées',
    'source_code' => 'Code source',
    'app_platforms' => 'Plateformes d\'app',
    'archived_task_statuses' => 'Les :value états de tâche ont été archivés succès',
    'deleted_task_statuses' => 'Les :value états de tâche ont été supprimés avec succès',
    'restored_task_statuses' => 'Les :value états de tâche ont été restaurés avec succès',
    'deleted_expense_categories' => 'Les :value catégories de dépense ont été supprimées avec succès',
    'restored_expense_categories' => 'Les :value catégories de dépense ont été restaurées avec succès',
    'archived_recurring_invoices' => 'Les :value factures récurrentes ont été archivées avec succès',
    'deleted_recurring_invoices' => 'Les :value factures récurrentes ont été supprimées avec succès',
    'restored_recurring_invoices' => 'Les :value factures récurrentes ont été restaurées avec succès',
    'archived_webhooks' => 'Les :value webhooks ont été archivés avec succès',
    'deleted_webhooks' => 'Les :value webhooks ont été supprimés avec succès',
    'removed_webhooks' => 'Les :value webhooks ont été retirés avec succès',
    'restored_webhooks' => 'Les :value webhooks ont été restaurés avec succès',
    'api_docs' => 'Docs API',
    'archived_tokens' => 'Les :value jetons ont été archivés avec succès',
    'deleted_tokens' => 'Les :value jetons ont été supprimés avec succès',
    'restored_tokens' => 'Les :value jetons ont été restaurés avec succès',
    'archived_payment_terms' => 'Les :value délais de paiement ont été archivés avec succès',
    'deleted_payment_terms' => 'Les :value délais de paiement ont été supprimés avec succès',
    'restored_payment_terms' => 'Les :value délais de paiement ont été restaurés avec succès',
    'archived_designs' => 'Les :value modèles ont été archivés avec succès',
    'deleted_designs' => 'Les :value modèles ont été supprimés avec succès',
    'restored_designs' => 'Les :value modèles ont été restaurés avec succès',
    'restored_credits' => 'Les :value crédits ont été restaurés avec succès',
    'archived_users' => 'Les :value utilisateurs ont été archivés avec succès',
    'deleted_users' => 'Les :value utilisateurs ont été supprimés avec succès',
    'removed_users' => 'Les :value utilisateurs ont été retirés avec succès',
    'restored_users' => 'Les :value utilisateurs ont été restaurés avec succès',
    'archived_tax_rates' => 'Les :value taux de taxes ont été archivés avec succès',
    'deleted_tax_rates' => 'Les :value taux de taxes ont été supprimés avec succès',
    'restored_tax_rates' => 'Les :value taux de taxes ont été restaurés avec succès',
    'archived_company_gateways' => 'Les :value passerelles ont été archivées avec succès',
    'deleted_company_gateways' => 'Les :value passerelles ont été supprimées avec succès',
    'restored_company_gateways' => 'Les :value passerelles ont été restaurées avec succès',
    'archived_groups' => 'Les :value groupes ont été archivés avec succès',
    'deleted_groups' => 'Les :value groupes ont été supprimés avec succès',
    'restored_groups' => 'Les :value groupes ont été restaurés avec succès',
    'archived_documents' => 'Les :value documents ont été archivés avec succès',
    'deleted_documents' => 'Les :value documents ont été supprimés avec succès',
    'restored_documents' => 'Les :value documents ont été restaurés avec succès',
    'restored_vendors' => 'Les :value fournisseurs ont été restaurés avec succès',
    'restored_expenses' => 'Les :value dépenses ont été restaurées avec succès',
    'restored_tasks' => 'Les :value tâches ont été restaurées avec succès',
    'restored_projects' => 'Les :value projets ont été restaurés avec succès',
    'restored_products' => 'Les :value produits ont été restaurés avec succès',
    'restored_clients' => 'Les :value clients ont été restaurés avec succès',
    'restored_invoices' => 'Les :value factures ont été restaurées avec succès',
    'restored_payments' => 'Les :value paiements ont été restaurés avec succès',
    'restored_quotes' => 'Les :value soumissions ont été restaurées avec succès',
    'update_app' => 'Mettre à jour l\'App',
    'started_import' => 'L\'importation a démarré avec succès',
    'duplicate_column_mapping' => 'Dupliquer le mappage de colonnes',
    'uses_inclusive_taxes' => 'Utiliser taxes incluses',
    'is_amount_discount' => 'Est Montant rabais',
    'map_to' => 'Mapper vers',
    'first_row_as_column_names' => 'Utiliser première rangée comme noms de colonnes',
    'no_file_selected' => 'Aucun fichier sélectionné',
    'import_type' => 'Type d\'importation',
    'draft_mode' => 'Mode brouillon',
    'draft_mode_help' => 'Prévisualisations mises à jour plus rapidement mais moins précises',
    'show_product_discount' => 'Afficher le rabais de produit',
    'show_product_discount_help' => 'Afficher un champ rabais de ligne d\'article',
    'tax_name3' => 'Nom de taxe 3',
    'debug_mode_is_enabled' => 'Mode debug activé',
    'debug_mode_is_enabled_help' => 'Avertissement: Pour usage local seulement. Fuites de données possible. En savoir plus.',
    'running_tasks' => 'Tâches en cours',
    'recent_tasks' => 'Tâches récentes',
    'recent_expenses' => 'Dépenses récentes',
    'upcoming_expenses' => 'Dépenses à venir',
    'search_payment_term' => 'Rechercher 1 délai de paiement',
    'search_payment_terms' => 'Rechercher :count délais de paiement',
    'save_and_preview' => 'Enregistrer et prévisualiser',
    'save_and_email' => 'Enregistrer et envoyer par courriel',
    'converted_balance' => 'Solde converti',
    'is_sent' => 'Est Envoyé',
    'document_upload' => 'Téléversement de document',
    'document_upload_help' => 'Autoriser les clients à téléverser des documents',
    'expense_total' => 'Total des dépenses',
    'enter_taxes' => 'Saisir les taxes',
    'by_rate' => 'Par taux',
    'by_amount' => 'Par montant',
    'enter_amount' => 'Entrer le montant',
    'before_taxes' => 'Avant taxes',
    'after_taxes' => 'Après taxes',
    'color' => 'Couleur',
    'show' => 'Voir',
    'empty_columns' => 'Colonnes vides',
    'project_name' => 'Nom du projet',
    'counter_pattern_error' => 'Pour utiliser :client_counter veuillez ajouter soit :client_number ou :client_id_number pour éviter les conflits',
    'this_quarter' => 'Ce trimestre',
    'to_update_run' => 'Pour mettre à jour l\'exécution',
    'registration_url' => 'URL d\'enregistrement',
    'show_product_cost' => 'Afficher le montant du produit',
    'complete' => 'Terminé',
     'next' => 'Suivant',
     'next_step' => 'Étape suivante',
     'notification_credit_sent_subject' => 'le crédit :invoice a été envoyé à :client',
     'notification_credit_viewed_subject' => 'Le crédit :invoice a été vu par :client',
     'notification_credit_sent' => 'Un crédit de :amount a été envoyé par courriel au client :client.',
     'notification_credit_viewed' => 'Un crédit de :amount a été vu par le client :client.',
     'reset_password_text' => 'Saisissez votre adresse courriel pour réinitialiser votre mot de passe.',
     'password_reset' => 'Réinitialisation du mot de passe',
     'account_login_text' => 'De retour ? Bienvenue.',
     'request_cancellation' => 'Annuler la demande',
     'delete_payment_method' => 'Supprimer le mode de paiement',
     'about_to_delete_payment_method' => 'Le mode de paiement sera supprimé',
     'action_cant_be_reversed' => 'Cette action ne peut être annulée',
     'profile_updated_successfully' => 'Le profil a été mis à jour avec succès.',
     'currency_ethiopian_birr' => 'birr éthiopien',
     'client_information_text' => 'Adresse permanente où vous recevez le courriel',
     'status_id' => 'État de facture',
     'email_already_register' => 'Cette adresse courriel est déjà liée à un compte',
     'locations' => 'Emplacements',
     'freq_indefinitely' => 'Indéfiniment',
     'cycles_remaining' => 'Cycles restants',
     'i_understand_delete' => 'Je comprends. Supprimer.',
     'download_files' => 'Télécharger les fichiers',
     'download_timeframe' => 'Utilisez ce lien pour télécharger vos fichiers. Le lien expirera dans 1 heure.',
     'new_signup' => 'Nouvelle inscription',
     'new_signup_text' => 'Un nouveau compte a été créé par :user - :email - de l\'adresse IP :ip',
     'notification_payment_paid_subject' => 'Le paiement a été fait par :client',
     'notification_partial_payment_paid_subject' => 'Le paiement partiel a été fait par :client',
     'notification_payment_paid' => 'Un paiement de :amount a été fait par le client : pour la facture :invoice',
     'notification_partial_payment_paid' => 'Un paiement partiel de :amount a été fait par le client : pour la facture :invoice',
     'notification_bot' => 'Bot de notifications',
     'invoice_number_placeholder' => 'Facture N° :invoice',
     'entity_number_placeholder' => ':entity N° :entity_number',
     'email_link_not_working' => 'Si le bouton ci-dessus ne fonctionne pas correctement, cliquez sur le lien',
     'display_log' => 'Afficher le registre',
     'send_fail_logs_to_our_server' => 'Rapporter les erreurs en temps réel',
     'setup' => 'Configuration',
     'quick_overview_statistics' => 'Aperçu et statistiques',
     'update_your_personal_info' => 'Mettre à jour vos infos personnelles',
     'name_website_logo' => 'Nom, site web et logo',
     'make_sure_use_full_link' => 'Utilisez le lien complet vers votre site',
     'personal_address' => 'Adresse personnelle',
     'enter_your_personal_address' => 'Saisissez votre adresse personnelle',
     'enter_your_shipping_address' => 'Saisissez votre adresse de livraison',
     'list_of_invoices' => 'Liste des factures',
     'with_selected' => 'Avec la sélection de',
     'invoice_still_unpaid' => 'Cette facture est toujours impayée. Cliquez sur le bouton pour compléter le paiement',
     'list_of_recurring_invoices' => 'Liste des factures récurrentes',
     'details_of_recurring_invoice' => 'Détails à propos des factures récurrentes',
     'cancellation' => 'Annulation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Avertissement! Vous avez demandé une annulation de ce service.\n Ce service pourrait être annulé sans autre notification.',
     'cancellation_pending' => 'Annulation en attente. Nous vous tiendrons au courant.',
     'list_of_payments' => 'Liste des paiements',
     'payment_details' => 'Détails du paiement',
     'list_of_payment_invoices' => 'Liste des factures affectées par le paiement',
     'list_of_payment_methods' => 'Liste des modes de paiement',
     'payment_method_details' => 'Détails du mode de paiement',
     'permanently_remove_payment_method' => 'Supprimer de façon définitive ce mode de paiement',
     'warning_action_cannot_be_reversed' => 'Avertissement! Cette action ne peut être annulée!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Soumissions',
     'waiting_for_approval' => 'En attente d\'approbation',
     'quote_still_not_approved' => 'Cette soumission n\'a pas encore été approuvée',
     'list_of_credits' => 'Crédits',
     'required_extensions' => 'Extensions requises',
     'php_version' => 'Version PHP',
     'writable_env_file' => 'Fichier .env inscriptible',
     'env_not_writable' => 'Le fichier .env n\'est pas inscriptible par l\'utilisateur en cours',
     'minumum_php_version' => 'Version PHP minimale',
     'satisfy_requirements' => 'Assurez-vous que toutes les exigences sont satisfaites',
     'oops_issues' => 'Oups, quelque chose cloche !',
     'open_in_new_tab' => 'Ouvrir dans un nouvel onglet',
     'complete_your_payment' => 'Paiement complet',
     'authorize_for_future_use' => 'Autoriser ce mode de paiement pour usage ultérieur',
     'page' => 'Page',
     'per_page' => 'Par page',
     'of' => 'De',
     'view_credit' => 'Voir le crédit',
     'to_view_entity_password' => 'Pour voir :entity, vous devez saisir votre mot de passe.',
     'showing_x_of' => 'Affiche :first de :last de :total résultats',
     'no_results' => 'Aucun résultat',
     'payment_failed_subject' => 'Le paiement a échoué pour le client :client',
     'payment_failed_body' => 'Un paiement fait par le client :client a échoué avec le message :message',
     'register' => 'S\'inscrire',
     'register_label' => 'Créer votre compte en quelques secondes',
     'password_confirmation' => 'Confirmer votre mot de passe',
     'verification' => 'Vérification',
     'complete_your_bank_account_verification' => 'Avant d\'utiliser un compte bancaire, il doit être vérifié.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Tous droits réservés © :year :company.',
     'credit_card_invalid' => 'Le numéro de carte de crédit fourni n\'est pas valide',
     'month_invalid' => 'Le mois indiqué n\'est pas valide',
     'year_invalid' => 'L\'année indiquée n\'est pas valide',
     'https_required' => 'HTTPS est requis, l\'envoi du formulaire va échouer',
     'if_you_need_help' => 'Si vous avez besoin d\'aide, vous pouvez écrire à notre',
     'update_password_on_confirm' => 'Après la mise à jour du mot de passe, votre compte sera confirmé.',
     'bank_account_not_linked' => 'Pour payer avec un compte bancaire, vous devez d\'abord l\'ajouter comme un mode de paiement.',
     'application_settings_label' => 'Enregistrons les informations de base sur votre Ninja de la facture!',
     'recommended_in_production' => 'Fortement recommandé en mode production',
     'enable_only_for_development' => 'Activer seulement en mode développement',
     'test_pdf' => 'Tester PDF',
     'checkout_authorize_label' => 'Checkout.com peut être enregistrer comme un mode de paiement pour usage ultérieur, lors de la première transaction. Cochez "Enregistrer les infos de carte de crédit" lors du processus de paiement.',
     'sofort_authorize_label' => 'Le compte bancaire (SOFORT) peut être enregistré comme un mode de paiement pour usage ultérieur, lors de la première transaction. Cochez "Enregistrer les infos de paiement" lors du processus de paiement.',
     'node_status' => 'État du noeud',
     'npm_status' => 'État du NPM',
     'node_status_not_found' => 'Nœud introuvable. Est-il installé ?',
     'npm_status_not_found' => 'NPM introuvable. Est-il installé ?',
     'locked_invoice' => 'La facture est verrouillée et ne peut être modifiée',
     'downloads' => 'Téléchargements',
     'resource' => 'Ressource',
     'document_details' => 'Détails du document',
     'hash' => 'Hash',
     'resources' => 'Ressources',
     'allowed_file_types' => 'Types de fichiers autorisés:',
     'common_codes' => 'Codes communs et leurs significations',
     'payment_error_code_20087' => '20087 : Données de suivi invalides (CVV et/ou date d\'expiration non valables)',
     'download_selected' => 'Télécharger la sélection',
     'to_pay_invoices' => 'Pour payer les factures, vous devez',
     'add_payment_method_first' => 'ajouter un mode de paiement',
     'no_items_selected' => 'Aucun article sélectionné',
     'payment_due' => 'Paiement dû',
     'account_balance' => 'Solde de compte',
     'thanks' => 'Merci',
     'minimum_required_payment' => 'Le paiement minimum requis est :amount',
     'under_payments_disabled' => 'La société ne tolère pas le sous-paiement.',
     'over_payments_disabled' => 'La société ne tolère pas le sur-paiement.',
     'saved_at' => 'Enregistré à :time',
     'credit_payment' => 'Le crédit a été affecté à la facture :invoice_number',
     'credit_subject' => 'Nouveau crédit :credit de :account',
     'credit_message' => 'Pour voir le crédit de :amount, cliquez sur le lien ci-dessous.',
     'payment_type_Crypto' => 'Cryptodevise',
     'payment_type_Credit' => 'Crédit',
     'store_for_future_use' => 'Enregistrer pour un usage ultérieur',
     'pay_with_credit' => 'Payer avec un crédit',
     'payment_method_saving_failed' => 'Ce mode de paiement ne peut pas être enregistré pour usage ultérieur.',
     'pay_with' => 'Payer avec',
     'n/a' => 'N/D',
     'by_clicking_next_you_accept_terms' => 'En cliquant sur "Prochaine étape", vous acceptez les conditions.',
     'not_specified' => 'Non spécifié',
     'before_proceeding_with_payment_warning' => 'Avant de procéder au paiement, vous devez remplir les champs suivants',
     'after_completing_go_back_to_previous_page' => 'Retournez à la page précédente après avoir complété',
     'pay' => 'Payer',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Le rappel 1 pour la facture :invoice a été envoyé à :client',
     'notification_invoice_reminder2_sent_subject' => 'Le rappel 2 pour la facture :invoice a été envoyé à :client',
     'notification_invoice_reminder3_sent_subject' => 'Le rappel 3 pour la facture :invoice a été envoyé à :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Un rappel perpétuel pour la facture :invoice a été envoyé à :client',
     'assigned_user' => 'Utilisateur affecté',
     'setup_steps_notice' => 'Pour accéder à la prochaine étape, vous devez tester chaque section.',
     'setup_phantomjs_note' => 'Notes à propos de Phantom JS. En savoir plus.',
     'minimum_payment' => 'Paiement minimum',
     'no_action_provided' => 'Aucune action reçue. Si c’est une erreur, veuillez contacter le soutien technique.',
     'no_payable_invoices_selected' => 'Aucune des factures sélectionnées porte un solde dû. Assurez-vous que vous n\'essayez pas de payer une facture provisoire ou une facture dont le solde est nul.',
     'required_payment_information' => 'Détails de paiement requis',
     'required_payment_information_more' => 'Pour terminer le paiement, nous avons besoin de plus d\'informations à propos de vous.',
     'required_client_info_save_label' => 'Ces informations seront sauvegardées. Vous n\'aurez pas à les saisir la prochaine fois.',
     'notification_credit_bounced' => 'Nous n\'avons pas pu émettre de Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Impossible d\'émettre Crédit :invoice',
     'save_payment_method_details' => 'Enregistrer les infos de mode de paiement',
     'new_card' => 'Nouvelle carte',
     'new_bank_account' => 'Nouveau compte bancaire',
     'company_limit_reached' => 'Limite de 10 entreprises par compte.',
     'credits_applied_validation' => 'Le total des crédits octroyés ne peut être supérieur au total des factures',
     'credit_number_taken' => 'Ce numéro de crédit est déjà utilisé',
     'credit_not_found' => 'Crédit introuvable',
     'invoices_dont_match_client' => 'Les factures sélectionnées proviennent de plus d\'un client',
     'duplicate_credits_submitted' => 'Crédits soumis en double.',
     'duplicate_invoices_submitted' => 'Factures soumises en double.',
     'credit_with_no_invoice' => 'Vous devez avoir une facture en règle avant de pouvoir utiliser un crédit lors d\'un paiement',
     'client_id_required' => 'Le numéro d\'identification du client est requis',
     'expense_number_taken' => 'Numéro de remboursement déjà utilisé',
     'invoice_number_taken' => 'Numéro de facture déjà utilisé',
     'payment_id_required' => 'Numéro de paiement requis.',
     'unable_to_retrieve_payment' => 'Impossible de récupérer le numéro de paiement spécifié',
     'invoice_not_related_to_payment' => 'La facture #:invoice n\'est pas liée à ce paiement',
     'credit_not_related_to_payment' => 'Le crédit #:credit n\'est pas lié à ce paiement',
     'max_refundable_invoice' => 'Essai de remboursement plus élevé que permis pour la facture #:invoice. Le maximum remboursable est :amount.',
     'refund_without_invoices' => 'Essai de remboursement d\'un paiement avec factures jointes. Veuillez spécifier une ou des factures valides à rembourser.',
     'refund_without_credits' => 'Essai de remboursement d\'un paiement avec crédits jointes. Veuillez spécifier un ou des crédits valides à rembourser.',
     'max_refundable_credit' => 'Essai de remboursement plus élevé que permis pour le crédit :credit. Le maximum remboursable est :amount.',
     'project_client_do_not_match' => 'Partiellement non-appliquée',
     'quote_number_taken' => 'Ce numéro de soumission est déjà pris',
     'recurring_invoice_number_taken' => 'Le numéro de facture récurrente :number est déjà pris',
     'user_not_associated_with_account' => 'L\'utilisateur n\'est pas associé à ce compte',
     'amounts_do_not_balance' => 'Les montants ne balancent pas correctement.',
     'insufficient_applied_amount_remaining' => 'Montant restant affecté insuffisant pour couvrir ce paiement.',
     'insufficient_credit_balance' => 'Solde insuffisant sur le crédit',
     'one_or_more_invoices_paid' => 'Une ou plusieurs factures ont été payées',
     'invoice_cannot_be_refunded' => 'La facture #:number ne peut être remboursée',
     'attempted_refund_failed' => 'Essai de remboursement du montant :amount seulement :refundable_amount  disponible pour remboursement.',
     'user_not_associated_with_this_account' => 'Cet utilisateur ne peut être rattaché à cette entreprise. Peut-être a-t-il déjà enregistré un utilisateur sur un autre compte?',
     'migration_completed' => 'Migration complétée',
     'migration_completed_description' => 'La migration est complétée. Veuillez vérifier vos données après la connexion.',
     'api_404' => '404 | Rien à voir ici!',
     'large_account_update_parameter' => 'Le chargement d\'un gros compte est impossible sans un paramètre updated_at',
     'no_backup_exists' => 'Aucune sauvegarde n\'existe pour cette activité',
     'company_user_not_found' => 'L\'enregistrement de l\'entreprise de l\'utilisateur introuvable.',
     'no_credits_found' => 'Aucun crédit trouvé.',
     'action_unavailable' => 'L\'action :action demandée n\'est pas disponible',
     'no_documents_found' => 'Aucun document trouvé',
     'no_group_settings_found' => 'Aucun paramètre de groupe trouvé',
     'access_denied' => 'Permissions insuffisantes pour accéder/modifier cette ressource',
     'invoice_cannot_be_marked_paid' => 'La facture ne peut pas être marquée comme payée',
     'invoice_license_or_environment' => 'License invalide, ou environnement :environment invalide',
     'route_not_available' => 'La route n\'est pas disponible',
     'invalid_design_object' => 'Objet design personnalisé invalide',
     'quote_not_found' => 'Soumission(s) introuvable(s)',
     'quote_unapprovable' => 'L\'approbation de cette soumission ne peut se faire puisqu\'elle est expirée.',
     'scheduler_has_run' => 'Le planificateur a démarré',
     'scheduler_has_never_run' => 'Le planificateur n\'a jamais démarré',
     'self_update_not_available' => 'La mise à jour manuelle n\'est pas disponible sur ce système',
     'user_detached' => 'L\'utilisateur a été détaché de l\'entreprise',
     'create_webhook_failure' => 'Création Webhook impossible',
     'payment_message_extended' => 'Merci pour votre paiement d\'un montant de :amount',
     'online_payments_minimum_note' => 'Note: Les paiements en ligne sont acceptés seulement si le montant est plus élevé que 1$ ou en devise équivalente.',
     'payment_token_not_found' => 'Le jeton de paiement est introuvable. Veuillez essayer de nouveau. Si le problème persiste, essayez avec un autre mode de paiement',
     'vendor_address1' => 'Rue du fournisseur',
     'vendor_address2' => 'App du fournisseur',
     'partially_unapplied' => 'Partiellement non-appliquée',
     'select_a_gmail_user' => 'Veuillez sélectionner un utilisateur authentifié avec Gmail',
     'list_long_press' => 'Longue pression pour liste',
     'show_actions' => 'Afficher les actions',
     'start_multiselect' => 'Démarrer la multisélection',
     'email_sent_to_confirm_email' => 'Un courriel a été envoyé pour confirmer l\'adresse courriel',
     'converted_paid_to_date' => 'Payé à ce jour converti',
     'converted_credit_balance' => 'Solde de crédit converti',
     'converted_total' => 'Total converti',
     'reply_to_name' => 'Nom de Répondre À',
     'payment_status_-2' => 'Partiellement non-appliquée',
     'color_theme' => 'Couleur de thème',
     'start_migration' => 'Démarrer la migration',
     'recurring_cancellation_request' => 'Demande d\'annulation de facture récurrente de :contact',
     'recurring_cancellation_request_body' => ':contact du client :client a demandé l\'annulation de la facture récurrente : invoice',
     'hello' => 'Bonjour',
     'group_documents' => 'Grouper les documents',
     'quote_approval_confirmation_label' => 'Êtes-vous certain de vouloir approuver cette soumission ?',
     'migration_select_company_label' => 'Sélectionnez les entreprises pour la migration',
     'force_migration' => 'Forcer la migration',
     'require_password_with_social_login' => 'Requiert un mot de passe avec une connexion de réseau social',
     'stay_logged_in' => 'Restez connecté',
     'session_about_to_expire' => 'Avertissement: Votre session va expirer bientôt',
     'count_hours' => ':count heures',
     'count_day' => '1 jour',
     'count_days' => ':count jours',
     'web_session_timeout' => 'Expiration de la session web',
     'security_settings' => 'Paramètres de sécurité',
     'resend_email' => 'Renvoyer le courriel',
     'confirm_your_email_address' => 'Veuillez confirmer votre adresse courriel',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Comptabilité',
     'required_files_missing' => 'Veuillez fournir tous les CSV.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'Vous pouvez trouver API_SECRET dans le fichier .env ou Invoice Ninja v5. Si la propriété est manquante, laissez le champ vide.',
     'billing_coupon_notice' => 'Votre rabais sera appliqué au moment de régler votre facture.',
     'use_last_email' => 'Utiliser le dernier e-mail',
     'activate_company' => 'Activer la société',
     'activate_company_help' => 'Activez les courriels, les factures récurrentes et les notifications',
     'an_error_occurred_try_again' => 'Une erreur s\'est produite, veuillez réessayer',
     'please_first_set_a_password' => 'Veuillez d\'abord définir un mot de passe',
     'changing_phone_disables_two_factor' => 'Attention: modifier votre numéro de téléphone désactivera l\'authentification à deux facteurs (A2F)',
     'help_translate' => 'Aide à la traduction',
     'please_select_a_country' => 'Veuillez sélectionner un pays',
     'disabled_two_factor' => 'L\'authentification à deux facteurs (A2F) a été désactivée avec succès',
     'connected_google' => 'Le compte a été connecté avec succès',
     'disconnected_google' => 'Le comte a été déconnecté avec succès',
     'delivered' => 'Livré',
     'spam' => 'Pourriel',
     'view_docs' => 'Afficher la documentation',
     'enter_phone_to_enable_two_factor' => 'Veuillez fournir un numéro de téléphone mobile pour activer l\'authentification à deux facteurs',
     'send_sms' => 'Envoyer un SMS',
     'sms_code' => 'Code SMS',
     'connect_google' => 'Connectez Google',
     'disconnect_google' => 'Déconnecter Google',
     'disable_two_factor' => 'Désactiver l\'authentification à deux facteurs',
     'invoice_task_datelog' => 'Facturer le journal des dates des tâches',
     'invoice_task_datelog_help' => 'Ajouter les détails de date aux lignes d\'articles des factures',
     'promo_code' => 'Code promo',
     'recurring_invoice_issued_to' => 'Facture récurrente émise à',
     'amount_greater_than_balance_v5' => 'Le montant est supérieur au solde de la facture. Vous ne pouvez pas payer en trop une facture.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Abonnement',
     'new_subscription' => 'Nouvel abonnement',
     'deleted_subscription' => 'L\'abonnement a été supprimé avec succès',
     'removed_subscription' => 'L\'abonnement a été retiré avec succès',
     'restored_subscription' => 'L\'abonnement a été restauré avec succès',
     'search_subscription' => 'Recherche de 1 abonnement',
     'search_subscriptions' => 'Recherche :count abonnements',
     'subdomain_is_not_available' => 'Le sous-domaine n\'est pas disponible',
     'connect_gmail' => 'Connectez Gmail',
     'disconnect_gmail' => 'Déconnecter Gmail',
     'connected_gmail' => 'Gmail a été connecté avec succès',
     'disconnected_gmail' => 'Gmail a été déconnecté avec succès',
     'update_fail_help' => 'Les modifications apportées au code de base peuvent bloquer la mise à jour, vous pouvez exécuter cette commande pour annuler les modifications:',
     'client_id_number' => 'Numéro d\'identification du client',
     'count_minutes' => ':count minutes',
     'password_timeout' => 'Délai d\'expiration du mot de passe',
     'shared_invoice_credit_counter' => 'Compteur partagé pour les factures et les crédits',
    'activity_80' => ':user a créé l\'abonnement :subscription',
    'activity_81' => ':user a mis à jour l\'abonnement :subscription',
    'activity_82' => ':user a archivé l\'abonnement :subscription',
    'activity_83' => ':user a supprimé l\'abonnement :subscription',
    'activity_84' => ':user a restauré l\'abonnement :subscription',

    'amount_greater_than_balance_v5' => 'Le montant est supérieur au solde de la facture. Vous ne pouvez pas payer en trop une facture.',
    'click_to_continue' => 'Cliquez pour continuer',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user a créé une facture récurrente :recurring_invoice',
    'activity_101' => ':user a mis à jour une facture récurrente :recurring_invoice',
    'activity_102' => ':user a archivé une facture récurrente :recurring_invoice',
    'activity_103' => ':user a supprimé une facture récurrente :recurring_invoice',
    'activity_104' => ':user a restauré une facture récurrente :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
